@@ -61,12 +61,19 @@ if ! $dir/bin/ccpem-python -c "import numpy" >/dev/null; then
     echo
 fi
 
+# Try and find CCP4 if on Mac
+MAC_CCP4=/Applications/ccp4-7.0/bin/ccp4.setup-sh
+if test -e $MAC_CCP4; then
+  source $MAC_CCP4
+fi
+
 if [ -z "$CCP4" ]; then
     echo
     echo "  Warning: CCP4 not found!"
     echo
-    echo "  Several CCP-EM tasks use CCP4 programs. To use those tasks, please install"
-    echo "  and set up CCP4 before running CCP-EM. CCP4 is available from www.ccp4.ac.uk."
+    echo "  CCP-EM will still run, but several tasks that use CCP4 programs will be"
+    echo "  unavailable. To use those tasks, please install and set up CCP4 before"
+    echo "  running CCP-EM. CCP4 is available from www.ccp4.ac.uk."
     echo
 else
     output="$($CCP4/bin/refmac5 -i | head -1)"
@@ -74,20 +81,56 @@ else
         echo
         echo "  Warning: problem running an example CCP4 program!"
         echo
-        echo "  Several CCP-EM tasks use CCP4 programs. Please check your CCP4 installation,"
+        echo "  CCP-EM will still run, but several tasks that use CCP4 programs will be"
+        echo "  unavailable or might run with errors. Please check your CCP4 installation,"
         echo "  or contact ccpem@stfc.ac.uk for assistance."
         echo
     else
-        version=${output##* }  # bash substring removal: keep only from the last space onwards
-        if [[ "${version%.*}" != "7.0" || (( ${version##*.} < 062 )) ]]; then
+        ccp4_version=${output##* }  # bash substring removal: keep only from the last space onwards
+        ccp4_majmin=${ccp4_version%.*}  # bash substring removal: keep up to the last '.'
+        ccp4_patch=${ccp4_version##*.}  # bash substring removal: keep only from the last '.' onwards
+        if [[ "$ccp4_majmin" != "7.0" || "10#$ccp4_patch" -lt 72 ]]; then
             echo
-            echo "  Your CCP4 installation (version ${version}) appears to be out of date."
-            echo "  We recommend using version 7.0.062 or later for best results."
+            echo "  Your CCP4 installation (version ${ccp4_version}) appears to be out of date."
+            echo "  We recommend using version 7.0.072 or later for best results."
             echo
         fi
     fi
 fi
 
+if [ "$(uname)" = "Darwin" ]; then
+    if [ ! -e "/usr/X11" ]; then
+        echo
+        echo "  Warning: XQuartz not found!"
+        echo
+        echo "  Graphical programs in CCP-EM require XQuartz."
+        echo "  Please install the latest version from https://www.xquartz.org/"
+        echo
+    else
+        xq_version="$(defaults read /Applications/Utilities/XQuartz.app/Contents/Info.plist CFBundleShortVersionString)"
+        if [ -z "$xq_version" ]; then
+            echo
+            echo "  Warning: problem getting XQuartz version information"
+            echo
+            echo "  Please check your XQuartz installation, or contact ccpem@stfc.ac.uk for assistance."
+            echo
+        else
+            xq_majmin=${xq_version%.*}  # bash substring removal: keep up to the last '.'
+            xq_patch=${xq_version##*.}  # bash substring removal: keep only from the last '.' onwards
+            if [[ "$xq_majmin" != "2.7" || "10#$xq_patch" -lt 11 ]]; then
+                echo
+                echo "  Warning: XQuartz version is too old!"
+                echo
+                echo "  Your XQuartz version (version ${xq_version}) is out of date and might cause"
+                echo "  some graphical CCP-EM programs to fail."
+                echo
+                echo "  Please install the latest version from https://www.xquartz.org/, or update"
+                echo "  using the \"Check for X11 Updates\" option in the XQuartz menu."
+                echo
+            fi
+        fi
+    fi
+fi
 
 echo
 echo "         Before running CCPEM programs from command line,"
