@@ -19,7 +19,6 @@ import shutil,glob
 from TEMPy.class_arg import TempyParser
 from collections import OrderedDict
 from TEMPy.ShowPlot import Plot
-from TEMPy.mapprocess import Filter
 import json
 mrcfile_import=True
 try:
@@ -63,6 +62,7 @@ rlist = tp.args.rlist
 rigid_out = tp.args.rigidout
 rigid_out_prefix = 'rigid'
 mode = tp.args.mode
+sm = tp.args.sim_map
 # the sigma factor determines the width of the Gaussian distribution used to describe each atom
 sim_sigma_coeff = 0.187
 if not tp.args.sigfac is None:
@@ -149,7 +149,7 @@ else:
         
 if len(list_maps) != len(list_res): 
     sys.exit("Number of input map(s) and resolution(s) dont match")  
-if len(list_maps) == 0 or  len(list_models) == 0: sys.exit('Input atleast one map and a model')      
+if len(list_maps) == 0 or len(list_models) == 0: sys.exit('Input atleast one map and a model')      
 #change these in case of multiple fitted models with single chain
 #labels for the models
 if len(list_labels) == 0: list_labels = ['.'.join(os.path.basename(x).split('.')[:-1]) for x in list_models]#['initial','final']
@@ -224,8 +224,6 @@ def get_neigh_residues(list_ca_coord_low,list_ca_coord,seqres,dist=5.0):
     return list_flex
 
 
-start_pdb = list_models[0]
-
 intermed_file = ""
 slow = 0.50
 shigh = 0.25 # fraction of structure fitted reasonably well initially
@@ -244,6 +242,20 @@ print list_maps
 dict_map_scores = OrderedDict()
 m_count = 0
 dict_str_scores = OrderedDict()
+if mrcfile_import:
+    from TEMPy.mapprocess import Filter
+#if model map is provided
+sim_map = None
+if sm is not None:
+    #read simulated map file
+    if mrcfile_import:
+        map_file = sm
+        mrcobj=mrcfile.open(map_file,mode='r')
+        sim_map = Filter(mrcobj)
+        sim_map.set_apix_tempy()
+    else:
+        sim_map=MapParser.readMRC(map_file)
+
 for map_file in list_maps:
     #read map file
     if mrcfile_import:
@@ -274,21 +286,33 @@ for map_file in list_maps:
                                                        out_iter_pdb,
                                                        hetatm=False,
                                                        water=False)
-            #get scores
-            if mode == 'CA' or mode == 'AR': dict_ch_scores,dict_chain_res = \
-                sc.S_OVR(emmap,res_map,structure_instance,c,win=win,
-                        rigid_body_file=rfilepath,sigma_map=sim_sigma_coeff,
-                        atom_sel=mode,fragment_score=fragment_window,
-                        dist=tp.args.dist)
-            else: dict_ch_scores,dict_chain_res = \
-                sc.SMOC(emmap,res_map,structure_instance,win=win,
-                        rigid_body_file=rfilepath,sigma_map=sim_sigma_coeff,
+        else: 
+            print 'PDB file not found:', out_iter_pdb
+            iter_num = iter_num - 1
+            continue
+            
+        #get scores
+        if mode == 'CA' or mode == 'AR': dict_ch_scores,dict_chain_res = \
+            sc.S_OVR(emmap,res_map,structure_instance,c,win=win,
+                    rigid_body_file=rfilepath,sim_map=sim_map,
+                    sigma_map=sim_sigma_coeff,
+                    atom_sel=mode,fragment_score=fragment_window,
+                    dist=tp.args.dist)
+        else: 
+            if fragment_window:
+                dict_ch_scores,dict_chain_res, dict_chain_CA = \
+                sc.SMOC(emmap,res_map,structure_instance=structure_instance,win=win,
+                        rigid_body_file=rfilepath,sim_map=sim_map,
+                        sigma_map=sim_sigma_coeff,
                         sigma_thr=2.0,fragment_score=fragment_window,
                         dist=tp.args.dist)
-        else:
-            print 'PDB file not found:', out_iter_pdb
-            iter_num = iter_num-1
-            continue
+            else:
+                dict_ch_scores,dict_chain_res, dict_chain_CA = \
+                sc.SMOC(emmap,res_map,structure_instance=structure_instance,win=win,
+                        rigid_body_file=rfilepath,sim_map=sim_map,
+                        sigma_map=sim_sigma_coeff,
+                        sigma_thr=2.0,fragment_score=fragment_window,
+                        dist=tp.args.dist, atom_centre='CB')
         
         if rigid_out:
                 dict_chain_indices, dict_chain_CA = blurrer.get_coordinates(
@@ -321,7 +345,8 @@ for map_file in list_maps:
                 except KeyError: 
                     if reslist.index(res) <= 0: 
                         #assign neighbour score
-                        scorelist.append(dict_res_scores[reslist[reslist.index(res)+1]])
+                        try: scorelist.append(dict_res_scores[reslist[reslist.index(res)+1]])
+                        except KeyError, IndexError: scorelist.append(0.0)
                     else: 
                         try:  scorelist.append(dict_res_scores[reslist[reslist.index(res)-1]])
                         except KeyError, IndexError: scorelist.append(0.0)
@@ -405,8 +430,8 @@ for ch in dict_chains_scores:
                     break
             list_ressc.append(res_sc)
             if flag_res == 0: continue 
-            reslist.append(res)
-            scorelist.append(dict_str_scores[model][ch][res])
+            reslist.append(int(res))
+            scorelist.append(float(dict_str_scores[model][ch][res]))
             if mdl_ini == 0: sco.write(str(res)+"\t"+'\t'.join(list_ressc)+"\n")
         if z_score: 
             npscorelist = np.array(scorelist,dtype='float')
@@ -417,5 +442,6 @@ for ch in dict_chains_scores:
         mdl_ini += 1
     sco.close()
     outfile = ch+"_smocscoreplot.png"
-    plt.lineplot(dict_points,outfile,xlabel='Residue_num',ylabel='SMOC',marker=False,lstyle=False,leg_pos=1.8,ylim=[-0.1,1.0]),#legend_loc='upper right')  
+    
+    plt.lineplot(dict_points,outfile,xlabel='Residue_num',ylabel='SMOC',marker=False,lstyle=False,leg_pos=1.8)#,ylim=[-0.1,1.0]),#legend_loc='upper right')  
   
