@@ -24,8 +24,8 @@ mrc_ext = 'MRC maps (*.mrc *.mrcs *.map *.ccp4)'
 text_ext = 'Text files (*.txt)'
 # PDB formats
 pdb_ext = 'PDB files (*.pdb *.cif *.ent)'
-# Lib format (Refmac)
-lib_ext = 'Lib files (*.lib)'
+# Ligand CIF library (Refmac)
+lib_ext = 'Ligand files (*.cif *.lib)'
 
 
 def check_text_file(filename):
