@@ -19,7 +19,7 @@ import numpy as np
 import pyrvapi
 # XXX Temp. fix for OS X build
 try:
-    from ccpem_core.star_io_mmdb.ext import star_io_mmdb as star_io_mmdb_ext
+    from ccpem_core.star_io.ext import star_io_mmdb as star_io_mmdb_ext
 except:
     ImportError
 import metadata_default_labels
@@ -405,14 +405,14 @@ class MetaDataContainer(object):
         hdf_import = pd.HDFStore(filename)
         for key in hdf_import.keys():
             if '_MetaDataTable' in key:
-                md_table = MetaDataTable()
-                md_table.data_frame = hdf_import[key]
+                data_frame = hdf_import[key]
+                md_table = MetaDataTable(data_frame)
                 name = key.replace('_MetaDataTable', '').replace('/', '')
                 self.metadata_items._add_meta_data_item(name=name,
                                                         item=md_table)
             elif '_MetaDataSeries' in key:
-                md_series = MetaDataSeries()
-                md_series.series = hdf_import[key]
+                series = hdf_import[key]
+                md_series = MetaDataSeries(series)
                 name = key.replace('_MetaDataSeries', '').replace('/', '')
                 self.metadata_items._add_meta_data_item(name=name,
                                                         item=md_series)
@@ -426,9 +426,9 @@ class MetaDataContainer(object):
             if key[0] != '_':
                 class_str = self.metadata_items.__dict__[key].__class__.__name__
                 if class_str is 'MetaDataSeries':
-                    hdf_export[key+'_MetaDataSeries'] = self.metadata_items.__dict__[key].series
+                    hdf_export[key+'_MetaDataSeries'] = self.metadata_items.__dict__[key]
                 elif class_str is 'MetaDataTable':
-                    hdf_export[key+'_MetaDataTable'] = self.metadata_items.__dict__[key].data_frame
+                    hdf_export[key+'_MetaDataTable'] = self.metadata_items.__dict__[key]
 
     def import_json_file(self, filename):
         '''
@@ -439,18 +439,18 @@ class MetaDataContainer(object):
         json_file.close()
         for key in data.keys():
             if '_MetaDataTable' in key:
-                md_table = MetaDataTable()
-                md_table.data_frame = pd.io.json.read_json(
+                data_frame = pd.io.json.read_json(
                                         path_or_buf=data[key],
                                         typ='frame')
+                md_table = MetaDataTable(data_frame)
                 name = key.replace('_MetaDataTable', '').replace('/', '')
                 self.metadata_items._add_meta_data_item(name=name,
                                                         item=md_table)
             elif '_MetaDataSeries' in key:
-                md_series = MetaDataSeries()
-                md_series.series = pd.io.json.read_json(
+                series = pd.io.json.read_json(
                                         path_or_buf=data[key],
                                         typ='series')
+                md_series = MetaDataSeries(series)
                 name = key.replace('_MetaDataSeries', '').replace('/', '')
                 self.metadata_items._add_meta_data_item(name=name,
                                                         item=md_series)
