@@ -38,7 +38,8 @@ class Nautilus(task_utils.CCPEMTask):
                 'cnautilus':which('cnautilus'),
                 'sftools':which('sftools'),
                 'cad':which('cad'),
-                'freerflag':which('freerflag')
+                'freerflag':which('freerflag'),
+                'libg':which('libg')
                 }
 
     def __init__(self,
@@ -127,22 +128,22 @@ class Nautilus(task_utils.CCPEMTask):
             help='Number of Nautilus cycles in subsequent pipeline cycle',
             metavar='N-th Nautilus cycles',
             type=int,
-            default=3)
+            default=5)
         #
         parser.add_argument(
             '-ncycle_refmac',
             '--ncycle_refmac',
             help='Number of refmac cycles',
-            metavar='Build cycles',
+            metavar='Refine cycles',
             type=int,
-            default=10)
+            default=20)
         #
         parser.add_argument(
             '-map_sharpen',
             '--map_sharpen',
-            metavar='Map sharpen',
-            help=('B-factor to apply to map. Negative B-factor to sharpen, '
-                  'positive to blur, zero to leave map as input.'),
+            metavar='Sharpen / blur',
+            help=('B-factor to apply to map. Negative B-factor to '
+                  'sharpen, positive to blur, zero to leave map as input'),
             type=float,
             default=0)
         #
@@ -168,13 +169,20 @@ class Nautilus(task_utils.CCPEMTask):
         Generate job classes and process.  Run=false for reloading.
         '''
         # Convert map to mtz (refmac)
+        # set F columns label suffix
         bfactor = self.args.map_sharpen()
         if bfactor >= 0:
             sharp_array = None
             blur_array = [bfactor]
+            if bfactor == 0:
+                label_out_suffix = '0'
+            else:
+                label_out_suffix = 'Blur_{0:.2f}'.format(self.args.map_sharpen.value)
         else:
             sharp_array = [-1 * bfactor]
             blur_array = None
+            label_out_suffix = 'Sharp_{0:.2f}'.format(self.args.map_sharpen.value)
+        
         self.process_maptomtz = refmac_task.RefmacMapToMtz(
             command=self.commands['refmac'],
             resolution=self.args.resolution.value,
@@ -195,15 +203,16 @@ class Nautilus(task_utils.CCPEMTask):
             name='Set MTZ SigF and SG')
         pl.append([self.process_sftools_buccanneer.process])
 
+        # I find this redundant so can skip
         # Set column labels with Cad
-        self.process_cad_labels = buccaneer_task.CADBuccaneerLabels(
-            command=self.commands['cad'],
-            job_location=self.job_location,
-            resolution=self.args.resolution.value,
-            hklin=self.process_sftools_buccanneer.hklout,
-            sharpen_bfactor=self.args.map_sharpen.value,
-            name='Set MTZ labels')
-        pl.append([self.process_cad_labels.process])
+        #self.process_cad_labels = buccaneer_task.CADBuccaneerLabels(
+        #    command=self.commands['cad'],
+        #    job_location=self.job_location,
+        #    resolution=self.args.resolution.value,
+        #    hklin=self.process_sftools_buccanneer.hklout,
+        #    sharpen_bfactor=self.args.map_sharpen.value,
+        #    name='Set MTZ labels')
+        #pl.append([self.process_cad_labels.process])
 
         # Create R free flags
         hklout = os.path.join(self.job_location,
@@ -211,7 +220,7 @@ class Nautilus(task_utils.CCPEMTask):
         self.process_free_r_flags = buccaneer_task.FreeRFlags(
             command=self.commands['freerflag'],
             job_location=self.job_location,
-            hklin=self.process_cad_labels.hklout,
+            hklin=self.process_sftools_buccanneer.hklout,
             hklout=hklout,
             name='Set Rfree')
         pl.append([self.process_free_r_flags.process])
@@ -227,7 +236,8 @@ class Nautilus(task_utils.CCPEMTask):
             self.args.input_seq.value = f.name
 
         # Run Nautilus - new pipeline = Nautilus->Refmac refine pipeline->repeat...
-        refine_keywords=add_refmac_keywords(self.args.refmac_keywords.value, self.process_cad_labels.label_out_suffix)
+        refine_keywords=add_refmac_keywords(self.args.refmac_keywords.value, 
+                                            label_out_suffix)
 
         for i in range(1, (self.args.ncycle.value + 1)) :
             # 1st cycle Nautilus
@@ -237,8 +247,9 @@ class Nautilus(task_utils.CCPEMTask):
                             job_location=self.job_location,
                             hklin=self.process_free_r_flags.hklout,
                             seqin=self.args.input_seq.value,
-                            label_out_suffix=self.process_cad_labels.label_out_suffix,
+                            label_out_suffix=label_out_suffix,
                             ncycle=i,
+                            internal_cycle=self.args.ncycle_nau1st.value,
                             resolution=self.args.resolution.value,
                             pdbin=self.args.extend_pdb.value,
                             pdbout=None,
@@ -247,29 +258,47 @@ class Nautilus(task_utils.CCPEMTask):
                             keywords=self.args.keywords.value)
                 pl.append([self.process_nautilus_pipeline.process])
 
+                # Run libg for DNA/RNA restraints
+                self.process_libg = refmac_task.LibgRestraints(
+                    command=self.commands['libg'],
+                    job_location=self.job_location,
+                    name='DNA or RNA basepair restraints ' + str(i),
+                    pdb_path=self.process_nautilus_pipeline.pdbout)
+                pl.append([self.process_libg.process])
+
                 # Run RefmacRefine (global)
+                # Invert sharpening value for refmac
+                if self.args.map_sharpen() is None:
+                    sharp = 0
+                else:
+                    sharp = -1.0*self.args.map_sharpen()
                 self.process_refine = refmac_task.RefmacRefine(
                     command=self.commands['refmac'],
                     job_location=self.job_location,
                     pdb_path=self.process_nautilus_pipeline.pdbout,
                     mtz_path=self.process_free_r_flags.hklout,
                     resolution=self.args.resolution.value,
+                    pdbout_path=os.path.join(self.job_location, 'refined' + str(i) + '.pdb'),
                     mode='Global',
                     name='Refmac refine (global) ' + str(i),
-                    sharp=self.args.map_sharpen.value,
+                    sharp=sharp,
                     ncycle=self.args.ncycle_refmac.value,
                     output_hkl=True,
-                    keywords=refine_keywords)
+                    symmetry_auto=False,
+                    keywords=refine_keywords,
+                    libg_restraints=True,
+                    libg_restraints_path=[self.process_libg.libg_restraints_path])
                 pl.append([self.process_refine.process])
             else :
                 #nth cycle Nautilus
                 self.process_nautilus_pipeline = NautilusPipeline(
                             command=self.commands['cnautilus'],
                             job_location=self.job_location,
-                            hklin=self.process_refine.hklout_path,
+                            hklin=self.process_free_r_flags.hklout,
                             seqin=self.args.input_seq.value,
-                            label_out_suffix=self.process_cad_labels.label_out_suffix,
+                            label_out_suffix=label_out_suffix,
                             ncycle=i,
+                            internal_cycle=self.args.ncycle_naunth.value,
                             resolution=self.args.resolution.value,
                             pdbin=self.process_refine.pdbout_path,
                             pdbout=None,
@@ -278,19 +307,36 @@ class Nautilus(task_utils.CCPEMTask):
                             keywords=self.args.keywords.value)
                 pl.append([self.process_nautilus_pipeline.process])
 
+                # Run libg for DNA/RNA restraints
+                self.process_libg = refmac_task.LibgRestraints(
+                    command=self.commands['libg'],
+                    job_location=self.job_location,
+                    name='DNA or RNA basepair restraints ' + str(i),
+                    pdb_path=self.process_nautilus_pipeline.pdbout)
+                pl.append([self.process_libg.process])
+
                 # Run RefmacRefine (global)
+                # Invert sharpening value for refmac
+                if self.args.map_sharpen() is None:
+                    sharp = 0
+                else:
+                    sharp = -1.0*self.args.map_sharpen()
                 self.process_refine = refmac_task.RefmacRefine(
                     command=self.commands['refmac'],
                     job_location=self.job_location,
                     pdb_path=self.process_nautilus_pipeline.pdbout,
                     mtz_path=self.process_free_r_flags.hklout,
                     resolution=self.args.resolution.value,
+                    pdbout_path=os.path.join(self.job_location, 'refined' + str(i) + '.pdb'),
                     mode='Global',
                     name='Refmac refine (global) ' + str(i),
-                    sharp=self.args.map_sharpen.value,
-                    ncycle=self.args.ncycle.refmac.value,
+                    sharp=sharp,
+                    ncycle=self.args.ncycle_refmac.value,
                     output_hkl=True,
-                    keywords=refine_keywords)
+                    symmetry_auto=False,
+                    keywords=refine_keywords,
+                    libg_restraints=True,
+                    libg_restraints_path=[self.process_libg.libg_restraints_path])
                 pl.append([self.process_refine.process])
 
         custom_finish = NautilusResultsOnFinish(
@@ -328,6 +374,7 @@ class NautilusPipeline(object):
             seqin,
             label_out_suffix,
             ncycle=1,
+            internal_cycle=5,
             resolution=2.0,
             pdbin=None,
             pdbout=None,
@@ -343,6 +390,7 @@ class NautilusPipeline(object):
         self.label_out_suffix = label_out_suffix
         self.pdbout = pdbout
         self.ncycle = ncycle
+        self.internal_cycle=internal_cycle
         self.resolution = resolution
         self.pdbin = pdbin
         if self.pdbout is None:
@@ -371,23 +419,22 @@ class NautilusPipeline(object):
     def set_stdin(self):
         pdbin_ref = os.path.join(os.environ['CLIBD'],
             'nautilus_lib.pdb')
-        if self.ncycle == 1:
-            self.buc_cycle = 5
-            self.stdin_extra = '''colin-phifom PHIem, FOMem
-            '''
-        else:
-            self.buc_cycle = 3
-            self.stdin_extra = '''colin-hl HLACOMB, HLBCOMB, HLCCOMB, HLDCOMB
-colin-fc FWT, PHWT
-'''
+        #if self.ncycle == 1:
+        #    self.stdin_extra = '''colin-phifom PHIem, FOMem
+        #    '''
+        #else:
+        #    self.stdin_extra = '''colin-hl HLACOMB, HLBCOMB, HLCCOMB, HLDCOMB
+#colin-fc FWT, PHWT
+#'''
 
         self.stdin = '''
 title {0}
 pdbin-ref {1}
 seqin {2}
 mtzin {3}
-colin-fo Fem{4},SIGFem{4}
+colin-fo Fout{4},SIGFem
 colin-free FreeR_flag
+colin-phifom Pout0,FOMem
 pdbout {5}
 cycles {6}
 resolution {7}
@@ -400,11 +447,11 @@ xmlout program{8}.xml
     self.hklin,
     self.label_out_suffix,
     self.pdbout,
-    self.buc_cycle,
+    self.internal_cycle,
     self.resolution,
     self.ncycle)
 
-        self.stdin = self.stdin + self.stdin_extra
+        #self.stdin = self.stdin + self.stdin_extra
         # Add optional nautilus keywords
         if isinstance(self.keywords, str):
             if self.keywords != '':
@@ -427,24 +474,20 @@ class NautilusResultsOnFinish(process_manager.CCPEMPipelineCustomFinish):
         self.refine_process = refine_process
 
     def on_finish(self, parent_pipeline=None):
-        #copy refine.pdb to nautilus.pdb just as the old pipeline
-        target_path = os.path.dirname(self.refine_process.pdbout_path)
-        targetpdb_path = os.path.join(target_path, 'nautilus.pdb')
-        os.system('cp {0} {1}' .format(self.refine_process.pdbout_path, targetpdb_path))
         #generate RVAPI report
         nautilus_results.PipelineResultsViewer(
                   pipeline_path=self.pipeline_path)
 
-def add_refmac_keywords(refkeywords, cad_labelout_suffix):
+def add_refmac_keywords(refkeywords, labelout_suffix):
     '''
     Add default and additional refmac keywords
     '''
-    refine_keywords='''labin PHIB=PHIem FOM=FOMem FREE=FreeR_flag FP=Fem{0} SIGFP=SIGFem{0}
-PHOUT
-PNAME nautilus
-DNAME nautilus
-'''.format(cad_labelout_suffix)
-    
+    refine_keywords=''
+#PHOUT
+#PNAME nautilus
+#DNAME nautilus
+#'''.format(labelout_suffix)
+
     if isinstance(refkeywords, str):
         if refkeywords != '':
             # Remove trailing white space and new lines
@@ -454,12 +497,3 @@ DNAME nautilus
 
     return refine_keywords
 
-def main():
-    '''
-    Run task
-    '''
-    task_utils.command_line_task_launch(
-        task=Nautilus)
-
-if __name__ == '__main__':
-    main()
