@@ -8,7 +8,7 @@
 #
 
 # N.B. to run in google chrome use following flag
-# google-chrome index.html --allow-file-access-from-files 
+# google-chrome index.html --allow-file-access-from-files
 
 
 # Refmac results - to do
@@ -20,6 +20,7 @@
 # 1) Set focus for single tab (i.e. to show log)
 # 2) Intermittent display bug (e.g. chrome vs firefox)
 
+import sys
 import os
 import collections
 import math
@@ -31,8 +32,6 @@ import pyrvapi
 from ccpem_core import ccpem_utils
 from ccpem_core.data_model import metadata_utils
 from ccpem_core.ccpem_utils.ccp4_log_parser import smartie
-from ccpem_core import process_manager
-
 
 # Ask Eugene...
 # N.B. large log files take a long time to run.
@@ -49,46 +48,23 @@ class RefmacResultsViewer(object):
             to refmac refinement process
     '''
     def __init__(self,
-                 pipeline=None,
-                 pipeline_path=None):
-        if pipeline_path is not None:
-            self.pipeline = process_manager.CCPEMPipeline(
-                pipeline=None,
-                import_json=pipeline_path)
-        else:
-            self.pipeline = pipeline
-        # Get processes
-        self.mrc2mtz_process = None
-        self.refine_process = None
-        self.validate_hm1_process = None
-        self.validate_hm2_process = None
-        self.fsc_process = None
-        self.dac_process = None
+                 job_location='',
+                 mrc2mtz_stdout='',
+                 refine_stdout='',
+                 validate_hm1_stdout='',
+                 validate_hm2_stdout='',
+                 fsc_stdout='',
+                 dac_stdout=''):
+        self.job_location = job_location
+        self.mrc2mtz_stdout = mrc2mtz_stdout
+        self.refine_stdout = refine_stdout
+        self.validate_hm1_stdout = validate_hm1_stdout
+        self.validate_hm2_stdout = validate_hm2_stdout
+        self.fsc_stdout = fsc_stdout
+        self.dac_stdout = dac_stdout
         #
-        errors = {}
-        for jobs in self.pipeline.pipeline:
-            for job in jobs:
-                if job.name == 'Map to MTZ':
-                    self.mrc2mtz_process = job
-                if job.name in ['Refmac refine (global)',
-                                'Refmac refine (local)']:
-                    self.refine_process = job
-                if job.name == 'Refmac refine (HM1)':
-                    self.validate_hm1_process = job
-                if job.name == 'Refmac stats (HM2)':
-                    self.validate_hm2_process = job
-                if job.name == 'Refmac FSC (HM1 vs HM2)':
-                    self.fsc_process = job
-                if job.name == 'Refine chain by chain':
-                    self.dac_process = job
-                #
-                if os.path.exists(job.stderr):
-                    statinfo = os.stat(job.stderr)
-                    if statinfo.st_size > 0:
-                        errors[job.name] = job.stderr
-
         self.refine_results = None
-        self.directory = os.path.join(self.pipeline.location,
+        self.directory = os.path.join(self.job_location,
                                       'rvapi_data')
         if os.path.exists(self.directory):
             shutil.rmtree(self.directory)
@@ -98,9 +74,10 @@ class RefmacResultsViewer(object):
         ccp4 = os.environ['CCPEM']
         share_jsrview = os.path.join(ccp4, 'share', 'jsrview')
         # Setup pages
-        pyrvapi.rvapi_init_document(self.pipeline.location, self.directory,
-                                    self.pipeline.location, 1, 4, share_jsrview,
-                                    None, None, None, None)
+        pyrvapi.rvapi_init_document(
+            self.job_location, self.directory,
+            self.job_location, 1, 4, share_jsrview,
+            None, None, None, None)
         pyrvapi.rvapi_flush()
 
         # Set results
@@ -111,54 +88,57 @@ class RefmacResultsViewer(object):
         '''
         Fix missing column headings for fsc table
         '''
-        error_line = ' 2sin(th)/l 2sin(th)/l NREF sigma  FSC PHdiff cos(PHdiff) sigmaSig ZZ TT cor(|F1|,|F2|) $$'
-        fixed_line = ' 2sin(th)/l 2sin(th)/l NREF sigma  FSC PHdiff cos(PHdiff) sigmaSig ZZ TT cor(|F1|,|F2|) H1 H2 $$'
+        error_line = ' 2sin(th)/l 2sin(th)/l NREF sigma  FSC FSCT PHdiff cos(PHdiff) sigmaSig ZZ TT co\n'
+        fixed_line = ' 2sin(th)/l 2sin(th)/l NREF sigma  FSC FSCT PHdiff cos(PHdiff) sigmaSig ZZ TT cor(|F1|,|F2|) $$'
+        ignore_line = ' r(|F1|,|F2|) $$\n'
+        #
         for line in fileinput.input(stdout, inplace=True):
-            if line.find(error_line) != -1:
+            if line == error_line:
                 print fixed_line,
+            elif line == ignore_line:
+                pass
             else:
                 print line,
         fileinput.close()
 
     def set_results(self):
         # DaC mode
-        if self.dac_process is not None:
+        if os.path.exists(self.dac_stdout):
             self.dac_results = dacParser(
-                stdout=self.dac_process.stdout)
+                stdout=self.dac_stdout)
             self.set_refine_results_summary()
             return
         else:
             self.dac_results = None
 
-
         # Get mrc2mtz results (power spectrum)
-        if self.mrc2mtz_process is not None:
+        if os.path.exists(self.mrc2mtz_stdout):
             self.mrc2mtz_results = RefmacPowerSpectrumParser(
-                stdout=self.mrc2mtz_process.stdout)
+                stdout=self.mrc2mtz_stdout)
         else:
             self.mrc2mtz_results = None
-        
+
         # Get refinement results
-        if self.refine_process is not None:
+        if os.path.exists(self.refine_stdout):
             self.refine_results = RefmacRefineResultsParser(
-                stdout=self.refine_process.stdout)
+                stdout=self.refine_stdout)
             if self.refine_results.refine_results is not None:
                 self.set_refine_results_summary()
 
         # Get validation results
-        validate_processes = [self.validate_hm1_process,
-                              self.validate_hm2_process,
-                              self.fsc_process]
-         
-        if validate_processes.count(None) == 0:
+        validate_processes = [os.path.exists(self.validate_hm1_stdout),
+                              os.path.exists(self.validate_hm2_stdout),
+                              os.path.exists(self.fsc_stdout)]
+
+        if all(validate_processes):
             # Refinement against half map one
             self.refine_hm1_results = RefmacRefineResultsParser(
-                stdout=self.validate_hm1_process.stdout)
+                stdout=self.validate_hm1_stdout)
             self.refine_hm2_results = RefmacRefineResultsParser(
-                stdout=self.validate_hm2_process.stdout)
-            self.fix_refmac_fsc_table(stdout=self.fsc_process.stdout)
+                stdout=self.validate_hm2_stdout)
+            self.fix_refmac_fsc_table(stdout=self.fsc_stdout)
             self.fsc_hm1hm2 = RefmacFSCMapParser(
-                stdout=self.fsc_process.stdout)
+                stdout=self.fsc_stdout)
             self.set_validation_results()
 
     def set_log(self, path):
@@ -183,9 +163,9 @@ class RefmacResultsViewer(object):
 #                                   'Refinement summary',
 #                                   validate_tab,
 #                                   0, 0, 1, 1, True)
-#         
+#
         # dac mode
-        if self.dac_process is not None:
+        if os.path.exists(self.dac_stdout):
             refine_tab = 'refine_tab'
             refine_sec = 'sec_refine'
             refine_summary_table = 'refine_table'
@@ -399,7 +379,7 @@ class RefmacResultsViewer(object):
             graph_id=refinement_graphs_id,
             data_id=final_data_id,
             originalXAxis=True,
-            step=int(len(self.refine_results.fsc_fom_table) / 7.0 ),
+            step=max(int(len(self.refine_results.fsc_fom_table) / 7.0 ), 1),
             ymin=0.0)
 
         ### Power spectrum
@@ -434,7 +414,7 @@ class RefmacResultsViewer(object):
                     'Mn(|F|)^2',
                     axis=1,
                     inplace=True)
-    
+
                 self.mrc2mtz_results.mean_amp_table['Log(Mn(|F|))'] = \
                     self.mrc2mtz_results.mean_amp_table['Mn(|F|)'].apply(
                         lambda x: str(math.log(float(x))))
@@ -444,7 +424,7 @@ class RefmacResultsViewer(object):
                 self.mrc2mtz_results.mean_amp_table['Log(Variance)'] = \
                     self.mrc2mtz_results.mean_amp_table['Variance'].apply(
                         lambda x: str(math.log(float(x))))
-    
+
                 self.mrc2mtz_results.mean_amp_table.drop(
                     'Mn(|F|)',
                     axis=1,
@@ -467,7 +447,7 @@ class RefmacResultsViewer(object):
                     graph_id=refinement_graphs_id,
                     data_id=map_data_id,
                     originalXAxis=True,
-                    step=int(len(self.mrc2mtz_results.mean_amp_table) / 7.0))
+                    step=max(int(len(self.mrc2mtz_results.mean_amp_table) / 7.0), 1))
 
 
     def set_validation_results(self):
@@ -489,7 +469,6 @@ class RefmacResultsViewer(object):
             validate_sec, 0, 0, 1, 1)
 
         ### Set validate table
-
         pyrvapi.rvapi_add_table(
             validate_table, 'Refinement statistics', validate_sec, 1, 0, 1,
             1, False)
@@ -556,7 +535,7 @@ class RefmacResultsViewer(object):
                                                            axis=1,
                                                            inplace=True)
 
-# Half map 1 vs 2
+        # Half map 1 vs 2
         self.fsc_hm1hm2.fsc_table.set_index(angstrom_label,
                                             inplace=True)
         keep_col = [angstrom_label, 'FSC', 'cos(PHdiff)', 'cor(|F1|,|F2|)']
@@ -619,8 +598,7 @@ class RefmacPowerSpectrumParser(object):
                     self.mean_amp_table.replace_infinity()
                 except ValueError:
                     self.mean_amp_table = None
-                    print ccpem_utils.print_warning(
-                        'Unable to parse Mean(|F|) table')
+                    ccpem_utils.print_warning('Unable to parse Mean(|F|) table')
 
 class RefmacFSCMapParser(object):
     '''
@@ -632,19 +610,18 @@ class RefmacFSCMapParser(object):
         # Find FSC program in stdout
         fsc_prog = self.log.program(0)
         self.fsc_table = None
-        self.mean_amp_table = None
         for table in fsc_prog.tables():
             if table.title() == 'FSC and other statistics':
                 self.fsc_table = \
                     smartie_table_to_meta_data_table(table=table)
                 self.fsc_table.convert_to_resolution_angstrom()
                 self.fsc_table.replace_infinity()
+        if self.fsc_table is None:
+            ccpem_utils.print_warning('Unable to parse FSC table')
 
     def print_summary(self):
         if self.fsc_table is not None:
             print self.fsc_table.to_string()
-        if self.mean_amp_table is not None:
-            print self.mean_amp_table.to_string()
 
 class RefmacRefineResultsParser(object):
     '''
@@ -674,8 +651,8 @@ class RefmacRefineResultsParser(object):
             self.refine_results = refine_prog.keytext(-1)
         if self.refine_results is not None:
             self.set_results_summary()
-    
-            # Parse table list in reverse order to find final FSC and ncyc table 
+
+            # Parse table list in reverse order to find final FSC and ncyc table
             for cntr in reversed(xrange(len(refine_prog.tables()))):
                 table = refine_prog.tables()[cntr]
                 if table.title().find('FSC and  Fom') != -1:
@@ -832,5 +809,33 @@ class dacParser(object):
     def print_summary(self):
         print self.stdout
 
+def main():
+    job_location = sys.argv[1]
+    mode = sys.argv[2]
+    
+    if mode == 'Local':
+        refine_stdout = os.path.join(
+            job_location,
+            'refmacrefinelocal_stdout.txt')
+    else:
+        refine_stdout = os.path.join(
+            job_location,
+            'refmacrefineglobal_stdout.txt')
+    RefmacResultsViewer(
+        job_location=job_location,
+        mrc2mtz_stdout=os.path.join(
+            job_location,
+            'maptomtz_stdout.txt'),
+        refine_stdout=refine_stdout,
+        validate_hm1_stdout=os.path.join(
+            job_location,
+            'refmacrefinehm1_stdout.txt'),
+        validate_hm2_stdout=os.path.join(
+            job_location,
+            'refmacstatshm2_stdout.txt'),
+        fsc_stdout=os.path.join(
+            job_location,
+            'refmacfschm1vshm2_stdout.txt'))
+
 if __name__ == '__main__':
     main()
