@@ -13,13 +13,16 @@
 
 import os
 import shutil
+import copy
+
+import mrcfile
+
 from ccpem_core.ccpem_utils import ccpem_argparser
 from ccpem_core.tasks.refmac import refmac_results
 from ccpem_core import ccpem_utils
 from ccpem_core.settings import which
 from ccpem_core import process_manager
 from ccpem_core.tasks import task_utils
-from ccpem_core.map_io import numpy_mrc_io
 from ccpem_core import settings
 
 # From Garib:
@@ -107,7 +110,7 @@ class Refmac(task_utils.CCPEMTask):
         parser.add_argument(
             '-libg',
             '--libg',
-            help='''Use libg to generate restraints for nucleic acids''',
+            help='''Use LIBG to generate restraints for nucleic acids''',
             metavar='Nucleic acids',
             type=bool,
             default=False)
@@ -173,7 +176,7 @@ class Refmac(task_utils.CCPEMTask):
         parser.add_argument(
             '-validate_on',
             '--validate_on',
-            help='''Perform validation''',
+            help='''Perform check for model overfitting''',
             metavar='Validate',
             type=bool,
             default=False)
@@ -221,7 +224,7 @@ class Refmac(task_utils.CCPEMTask):
         parser.add_argument(
             '-lib_in',
             '--lib_in',
-            help='Library dictionary file for ligands (lib format)',
+            help='Library dictionary file for ligands (lib/cif format)',
             metavar='Ligand dictionary',
             type=str,
             default=None)
@@ -229,7 +232,7 @@ class Refmac(task_utils.CCPEMTask):
         parser.add_argument(
             '-find_in_map',
             '--find_in_map',
-            help='Run Molrep to place model in map',
+            help='Fit starting model into map if necessary (uses Molrep)',
             metavar='Find in map',
             type=bool,
             default=False)
@@ -365,16 +368,23 @@ class Refmac(task_utils.CCPEMTask):
         parser.add_argument(
             '-symmetry_auto',
             '--symmetry_auto',
-            help=('Automatically detect and apply symmetry (recommended)'),
+            help='Automatically detect and apply symmetry (recommended)',
             metavar='Auto symmetry',
-            type=bool,
-            default=True)
+            choices=['None',
+                     'Local',
+                     'Global'
+                     ],
+            type=str,
+            default='Local')
+
         #
         parser.add_argument(
             '-map_sharpen',
             '--map_sharpen',
-            metavar='Map sharpen',
-            help=('Positive B-factor to sharpen, negative to blur'),
+            metavar='Sharpen / blur',
+            help=('B-factor to apply to map. Negative B-factor to '
+                  'sharpen, positive to blur, zero to leave map as '
+                  'input'),
             type=float,
             default=None)
         #
@@ -500,6 +510,10 @@ class Refmac(task_utils.CCPEMTask):
                 else:
                     timeQuant = 60
 
+                if self.args.map_sharpen() is None:
+                    sharp = 0
+                else:
+                    sharp = -1.0*self.args.map_sharpen()
                 self.process_DaC = DivideAndConquer(
                   command=['ccpem-python', '-m', 'ccpem_core.tasks.refmac.dummy_dac'],
                   name='Refine chain by chain',
@@ -511,7 +525,7 @@ class Refmac(task_utils.CCPEMTask):
                   option_timeQuant = timeQuant,
                   weight=self.args.weight.value,
                   weight_auto=self.args.weight_auto.value,
-                  sharp=self.args.map_sharpen.value,
+                  sharp=sharp,
                   set_bfactor=self.args.set_bfactor_on.value,
                   atom_bfactor=self.args.set_bfactor.value,
                   jelly_body_on=self.args.jelly_body.value,
@@ -521,9 +535,8 @@ class Refmac(task_utils.CCPEMTask):
 
                 pl = [[self.process_DaC.process]]
 
-                refmac_custom_finish = RefmacResultsOnFinish(
-                    pipeline_path=self.job_location+'/task.ccpem')
-
+                #XXXX
+                print 'Add results'
                 if run:
                     self.pipeline = process_manager.CCPEMPipeline(
                         pipeline=pl,
@@ -532,10 +545,8 @@ class Refmac(task_utils.CCPEMTask):
                         database_path=self.database_path,
                         taskname=self.task_info.name,
                         title=self.args.job_title.value,
-                        verbose=self.verbose,
-                        on_finish_custom=refmac_custom_finish)
+                        verbose=self.verbose)
                     self.pipeline.start()
-
                 return
 
         # Convert map to mtz
@@ -546,8 +557,8 @@ class Refmac(task_utils.CCPEMTask):
             name='Map to MTZ',
             job_location=self.job_location,
             map_path=self.args.input_map.value,
-            blur_array=None,
-            sharp_array=[self.args.map_sharpen.value],
+            blur_array=[self.args.map_sharpen.value],
+            sharp_array=None,
             atomsf_path=self.atomsf)
         pl = [[self.process_maptomtz.process]]
 
@@ -558,13 +569,20 @@ class Refmac(task_utils.CCPEMTask):
         self.libg_restraints = False
         self.libg_restraints_path = []
         if self.args.libg.value:
-            if len(self.args.libg_selection.value.strip()) > 0:
-                self.process_libg = LibgRestraints(
-                    command=self.commands['libg'],
-                    job_location=self.job_location,
-                    name='DNA or RNA basepair restraints',
-                    pdb_path=self.args.start_pdb.value,
-                    u = self.args.libg_selection.value.strip())
+            if self.args.libg_selection.value:
+                if len(self.args.libg_selection.value.strip()) > 0:
+                    self.process_libg = LibgRestraints(
+                        command=self.commands['libg'],
+                        job_location=self.job_location,
+                        name='DNA or RNA basepair restraints',
+                        pdb_path=self.args.start_pdb.value,
+                        u = self.args.libg_selection.value.strip())
+                else:
+                    self.process_libg = LibgRestraints(
+                        command=self.commands['libg'],
+                        job_location=self.job_location,
+                        name='DNA or RNA basepair restraints',
+                        pdb_path=self.args.start_pdb.value)
             else:
                 self.process_libg = LibgRestraints(
                     command=self.commands['libg'],
@@ -602,7 +620,7 @@ class Refmac(task_utils.CCPEMTask):
             else:
                 self.start_refmac_pdb_path = self.process_pdb_set.pdbout_path
 
-            if self.args.local_refinement_on.value:
+            if self.args.local_refinement_on():
                 # Local refine
                 # Get local structure factors.  N.B. this must come after find in
                 # map
@@ -615,154 +633,107 @@ class Refmac(task_utils.CCPEMTask):
                     lib_path=self.args.lib_in.value,
                     map_path=self.args.input_map.value,
                     pdb_path=self.start_refmac_pdb_path,
-                    blur_array=None,
-                    sharp_array=[self.args.map_sharpen.value],
+                    blur_array=[self.args.map_sharpen.value],
+                    sharp_array=None,
                     atomsf_path=self.atomsf)
                 pl.append([self.process_maptomtz_local.process])
 
-                # Local refinement
-                self.process_refine = RefmacRefine(
-                    command=self.commands['refmac'],
-                    job_location=self.job_location,
-                    pdb_path=self.process_maptomtz_local.pdbout_path,
-                    resolution=self.args.resolution.value,
-                    mode='Local',
-                    name='Refmac refine (local)',
-                    sharp=self.args.map_sharpen.value,
-                    weight=self.args.weight.value,
-                    weight_auto=self.args.weight_auto.value,
-                    symmetry_auto=self.args.symmetry_auto.value,
-                    set_bfactor=self.args.set_bfactor_on.value,
-                    atom_bfactor=self.args.set_bfactor.value,
-                    atomsf_path=self.atomsf,
-                    external_restraints_on=self.args.external_restraints_on.value,
-                    external_restraints_path=self.args.restraints_files(),
-                    external_weight_scale=self.args.external_weight_scales(),
-                    external_weight_gmwt=self.args.external_weight_gmwts(),
-                    external_weight_dmax=self.args.external_weight_dmx.value,
-                    external_main_chain=self.args.external_main_only.value,
-                    jelly_body_on=self.args.jelly_body.value,
-                    hydrogens=self.args.hydrogens.value,
-                    lib_path=self.args.lib_in.value,
-                    ncycle=self.args.ncycle.value,
-                    keywords=self.args.keywords.value,
-                    libg_restraints=self.libg_restraints,
-                    libg_restraints_path=self.libg_restraints_path)
-                pl.append([self.process_refine.process])
-
-                # Shift back structure to original map
-                self.process_shift_back = RefmacShiftBack(
-                    command=self.commands['refmac'],
-                    name='Shift back to map frame',
-                    lib_path=self.args.lib_in.value,
-                    job_location=self.job_location,
-                    pdb_path=self.process_refine.pdbout_path,
-                    atomsf_path=self.atomsf)
-                pl.append([self.process_shift_back.process])
-
+                # Refinement parameters: Local
+                mode = 'Local'
+                name='Refmac refine (local)'
+                pdb_path=self.process_maptomtz_local.pdbout_path
+                mtz_path = 'masked_fs.mtz'
             else:
-                # Global refine
-                self.process_refine = RefmacRefine(
-                    command=self.commands['refmac'],
-                    job_location=self.job_location,
-                    pdb_path=self.start_refmac_pdb_path,
-                    resolution=self.args.resolution.value,
-                    mode='Global',
-                    name='Refmac refine (global)',
-                    weight=self.args.weight.value,
-                    weight_auto=self.args.weight_auto.value,
-                    symmetry_auto=self.args.symmetry_auto.value,
-                    sharp=self.args.map_sharpen.value,
-                    set_bfactor=self.args.set_bfactor_on.value,
-                    atom_bfactor=self.args.set_bfactor.value,
-                    atomsf_path=self.atomsf,
-                    ncycle=self.args.ncycle.value,
-                    external_restraints_on=self.args.external_restraints_on.value,
-                    external_restraints_path=self.args.restraints_files(),
-                    external_weight_scale=self.args.external_weight_scales(),
-                    external_weight_gmwt=self.args.external_weight_gmwts(),
-                    external_weight_dmax=self.args.external_weight_dmx.value,
-                    external_main_chain=self.args.external_main_only.value,
-                    lib_path=self.args.lib_in.value,
-                    jelly_body_on=self.args.jelly_body.value,
-                    hydrogens=self.args.hydrogens.value,
-                    keywords=self.args.keywords.value,
-                    libg_restraints=self.libg_restraints,
-                    libg_restraints_path=self.libg_restraints_path)
+                # Refinement parameters: Local
+                mode = 'Global'
+                name = 'Refmac refine (global)'
+                pdb_path = self.start_refmac_pdb_path
+                mtz_path = 'starting_map.mtz'
 
+            #  Refine
+            # Invert sharpening value for refmac
+            if self.args.map_sharpen() is None:
+                sharp = 0
+            else:
+                sharp = -1.0*self.args.map_sharpen()
+            self.process_refine = RefmacRefine(
+                command=self.commands['refmac'],
+                job_location=self.job_location,
+                pdb_path=pdb_path,
+                resolution=self.args.resolution.value,
+                mtz_path=mtz_path,
+                mode=mode,
+                name=name,
+                weight=self.args.weight.value,
+                weight_auto=self.args.weight_auto.value,
+                symmetry_auto=self.args.symmetry_auto.value,
+                sharp=sharp,
+                set_bfactor=self.args.set_bfactor_on.value,
+                atom_bfactor=self.args.set_bfactor.value,
+                atomsf_path=self.atomsf,
+                ncycle=self.args.ncycle.value,
+                external_restraints_on=self.args.external_restraints_on.value,
+                external_restraints_path=self.args.restraints_files(),
+                external_weight_scale=self.args.external_weight_scales(),
+                external_weight_gmwt=self.args.external_weight_gmwts(),
+                external_weight_dmax=self.args.external_weight_dmx.value,
+                external_main_chain=self.args.external_main_only.value,
+                lib_path=self.args.lib_in.value,
+                jelly_body_on=self.args.jelly_body.value,
+                hydrogens=self.args.hydrogens.value,
+                keywords=self.args.keywords.value,
+                libg_restraints=self.libg_restraints,
+                libg_restraints_path=self.libg_restraints_path)
                 #
-                pl.append([self.process_refine.process])
+            pl.append([self.process_refine.process])
 
             # Validation
             if self.args.validate_on.value:
                 # Shake structure
-                if self.args.local_refinement_on.value:
-                    shake_pdb_path = self.process_shift_back.pdbout_path
-                else:
-                    shake_pdb_path = self.process_refine.pdbout_path
-                #
                 self.process_shake = PDBSetShake(
                     name='Shake refined structure',
                     job_location=self.job_location,
-                    pdb_path=shake_pdb_path)
+                    pdb_path=self.process_refine.pdbout_path)
                 pl.append([self.process_shake.process])
 
-                # N.B. no need to shift back coordinates for validation
-                # refinement.
-                if self.args.local_refinement_on.value:
-                    validation_mode = 'Local'
-                else:
-                    validation_mode = 'Global'
                 # Convert half map 1 to mtz; stage
                 self.process_maptomtz_hm1 = RefmacMapToMtz(
                     command=self.commands['refmac'],
                     resolution=self.args.resolution.value,
                     refmap_path = self.args.reference_map.value,
-                    mode=validation_mode,
+                    mode=mode,
                     lib_path=self.args.lib_in.value,
                     name='Map to MTZ (HM1)',
                     job_location=self.job_location,
                     pdb_path=self.process_shake.pdbout_path,
+                    pdbout_path='shifted_local_hm1.pdb',
                     map_path=self.args.half_map_1.value,
                     hklout_path=os.path.join(self.job_location,
                                              'starting_map_hm1.mtz'),
-                    blur_array=None,
-                    sharp_array=[self.args.map_sharpen.value],
+                    blur_array=[self.args.map_sharpen.value],
+                    sharp_array=None,
                     atomsf_path=self.atomsf)
                 pl.append([self.process_maptomtz_hm1.process])
 
                 # Refine shaken structure vs half map 1
-                self.process_refine_hm1 = RefmacRefine(
-                    command=self.commands['refmac'],
-                    job_location=self.job_location,
-                    pdb_path=self.process_shake.pdbout_path,
-                    pdbout_path=os.path.join(self.job_location,
-                                             'refined_hm1.pdb'),
-                    resolution=self.args.resolution.value,
-                    mode=validation_mode,
-                    sharp=self.args.map_sharpen.value,
-                    weight=self.args.weight.value,
-                    weight_auto=self.args.weight_auto.value,
-                    symmetry_auto=self.args.symmetry_auto.value,
-                    set_bfactor=self.args.set_bfactor_on.value,
-                    atom_bfactor=self.args.set_bfactor.value,
-                    name='Refmac refine (HM1)',
-                    mtz_path=self.process_maptomtz_hm1.hklout_path,
-                    atomsf_path=self.atomsf,
-                    ncycle=self.args.ncycle.value,
-                    external_restraints_on=self.args.external_restraints_on.value,
-                    external_restraints_path=self.args.restraints_files(),
-                    external_weight_scale=self.args.external_weight_scales(),
-                    external_weight_gmwt=self.args.external_weight_gmwts(),
-                    external_weight_dmax=self.args.external_weight_dmx.value,
-                    external_main_chain=self.args.external_main_only.value,
-                    lib_path=self.args.lib_in.value,
-                    jelly_body_on=False,
-                    hydrogens=self.args.hydrogens.value,
-                    keywords=self.args.keywords.value,
-                    libg_restraints=self.libg_restraints,
-                    libg_restraints_path=self.libg_restraints_path)
+                self.process_refine_hm1 = copy.deepcopy(
+                    self.process_refine)
 
+                if self.args.local_refinement_on():
+                    self.process_refine_hm1.pdb_path = \
+                        self.process_maptomtz_hm1.pdbout_path
+                    self.process_refine_hm1.mtz_path = 'masked_fs.mtz'
+                else:
+                    self.process_refine_hm1.pdb_path = \
+                        self.process_shake.pdbout_path
+                    self.process_refine_hm1.mtz_path = \
+                        self.process_maptomtz_hm1.hklout_path
+
+                self.process_refine_hm1.pdbout_path = os.path.join(
+                    self.job_location,
+                    'refined_hm1.pdb')
+                self.process_refine_hm1.name = 'Refmac refine (HM1)'
+                self.process_refine_hm1.set_process()
                 pl.append([self.process_refine_hm1.process])
 
                 # Convert half map 2 to mtz
@@ -771,36 +742,44 @@ class Refmac(task_utils.CCPEMTask):
                     resolution=self.args.resolution.value,
                     refmap_path = self.args.reference_map.value,
                     lib_path=self.args.lib_in.value,
-                    mode=validation_mode,
+                    mode=mode,
                     name='Map to MTZ (HM2)',
                     job_location=self.job_location,
                     map_path=self.args.half_map_2.value,
-                    pdb_path=self.process_shake.pdbout_path,
+                    pdb_path=self.process_refine_hm1.pdbout_path,
+                    pdbout_path='shifted_local_hm2.pdb',
                     hklout_path=os.path.join(self.job_location,
                                              'starting_map_hm2.mtz'),
-                    blur_array=None,
-                    sharp_array=[self.args.map_sharpen.value],
+                    blur_array=[self.args.map_sharpen.value],
+                    sharp_array=None,
                     atomsf_path=self.atomsf)
                 pl.append([self.process_maptomtz_hm2.process])
 
-                # Calculate FSC of model refined against half map 1 vs half map 2
-                self.process_fsc_hm2 = RefmacRefine(
-                    command=self.commands['refmac'],
-                    job_location=self.job_location,
-                    pdb_path=self.process_refine_hm1.pdbout_path,
-                    pdbout_path=os.path.join(self.job_location,
-                                             'fsc_hm2.pdb'),
-                    resolution=self.args.resolution.value,
-                    lib_path=self.args.lib_in.value,
-                    mode=validation_mode,
-                    name='Refmac stats (HM2)',
-                    sharp=self.args.map_sharpen.value,
-                    mtz_path=self.process_maptomtz_hm2.hklout_path,
-                    atomsf_path=self.atomsf,
-                    ncycle=1,
-                    keywords=self.args.keywords.value,
-                    libg_restraints=self.libg_restraints,
-                    libg_restraints_path=self.libg_restraints_path)
+                # Calculate FSC of model refined against half map 1 
+                # vs half map 2
+                self.process_fsc_hm2 = copy.deepcopy(
+                    self.process_refine_hm1)
+
+                # Set to 0 cycles to only calculate stats and do not reset
+                # bfactors
+                self.process_fsc_hm2.ncycle=0
+                self.process_fsc_hm2.set_bfactor=False
+
+                if self.args.local_refinement_on():
+                    self.process_fsc_hm2.pdb_path = \
+                        self.process_maptomtz_hm2.pdbout_path
+                    self.process_fsc_hm2.mtz_path = 'masked_fs.mtz'
+                else:
+                    self.process_fsc_hm2.pdb_path = \
+                        self.process_refine_hm1.pdbout_path
+                    self.process_fsc_hm2.mtz_path = \
+                        self.process_maptomtz_hm2.hklout_path
+
+                self.process_fsc_hm2.pdbout_path = os.path.join(
+                    self.job_location,
+                    'refined_hm2.pdb')
+                self.process_fsc_hm2.name = 'Refmac stats (HM2)'
+                self.process_fsc_hm2.set_process()
                 pl.append([self.process_fsc_hm2.process])
 
                 # Calculate FSC of two half maps
@@ -810,15 +789,19 @@ class Refmac(task_utils.CCPEMTask):
                     job_location=self.job_location,
                     map1_path=self.args.half_map_1.value,
                     map2_path=self.args.half_map_2.value,
-# Uncomment once REFMAC5 is updated, otherwise it will die
                     resolution=self.args.resolution.value,
                     refmap_path=self.args.reference_map.value,
                     atomsf_path=self.atomsf)
                 pl.append([self.process_fsc_hm1_vs_hm2.process])
 
         # Generate results
-        refmac_custom_finish = RefmacResultsOnFinish(
-            pipeline_path=self.job_location+'/task.ccpem')
+        refmac_results_path = os.path.realpath(refmac_results.__file__)
+        refmac_results_process = process_manager.CCPEMProcess(
+            name='Refmac results',
+            command='ccpem-python',
+            args=[refmac_results_path, self.job_location, mode],
+            location=self.job_location)
+        pl.append([refmac_results_process])
 
         if run:
             self.pipeline = process_manager.CCPEMPipeline(
@@ -830,24 +813,10 @@ class Refmac(task_utils.CCPEMTask):
                 db_inject=db_inject,
                 taskname=self.task_info.name,
                 title=self.args.job_title.value,
-                verbose=self.verbose,
-                on_finish_custom=refmac_custom_finish)
+                verbose=self.verbose)
             self.pipeline.start()
 
 
-class RefmacResultsOnFinish(process_manager.CCPEMPipelineCustomFinish):
-    '''
-    Generate RVAPI results on finish.
-    '''
-    def __init__(self,
-                 pipeline_path):
-        super(RefmacResultsOnFinish, self).__init__()
-        self.pipeline_path = pipeline_path
-
-    def on_finish(self, parent_pipeline=None):
-        refmac_results.RefmacResultsViewer(
-            pipeline_path=self.pipeline_path)
-
 class PDBSetCell(object):
     '''
     Set input PDB cell and scale cards to input map.
@@ -862,7 +831,7 @@ class PDBSetCell(object):
         self.pdb_path = ccpem_utils.get_path_abs(pdb_path)
         self.map_path = ccpem_utils.get_path_abs(map_path)
         self.pdbout_path = os.path.join(self.job_location,
-                                             'pdbset.pdb')
+                                        'pdbset.pdb')
         self.cell_info = None
         self.stdin = None
         #
@@ -881,13 +850,13 @@ class PDBSetCell(object):
 
     def get_cell_parameters(self):
         if os.path.exists(path=self.map_path):
-            map_header = numpy_mrc_io.read_mrc(self.map_path, header_only=True)
-            self.cell_info = [map_header['xlen'],
-                              map_header['ylen'],
-                              map_header['zlen'],
-                              map_header['alpha'],
-                              map_header['beta'],
-                              map_header['gamma']]
+            with mrcfile.open(self.map_path, header_only=True) as map:
+                self.cell_info = [map.header.cella.x,
+                                  map.header.cella.y,
+                                  map.header.cella.z,
+                                  map.header.cellb.alpha,
+                                  map.header.cellb.beta,
+                                  map.header.cellb.gamma]
 
     def set_args(self):
         self.args = ['xyzin', self.pdb_path]
@@ -966,6 +935,7 @@ class RefmacMapToMtz(object):
                  mode='Global',
                  name=None,
                  pdb_path=None,
+                 pdbout_path='shifted_local.pdb',
                  lib_path=None,
                  refmap_path=None,
                  hklout_path=None,
@@ -988,6 +958,9 @@ class RefmacMapToMtz(object):
         self.pdb_path = pdb_path
         if self.mode == 'Local':
             assert self.pdb_path is not None
+        self.pdbout_path = os.path.join(
+            self.job_location,
+            pdbout_path)
         self.mrad = mrad
         self.atomsf_path = atomsf_path
         self.blur_array = blur_array
@@ -997,8 +970,6 @@ class RefmacMapToMtz(object):
 #         if self.sharp_array == [0.0]:
 #             self.sharp_array = None
         self.stdin = None
-        self.pdbout_path = os.path.join(self.job_location,
-                                        'shifted_local.pdb')
         self.hklout_path = hklout_path
         if self.hklout_path is None:
             self.hklout_path = os.path.join(self.job_location,
@@ -1135,9 +1106,9 @@ class RefmacRefine(object):
                  job_location,
                  pdb_path,
                  resolution,
+                 mtz_path,
                  mode='Global',
-                 mtz_path=None,
-                 pdbout_path=None,
+                 pdbout_path='refined.pdb',
                  name=None,
                  atomsf_path=None,
                  sharp=None,
@@ -1158,7 +1129,7 @@ class RefmacRefine(object):
                  vector_diff_map=False,
                  weight=0.0001,
                  weight_auto=True,
-                 symmetry_auto=True,
+                 symmetry_auto='Local',
                  keywords=None,
                  libg_restraints=False,
                  libg_restraints_path=None,
@@ -1170,19 +1141,8 @@ class RefmacRefine(object):
         self.mode = mode
         assert self.mode in self.modes
         self.mtz_path = mtz_path
-        if self.mtz_path is None:
-            if self.mode == 'Global':
-                self.mtz_path = 'starting_map.mtz'
-            else:
-                self.mtz_path = 'masked_fs.mtz'
-        self.pdbout_path = pdbout_path
-        if self.pdbout_path is None:
-            if self.mode == 'Global':
-                pdb_out = 'refined.pdb'
-            else:
-                pdb_out = 'refined_shifted.pdb'
-            self.pdbout_path = os.path.join(self.job_location,
-                                            pdb_out)
+        self.pdbout_path = os.path.join(self.job_location,
+                                        pdbout_path)
         self.name = name
         if self.name is None:
             self.name = self.__class__.__name__ + self.mode
@@ -1221,9 +1181,11 @@ class RefmacRefine(object):
         self.libg_restraints_path=libg_restraints_path
         self.output_hkl = output_hkl
         #
+        self.set_process()
+
+    def set_process(self):
         self.set_args()
         self.set_stdin()
-        #
         self.process = process_manager.CCPEMProcess(
             name=self.name,
             command=self.command,
@@ -1246,6 +1208,8 @@ class RefmacRefine(object):
 
     def set_stdin(self):
         self.stdin = 'labin FP=Fout0 PHIB=Pout0'
+        if self.mode == 'Local':
+            self.stdin += '\n@shifts.txt'
         if self.hydrogens:
             self.stdin += '\nmake hydr all'
             self.stdin += '\nhout no' # do NOT write hydrogens out
@@ -1266,7 +1230,9 @@ class RefmacRefine(object):
         else:
             if self.weight is not None:
                 self.stdin += '\nweight matrix {0}'.format(self.weight)
-        if self.symmetry_auto:
+        if self.symmetry_auto == 'Local':
+            self.stdin += '\nncsr local'
+        elif self.symmetry_auto == 'Global':
             self.stdin += '\nncsr global'
         if self.set_bfactor and self.atom_bfactor is not None:
             self.stdin += '\nBFACtor SET {0}'.format(self.atom_bfactor)
@@ -1348,65 +1314,6 @@ class RefmacSfcalcCrd(object):
         self.stdin += '\nend'
 
 
-class RefmacShiftBack(object):
-    '''
-    Refmac process to shift back coordinates after local refinement
-    '''
-    def __init__(self,
-                 command,
-                 job_location,
-                 pdb_path,
-                 mtz_path=None,
-                 lib_path=None,
-                 pdbout_path=None,
-                 name=None,
-                 atomsf_path=None):
-        self.command = command
-        self.job_location = job_location
-        self.pdb_path = pdb_path
-        self.lib_path = lib_path
-        self.pdbout_path = pdbout_path
-        self.mtz_path = mtz_path
-        if self.mtz_path is None:
-            self.mtz_path = os.path.join(self.job_location,
-                                         'masked_fs.mtz')
-        self.atomsf_path = atomsf_path
-        self.name = name
-        if self.name is None:
-            self.name = self.__class__.__name__
-        self.stdin = None
-        #
-        self.set_args()
-        self.set_stdin()
-        #
-        self.process = process_manager.CCPEMProcess(
-            name=self.name,
-            command=self.command,
-            args=self.args,
-            location=self.job_location,
-            stdin=self.stdin)
-
-    def set_args(self):
-        self.args = ['xyzin', self.pdb_path]
-        self.args += ['hklin', self.mtz_path]
-        if self.lib_path is not None:
-            self.args += ['libin', self.lib_path]
-        if self.pdbout_path is None:
-            self.pdbout_path = os.path.join(self.job_location,
-                                            'refined.pdb')
-        self.args += ['xyzout', self.pdbout_path]
-        if self.atomsf_path is not None:
-            self.atomsf_path = ccpem_utils.get_path_abs(self.atomsf_path)
-            self.args += ['atomsf', self.atomsf_path]
-
-    def set_stdin(self):
-        self.stdin = 'labin FP=Fout0 PHIB=Pout0'
-        self.stdin += '\n@shifts.txt'
-        self.stdin += '\n' + refmac_source
-        self.stdin += '\nncycle 0'
-        self.stdin += '\nend'
-
-
 class PDBSetShake(object):
     '''
     PDBSet process to shake structure for cross validation.
@@ -1535,7 +1442,7 @@ class DivideAndConquer(object):
 
         self.lib_in = lib_in
         self.sharp = sharp
-        self.weight  = weight
+        self.weight = weight
         self.weight_auto = weight_auto
         self.set_bfactor  = set_bfactor
         self.atom_bfactor = atom_bfactor
