@@ -13,41 +13,41 @@ from ccpem_core.ccpem_utils import ccpem_argparser
 from ccpem_core import ccpem_utils
 from ccpem_core import process_manager
 from ccpem_core.tasks import task_utils
-from ccpem_core.map_tools.TEMPy import difference_map
+from ccpem_core.tasks.tempy.difference_map import difference_map
 
 
 class DifferenceMap(task_utils.CCPEMTask):
     '''
-    CCPEM / TEMPy difference map wrapper.
+    CCPEM TEMPy difference map wrapper.
     '''
     task_info = task_utils.CCPEMTaskInfo(
         name='TEMPyDifferenceMap',
         author='A. Joseph, M. Topf, M. Winn',
         version='1.1',
         description=(
-            '''Difference map calculation using TEMPy library.The maps
+            '''Difference map calculation using TEMPy and LocScale libraries.The maps
             are matched by amplitude scaling in resolution shells before 
             calculating difference.<br><br>
             Input two maps or a map and an atomic model.<br>
             - The maps have to be aligned before using as input 
             for this task. If an atomic model is provided, 
             it has to be fitted in the experimental map.<br><br>
-            - Map contours are used to mask the output differences.\
-            The contour thresholds are optional (1.5 sigma by default).
-            Switch contour_mask to False to disable masking the 
-            difference.<br>
-            - A dust filter is applied on the difference maps by default.
+            - Local or Global mode can be used for scaling. For local mode,
+            scaling in done in local sliding windows and hence local resolution
+             variations are considered for scaling. Local mode has MPI option 
+             for faster run.
+            - A fractional difference map is calculated by default (difference/initial).
+            This can be disabled. A difference fraction threshold can be used to 
+            mask the difference map as well.
+            - Optionally, a dust filter can be applied on the difference maps.
             This is done to remove small isolated densities that usually 
-            correspond to noise in the differences. The dust filter can 
-            be switched off in the advanced options.<br>
-            To get the unfiltered difference maps, disable both 
-            contour_mask and dust_filter.<br>
-            - The shell width (1/Angstrom) is calculated by default 
-            based on voxel size. It can be edited in the advanced options.
+            correspond to noise in the differences. A fractional difference threshold 
+            is used to mask first before dusting. The threshold can be set.<br>
+            <br>
             '''),
         short_description=(
             'Difference map calculation'),
-        documentation_link='http://topf-group.ismb.lon.ac.uk/TEMPY.html',
+        documentation_link='',
         references=None)
 
     commands = {'ccpem-python':
@@ -130,32 +130,6 @@ class DifferenceMap(task_utils.CCPEMTask):
         return parser
         
     def add_diffmap_specific_arguments(self,parser):
-        contour_mask = parser.add_argument_group()
-        contour_mask.add_argument(
-            '-contour_mask',
-            '--contour_mask',
-            help='''Apply contour mask to difference''',
-            metavar='Contour mask',
-            type=bool,
-            default=True)
-        #
-        map_contour_1 = parser.add_argument_group()
-        map_contour_1.add_argument(
-            '-map_contour_1',
-            '--map_contour_1',
-            help='''Contour level of map 1 (optional)''',
-            metavar='Contour map 1',
-            type=float,
-            default=None)
-        #
-        map_contour_2 = parser.add_argument_group()
-        map_contour_2.add_argument(
-            '-map_contour_2',
-            '--map_contour_2',
-            help='''Contour level of map 2 (optional)''',
-            metavar='Contour map 2',
-            type=float,
-            default=None)
         #
         pdb_path = parser.add_argument_group()
         pdb_path.add_argument(
@@ -173,16 +147,69 @@ class DifferenceMap(task_utils.CCPEMTask):
             '--map_or_pdb_selection',
             help=('Select map or PDB'),
             metavar='Input selection',
-            choices=['Map', 'PDB'],
+            choices=['Map', 'Model'],
             type=str,
             default='Map')
+        #local or global
+        mode_selection = parser.add_argument_group()
+        mode_selection.add_argument(
+            '-mode_selection',
+            '--mode_selection',
+            help=('Select local or global scaling mode'),
+            metavar='Mode selection',
+            choices=['global', 'local','None'],
+            type=str,
+            default='global')
+        parser.add_argument(
+            '-noscale',
+            '--noscale',
+            help=('Do not scale for difference'),
+            metavar='Scale the maps?',
+            type=bool,
+            default=False)
+        parser.add_argument(
+            '-use_mpi',
+            '--use_mpi',
+            help=('Use MPI for local scaling'),
+            metavar='Use MPI?',
+            type=bool,
+            default=False)
+        parser.add_argument(
+            '-n_mpi',
+            '--n_mpi',
+            help=('Use n proc for mpi'),
+            metavar='Use n proc',
+            type=int,
+            default=1)
+        parser.add_argument(
+            '-maskfile',
+            '--maskfile',
+            help=('Input mask map. Local scaling is calculated within this mask'),
+            metavar='Input mask map',
+            type=str,
+            default=None)
+        parser.add_argument(
+            '-w',
+            '--window_size',
+            help=('Window size for local scaling (default 7*resolution)'),
+            metavar='Window size',
+            type=int,
+            default=None)
         #
-        shell_width = parser.add_argument_group()
-        shell_width.add_argument(
-            '-shell_width',
-            '--shell_width',
-            help='''Shell width for map scaling (1/Angstrom) (optional)''',
-            metavar='Shell width',
+        parser.add_argument(
+            '-refscale',
+            '--refscale',
+            help='''Use second map as reference for scaling''',
+            metavar='Use map2 as reference?',
+            type=bool,
+            default=False)
+        #
+        parser.add_argument(
+            '-threshold_fraction',
+            '--threshold_fraction',
+            help='''Threshold difference map by fractional difference (difference/initial).'''
+                    ''' Set this for dusting (0.35 by default for dusting)''',
+            metavar='Cutoff: fractional difference',
             type=float,
             default=None)
         #
@@ -190,9 +217,28 @@ class DifferenceMap(task_utils.CCPEMTask):
         dust_filter.add_argument(
             '-dust_filter',
             '--dust_filter',
-            help='''Remove dust noise''',
+            help='''Remove dust beyond a threshold of fractional difference (default: 0.35)''',
             metavar='Dust filter',
             type=bool,
+            default=False)
+        #
+        dust_filter.add_argument(
+            '-dustprob',
+            '--dustprob',
+            help='''Probability of dust size (sizes divided in 20 bins) greather than?'''
+                ''' Dusts (small sized densities) are usually more probable than useful differences''',
+            metavar='Dust size probability',
+            type=float,
+            default=0.1
+            )
+        #
+        frac_map = parser.add_argument_group()
+        frac_map.add_argument(
+            '-save_fracmap',
+            '--save_fracmap',
+            help='''Calculate fractional difference maps''',
+            metavar='Calc fractional difference',
+            type=bool,
             default=True)
         #
         map_alignment = parser.add_argument_group()
@@ -216,21 +262,30 @@ class DifferenceMap(task_utils.CCPEMTask):
         #
 
     def run_pipeline(self, job_id=None, db_inject=None):
+        if self.args.map_or_pdb_selection.value == "Model":
+            if self.args.pdb_path.value != None:
+                self.args.map_path_2.value = None
+        
         # Generate process
         self.tempy_difference_map = TEMPyDifferenceMap(
             job_location=self.job_location,
             command=self.commands['ccpem-python'],
             map_path_1=self.args.map_path_1.value,
+            map_or_pdb=self.args.map_or_pdb_selection.value,
             map_path_2=self.args.map_path_2.value,
             map_resolution_1=self.args.map_resolution_1.value,
             map_resolution_2=self.args.map_resolution_2.value,
-            map_contour_1=self.args.map_contour_1.value,
-            map_contour_2=self.args.map_contour_2.value,
-            pdb_path=self.args.pdb_path.value,
-            map_or_pdb=self.args.map_or_pdb_selection.value,
-            shell_width=self.args.shell_width.value,
+            pdb_path = self.args.pdb_path.value,
+            mode=self.args.mode_selection.value,
+            noscale=self.args.noscale.value,
+            maskfile=self.args.maskfile.value,
+            mpi=self.args.use_mpi.value,
+            window_size=self.args.window_size.value,
+            threshold_fraction=self.args.threshold_fraction.value,
             dust_filter=self.args.dust_filter.value,
-            contour_mask=self.args.contour_mask.value)
+            fracmap=self.args.save_fracmap.value,
+            dust_prob = self.args.dustprob.value,
+            ref_scale = self.args.refscale.value)
             #map_alignment=self.args.map_alignment.value)
             #soft_mask=self.args.soft_mask.value)
 
@@ -256,18 +311,26 @@ class TEMPyDifferenceMap(object):
                  command,
                  map_path_1,
                  map_resolution_1,
-                 map_contour_1=None,
                  map_path_2=None,
                  map_resolution_2=None,
-                 map_contour_2=None,
                  pdb_path=None,
                  map_or_pdb='Map',
-                 shell_width=None,
-                 dust_filter=True,
-                 contour_mask=True,
+                 mode='global',
+                 noscale=False,
+                 maskfile=None,
+                 mpi=False,
+                 window_size=None,
+                 threshold_fraction=None,
+                 dust_filter=False,
+                 fracmap=True,
+                 contour_mask=False,
                  map_alignment=False,
-                 soft_mask=False,
+                 map_contour_1=None,
+                 map_contour_2=None,
+                 dust_prob=None,
+                 ref_scale = False,
                  name=None):
+        
         assert [pdb_path, map_path_2].count(None) != 2
         self.job_location = ccpem_utils.get_path_abs(job_location)
         self.name = name
@@ -278,33 +341,31 @@ class TEMPyDifferenceMap(object):
         self.args = ['-m1', self.map_path_1,
                      '-r1', map_resolution_1]
         # Difference map 1 vs map 2 or PDB
-        if map_or_pdb == 'PDB':
+        if map_or_pdb == 'Model':
             self.pdb_path = ccpem_utils.get_path_abs(pdb_path)
             self.args += ['-p', self.pdb_path]
         else:
             self.map_path_2 = ccpem_utils.get_path_abs(map_path_2)
             self.args += ['-m2', self.map_path_2]
             self.args += ['-r2', map_resolution_2]
+        #scaling mode
+        if mode in ['global','local']:
+            self.args += ['-mode',mode]
+        if noscale:
+            self.args += ['--noscale']
+        if ref_scale:
+            self.args += ['--refscale']
         #
-        if map_contour_1 == 0:
-            map_contour_1 = None
-        if map_contour_2 == 0:
-            map_contour_2 = None
-        #
-        if map_contour_1 is not None:
-            self.args += ['-t1', map_contour_1]
-        if map_contour_2 is not None:
-            self.args += ['-t2', map_contour_2]
-        #
-        if not contour_mask:
-            self.args += ['-nomask']
-        if not dust_filter:
-            self.args += ['-nodust']
-        if shell_width is not None:
-            self.args += ['-sw', shell_width]
-        if soft_mask:
-            self.args += ['-smask']
-
+        if dust_filter:
+            self.args += ['-dust']
+        if not fracmap:
+            self.args += ['--nofracmap']
+        if threshold_fraction is not None:
+            self.args += ['-tf',threshold_fraction]
+        if window_size is not None:
+            self.args += ['-w',window_size]
+        if dust_prob is not None:
+            self.args += ['-dp',dust_prob]
 #         XXX TODO: Agnel to write code for alignment, may take some time!
 #         if map_alignment:
 #             self.args += ['-XXX', '???']
