@@ -14,22 +14,26 @@ CCP-EM main window.
 
 import sys
 import os
+import traceback
+
 from PyQt4 import QtGui
 from PyQt4 import QtCore
+
 import ccpem_core
-from ccpem_gui.tasks import ccpem_tasks
-from ccpem_gui import icons
-from ccpem_gui.project_database import sqlite_project_database
-from ccpem_gui.project_database import database_widget
+from ccpem_core import ccpem_utils
+from ccpem_core import process_manager
 from ccpem_core import settings
-from ccpem_gui.project_database import project_widget
-from ccpem_gui.project_database import project_manager
-from ccpem_gui.utils import ccpem_widgets
+from ccpem_gui import icons
 from ccpem_gui.image_viewer import gallery_viewer
 from ccpem_gui.image_viewer import mrc_edit_window
-from ccpem_core import process_manager
+from ccpem_gui.project_database import sqlite_project_database
+from ccpem_gui.project_database import database_widget
+from ccpem_gui.project_database import project_widget
+from ccpem_gui.project_database import project_manager
+from ccpem_gui.tasks import ccpem_tasks
+from ccpem_gui.utils import gui_process
+from ccpem_gui.utils import ccpem_widgets
 from ccpem_gui.utils import window_utils
-from ccpem_core import ccpem_utils
 
 # Import modeller if available
 try:
@@ -38,6 +42,7 @@ try:
 except ImportError:
     modeller_available = False
 
+
 class CCPEMProjectWindow(QtGui.QMainWindow):
     '''
     Window to show job view and project manager
@@ -114,7 +119,7 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         self.version = ccpem_utils.CCPEMVersion()
 
         # Get tasks
-        self.tasks = ccpem_tasks.CCPEMTasks(verbose=False)
+        self.tasks = ccpem_tasks.CCPEMTasks()
 
         # Set main layout
         widget = QtGui.QWidget()
@@ -182,7 +187,6 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         msg.setWindowTitle('CCP-EM task warning')
         errors = 'Task errors:'
         for key, value in self.tasks.errors.iteritems():
-            print key
             print str(value)
             errors += '\n{0} : {1}'.format(key, value)
         msg.setInformativeText(errors)
@@ -258,8 +262,12 @@ class CCPEMMainWindow(QtGui.QMainWindow):
             self.database_path = os.path.join(
                 self.ccpem_projects.get_active_project().path,
                 sqlite_project_database.CCPEMDatabase.ccpem_db_filename)
-            self.database = sqlite_project_database.CCPEMDatabase(
-                database_path=self.database_path)
+            try:
+                self.database = sqlite_project_database.CCPEMDatabase(
+                    database_path=self.database_path)
+            except Exception:
+                print "Error opening project database file " + self.database_path
+                traceback.print_exc()
         else:
             self.database_path = None
             self.database = None
@@ -273,13 +281,32 @@ class CCPEMMainWindow(QtGui.QMainWindow):
             if self.ccpem_projects.get_active_project_path() is not None:
                 os.chdir(self.ccpem_projects.get_active_project_path())
 
-    def set_task_button_disabled(self, button, message=None):
-        button.setDisabled(True)
-        if message is None:
-            message = (
-                'task unavailable. Click info button below for more '
-                'details')
-        button.setToolTip('Error: ' + message)
+    def add_button(self, name, tooltip, callback):
+        '''Convenience function for adding a button to the task layout.'''
+        button = QtGui.QPushButton(name, self)
+        self.task_buttons_layout.addWidget(button)
+        button.setToolTip(tooltip)
+        button.clicked.connect(callback)
+        return button
+
+    def add_task_button(self, name, task_wrapper):
+        '''Convenience function for adding a task button.
+
+        The task's short_info is used as the tooltip. If task_wrapper is None,
+        the button is created in a disabled state.'''
+        if task_wrapper is not None:
+            def open_task_window():
+                self.open_new_task_window(task_wrapper)
+
+            button = self.add_button(name,
+                                     task_wrapper.task.task_info.short_description,
+                                     open_task_window)
+        else:
+            button = QtGui.QPushButton(name, self)
+            self.task_buttons_layout.addWidget(button)
+            button.setToolTip('Error: task unavailable. See "About" below for more details.')
+            button.setDisabled(True)
+        return button
 
     def set_task_buttons(self):
         '''
@@ -305,274 +332,60 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         self.task_buttons_layout.addWidget(ccpem_widgets.CCPEMMenuSeparator())
 
         # Tasks
-        # Buccaneer
-        self.button_run_buccaneer = QtGui.QPushButton(
-            'Buccaneer',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_buccaneer)
-        if self.tasks.buccaneer is not None:
-            self.button_run_buccaneer.setToolTip(
-                self.tasks.buccaneer.task.task_info.short_description)
-            self.button_run_buccaneer.clicked.connect(self.handle_run_buccaneer)
-        else:
-            self.set_task_button_disabled(self.button_run_buccaneer)
+        self.add_task_button('Buccaneer', self.tasks.buccaneer)
+        self.add_task_button('Choyce', self.tasks.choyce)
+        self.add_task_button('Confidence Maps', self.tasks.confidence_maps)
+        self.add_button('Coot', 'Open Coot in the project directory', lambda: gui_process.run_coot(None))
+        self.add_task_button('DockEM', self.tasks.dock_em)
+        self.add_task_button('Flex-EM', self.tasks.flex_em)
+        self.add_task_button('LAFTER', self.tasks.lafter)
+        self.add_task_button('LocScale', self.tasks.loc_scale)
+        self.add_task_button('Map Process', self.tasks.map_process)
+        self.add_task_button('Molrep', self.tasks.molrep)
+        self.add_task_button('Model tools', self.tasks.model_tools)
+        self.add_task_button('MRC to MTZ', self.tasks.mrc_to_mtz)
+        self.add_task_button('MRC-Allspace', self.tasks.mrcallspacea)
+        self.add_task_button('MRC-Tif', self.tasks.mrc2tif)
+        self.add_task_button('Nautilus', self.tasks.nautilus)
+        self.add_task_button('ProSHADE', self.tasks.proshade)
+        self.add_task_button('ProSMART', self.tasks.prosmart)
+        self.add_task_button('Refmac5', self.tasks.refmac)
+        self.add_button('RELION', 'Open RELION in a chosen project directory', self.handle_run_relion)
+        self.add_task_button('Ribfind', self.tasks.ribfind)
+        self.add_task_button('Shake', self.tasks.shake)
+        self.add_task_button('SymmetryExpand', self.tasks.sym_expand)
+        self.add_task_button('TEMPy: DiffMap', self.tasks.tempy_diff_map)
+        self.add_task_button('TEMPy: Local score', self.tasks.tempy_smoc)
+        self.add_task_button('TEMPy: Scores', self.tasks.tempy_scores)
+        self.add_task_button('Validation: model', self.tasks.model_validation)
 
-        # Choyce
-        self.button_run_choyce = QtGui.QPushButton(
-            'Choyce',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_choyce)
-        if self.tasks.choyce is not None:
-            self.button_run_choyce.setToolTip(
-                self.tasks.choyce.task.task_info.short_description)
-            self.button_run_choyce.clicked.connect(self.handle_run_choyce)
-        else:
-            self.set_task_button_disabled(self.button_run_choyce)
-
-        # DockEM
-        self.button_run_dock_em = QtGui.QPushButton(
-            'DockEM',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_dock_em)
-        if self.tasks.dock_em is not None:
-            self.button_run_dock_em.setToolTip(
-                self.tasks.dock_em.task.task_info.short_description)
-            self.button_run_dock_em.clicked.connect(
-                self.handle_run_dock_em)
-        else:
-            self.button_run_dock_em.setDisabled(True)
-            self.button_run_dock_em.setToolTip('Error not available')
-
-        # Flex-EM
-        self.button_run_flexem = QtGui.QPushButton(
-            'Flex-EM',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_flexem)
-        if self.tasks.flex_em is not None:
-            self.button_run_flexem.setToolTip(
-                self.tasks.flex_em.task.task_info.short_description)
-            self.button_run_flexem.clicked.connect(self.handle_run_flexem)
-        else:
-            self.set_task_button_disabled(self.button_run_flexem)
-
-        # LocScale
-        self.button_run_loc_scale = QtGui.QPushButton(
-            'LocScale',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_loc_scale)
-        if self.tasks.loc_scale is not None:
-            self.button_run_loc_scale.setToolTip(
-                self.tasks.loc_scale.task.task_info.short_description)
-            self.button_run_loc_scale.clicked.connect(
-                self.handle_run_loc_scale)
-        else:
-            self.set_task_button_disabled(self.button_run_loc_scale)
-
-        # Molrep
-        self.button_run_molrep = QtGui.QPushButton(
-            'Molrep',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_molrep)
-        if self.tasks.molrep is not None:
-            self.button_run_molrep.setToolTip(
-                self.tasks.molrep.task.task_info.short_description)
-            self.button_run_molrep.clicked.connect(self.handle_run_molrep)
-        else:
-            self.set_task_button_disabled(self.button_run_molrep)
-
-        # MRC to MTZ
-        self.button_run_refmac_sb = QtGui.QPushButton(
-            'MRC to MTZ',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_refmac_sb)
-        if self.tasks.mrc_to_mtz is not None:
-            self.button_run_refmac_sb.setToolTip(
-                self.tasks.mrc_to_mtz.task.task_info.short_description)
-            self.button_run_refmac_sb.clicked.connect(self.handle_run_refmac_sb)
-        else:
-            self.set_task_button_disabled(self.button_run_refmac_sb)
-
-        # MRC Allspace
-        self.button_mrc_mrc_allspacea = QtGui.QPushButton(
-            'MRC-Allspace',
-            self)
-        self.task_buttons_layout.addWidget(self.button_mrc_mrc_allspacea)
-        if self.tasks.mrcallspacea is not None:
-            self.button_mrc_mrc_allspacea.setToolTip(
-                self.tasks.mrcallspacea.task.task_info.short_description)
-            self.button_mrc_mrc_allspacea.clicked.connect(
-                self.handle_run_mrc_allspacea)
-            self.task_buttons_layout.addWidget(self.button_mrc_mrc_allspacea)
-        else:
-            self.set_task_button_disabled(self.button_mrc_mrc_allspacea)
-
-        # MRC to tif
-        self.button_mrc_mrc2tif = QtGui.QPushButton(
-            'MRC-Tif',
-            self)
-        self.task_buttons_layout.addWidget(self.button_mrc_mrc2tif)
-        if self.tasks.mrc2tif is not None:
-            self.button_mrc_mrc2tif.setToolTip(
-                self.tasks.mrc2tif.task.task_info.short_description)
-            self.button_mrc_mrc2tif.clicked.connect(
-                self.handle_run_mrc_mrc2tif)
-        else:
-            self.set_task_button_disabled(self.button_mrc_mrc2tif)
-
-        # Nautilus
-        self.button_run_nautilus = QtGui.QPushButton(
-            'Nautilus',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_nautilus)
-        if self.tasks.nautilus is not None:
-            self.button_run_nautilus.setToolTip(
-                self.tasks.nautilus.task.task_info.short_description)
-            self.button_run_nautilus.clicked.connect(self.handle_run_nautilus)
-        else:
-            self.set_task_button_disabled(self.button_run_nautilus)
-
-        #
-        self.button_run_prosmart = QtGui.QPushButton(
-            'ProSMART',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_prosmart)
-        if self.tasks.prosmart is not None:
-            self.button_run_prosmart.setToolTip(
-                self.tasks.prosmart.task.task_info.short_description)
-            self.button_run_prosmart.clicked.connect(self.handle_run_prosmart)
-        else:
-            self.set_task_button_disabled(self.button_run_prosmart)
-
-        # Refmac
-        self.button_run_refmac5 = QtGui.QPushButton(
-            'Refmac5',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_refmac5)
-        if self.tasks.refmac is not None:
-            self.button_run_refmac5.setToolTip(
-                self.tasks.refmac.task.task_info.short_description)
-            self.button_run_refmac5.clicked.connect(self.handle_run_refmac5)
-        else:
-            self.set_task_button_disabled(self.button_run_refmac5)
-
-        # Ribfind
-        self.button_run_ribfind = QtGui.QPushButton(
-            'Ribfind',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_ribfind)
-        if self.tasks.ribfind is not None:
-            self.button_run_ribfind.setToolTip(
-                self.tasks.ribfind.task.task_info.short_description)
-            self.button_run_ribfind.clicked.connect(self.handle_run_ribfind)
-        else:
-            self.set_task_button_disabled(self.button_run_ribfind)
-
-        # Shake
-        self.button_run_shake = QtGui.QPushButton(
-            'Shake',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_shake)
-        if self.tasks.shake is not None:
-            self.button_run_shake.setToolTip(
-                self.tasks.shake.task.task_info.short_description)
-            self.button_run_shake.clicked.connect(
-                self.handle_run_shake)
-        else:
-            self.set_task_button_disabled(self.button_run_shake)
-
-        # TEMPy: Diffmap
-        self.button_run_tempy_difference_map = QtGui.QPushButton(
-            'TEMPy: DiffMap',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_tempy_difference_map)
-        if self.tasks.tempy_diff_map is not None:
-            self.button_run_tempy_difference_map.setToolTip(
-                self.tasks.tempy_diff_map.task.task_info.short_description)
-            self.button_run_tempy_difference_map.clicked.connect(
-                self.handle_run_tempy_difference_map)
-        else:
-            self.set_task_button_disabled(self.button_run_tempy_difference_map)
-        '''
-        # TEMPy:SCCC
-        self.button_run_tempy_sccc = QtGui.QPushButton(
-            'TEMPy: SCCC',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_tempy_sccc)
-        if self.tasks.tempy_sccc is not None:
-            self.button_run_tempy_sccc.setToolTip(
-                self.tasks.tempy_sccc.task.task_info.short_description)
-            self.button_run_tempy_sccc.clicked.connect(
-                self.handle_run_tempy_sccc)
-        else:
-            self.set_task_button_disabled(self.button_run_tempy_sccc)
-        '''
-        # TEMPy: SMOC
-        self.button_run_tempy_smoc = QtGui.QPushButton(
-            'TEMPy: Local score',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_tempy_smoc)
-        if self.tasks.tempy_smoc is not None:
-            self.button_run_tempy_smoc.setToolTip(
-                self.tasks.tempy_smoc.task.task_info.short_description)
-            self.button_run_tempy_smoc.clicked.connect(
-                self.handle_run_tempy_smoc)
-        else:
-            self.set_task_button_disabled(self.button_run_tempy_smoc)
-        
-        # TEMPy: GlobScore
-        self.button_run_tempy_scores = QtGui.QPushButton(
-            'TEMPy: Scores',
-            self)
-        self.task_buttons_layout.addWidget(self.button_run_tempy_scores)
-        if self.tasks.tempy_scores is not None:
-            self.button_run_tempy_scores.setToolTip(
-                self.tasks.tempy_scores.task.task_info.short_description)
-            self.button_run_tempy_scores.clicked.connect(
-                self.handle_run_tempy_scores)
-        else:
-            self.set_task_button_disabled(self.button_run_tempy_scores)
+        # Separator
+        self.task_buttons_layout.addWidget(ccpem_widgets.CCPEMMenuSeparator())
 
         ### Utilities
-        # Separator
-        self.task_buttons_layout.addWidget(ccpem_widgets.CCPEMMenuSeparator())
-        # Images - gallery
-        self.button_run_images = QtGui.QPushButton(
-            'Images',
-            self)
-        self.button_run_images.setToolTip(
-            'Image gallery')
-        self.button_run_images.clicked.connect(self.handle_run_images)
-        self.task_buttons_layout.addWidget(self.button_run_images)
-        # MRC Edit
-        self.button_run_mrc_edit = QtGui.QPushButton(
-            'MRCEdit',
-            self)
-        self.button_run_mrc_edit.setToolTip(
-            'MRC header viewer / editor')
-        self.button_run_mrc_edit.clicked.connect(self.handle_run_mrc_edit)
-        self.task_buttons_layout.addWidget(self.button_run_mrc_edit)
+        self.add_button('Images', 'Image gallery', self.handle_run_images)
+        self.add_button('MRC Header', 'MRC header viewer', self.handle_run_mrc_edit)
+        self.add_button('relion_display', 'Run relion_display to view maps and images',
+                             gui_process.run_relion_display)
+
+        # Separator with stretch above
         self.task_buttons_layout.addStretch()
+        self.task_buttons_layout.addWidget(ccpem_widgets.CCPEMMenuSeparator())
 
         ### Information
-        # Separator
-        self.task_buttons_layout.addWidget(ccpem_widgets.CCPEMMenuSeparator())
         
-        # Info button
-        self.info_button = QtGui.QPushButton('Info')
-        self.info_button.setToolTip('CCP-EM information')
-        self.info_button.clicked.connect(self.handle_info_button)
-        self.task_buttons_layout.addWidget(self.info_button)
+        # About button
+        self.add_button('About', 'Information about CCP-EM setup', self.handle_about_button)
 
         # Test mode button
-        self.test_button = QtGui.QPushButton('Test mode')
+        self.test_button = self.add_button('Test mode', 'Test mode launches tasks with test parameters',
+                                           self.handle_test_button)
         self.test_button.setCheckable(True)
         self.test_button.setChecked(True)
         self.test_button.setStyleSheet(
             'QPushButton:checked { background-color: lightgreen; }')
-        self.test_button.setToolTip(
-            'Test mode launches tasks with test parameters')
-        self.test_button.clicked.connect(self.handle_test_button)
-        self.task_buttons_layout.addWidget(self.test_button)
+
+        # Set up scrolling
         self.task_scroll = QtGui.QScrollArea()
         self.task_scroll.setWidgetResizable(True) # Set to make the inner widget resize with scroll area
         self.task_scroll.setWidget(self.task_buttons)
@@ -584,9 +397,9 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         '''
         QtGui.QDesktopServices.openUrl(QtCore.QUrl('http://www.ccpem.ac.uk/'))
 
-    def handle_info_button(self):
+    def handle_about_button(self):
         '''
-        Launch CCP-EM information
+        Launch CCP-EM settings display
         '''
         # Bugs etc
         info_str = '\nFeatures, bugs and requests please contact'
@@ -625,27 +438,27 @@ class CCPEMMainWindow(QtGui.QMainWindow):
                 modeller.info.version)
         else:
             info_str += '\nModeller\nNot available\n'
-        info_str += '\nSettings\n'
+        info_str += '\nUser settings\n'
         info_str +=  self.args.output_args_as_text()
 
         # Task errors
         if self.tasks.errors:
-            info_str +='''
-Missing tasks
-
-Tasks are missing when all or some part of the task pipeline is missing or can not be found on your system.
-
-For CCP4 programs (e.g. Buccaneer, Molrep, MRC to MTZ, Refmac, ProSMART, Shake) please ensure CCP4 is installed and correctly sourced (CCP4 flag errors indicated CCP4 is not sourced).
-
-For Choyce and Flex-EM please ensure Modeller is installed.
-
-See below for list of missing tasks.
-'''
+            info_str += ('\nMissing tasks\n\nTasks are missing when all or '
+                         'some part of the task pipeline is missing or can '
+                         'not be found on your system.\n\n'
+                         'For CCP4 programs (e.g. Buccaneer, Molrep, MRC to '
+                         'MTZ, Refmac, ProSMART, Shake) please ensure CCP4 is '
+                         'installed and correctly set up (CCP4 flag errors '
+                         'indicated CCP4 is not sourced).\n\n'
+                         'For Choyce and Flex-EM please ensure Modeller is '
+                         'installed.\n\n'
+                         'See below for list of missing tasks:\n')
             for task, error in self.tasks.errors.iteritems():
                 info_str += '\n{0}: {1}'.format(task, error)
 
         # Info message box
         info_box = QtGui.QMessageBox(self)
+        info_box.setWindowTitle('About CCP-EM')
         info_box.setText(info_str)
         info_box.addButton(QtGui.QPushButton('Edit'), QtGui.QMessageBox.YesRole)
         info_box.addButton(QtGui.QPushButton('Ok'), QtGui.QMessageBox.NoRole)
@@ -661,294 +474,47 @@ See below for list of missing tasks.
         test_mode = self.test_button.isChecked()
         self.set_test_mode(test_mode=test_mode)
 
-    def handle_run_mrc_allspacea(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.mrcallspacea.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.mrcallspacea.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.mrcallspacea.window(
-            parent=self,
-            task=task)
+    def open_new_task_window(self, task_wrapper):
+        args_json = task_wrapper.window.gui_test_args if self.test_mode else None
+        task = task_wrapper.task(parent=self, args_json=args_json, database_path=self.database_path)
+        window = task_wrapper.window(parent=self, task=task)
         window.show()
 
-    def handle_run_mrc_mrc2tif(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.mrc2tif.test_data,
-                'unittest_args.json')
+    def handle_run_relion(self):
+        '''
+        Run relion GUI in a directory chosen by the user.
+        '''
+        relion_command = settings.which('relion')
+        if relion_command is None:
+            text = 'Warning: RELION not found'
+            ccpem_utils.print_error(message=text)
         else:
-            args_json = None
-        task = self.tasks.mrc2tif.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.mrc2tif.window(
-            parent=self,
-            task=task)
-        window.show()
+            found_project = False
+            project_dir = os.getcwd()
+            # Slightly tricky logic here. Take care not to get stuck in an infinite loop!
+            while not found_project:
+                project_dir = QtGui.QFileDialog.getExistingDirectory(self, 'Choose RELION project directory',
+                                                                     directory=project_dir)
+                if len(project_dir) == 0:
+                    # User selected 'Cancel'. Exit without running RELION.
+                    return
 
-    def handle_run_flexem(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.flex_em.test_data,
-                'demo_args.json')
-        else:
-            args_json = None
-        task = self.tasks.flex_em.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.flex_em.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_loc_scale(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.loc_scale.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.loc_scale.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.loc_scale.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_choyce(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.choyce.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.choyce.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.choyce.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_dock_em(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.dock_em.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.dock_em.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.dock_em.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_buccaneer(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.buccaneer.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.buccaneer.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.buccaneer.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_nautilus(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.nautilus.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.nautilus.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.nautilus.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_prosmart(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.prosmart.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.prosmart.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.prosmart.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_refmac5(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.refmac.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.refmac.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.refmac.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_refmac_sb(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.mrc_to_mtz.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.mrc_to_mtz.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.mrc_to_mtz.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_molrep(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.molrep.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.molrep.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.molrep.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_ribfind(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.ribfind.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.ribfind.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.ribfind.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_tempy_difference_map(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.tempy_diff_map.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.tempy_diff_map.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.tempy_diff_map.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_tempy_smoc(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.tempy_smoc.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.tempy_smoc.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.tempy_smoc.window(
-            parent=self,
-            task=task)
-        window.show()
-    
-    def handle_run_tempy_scores(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.tempy_scores.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.tempy_scores.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.tempy_scores.window(
-            parent=self,
-            task=task)
-        window.show()
-
-
-    def handle_run_tempy_sccc(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.tempy_sccc.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.tempy_sccc.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.tempy_sccc.window(
-            parent=self,
-            task=task)
-        window.show()
-
-    def handle_run_shake(self):
-        if self.test_mode:
-            args_json = os.path.join(
-                self.tasks.shake.test_data,
-                'unittest_args.json')
-        else:
-            args_json = None
-        task = self.tasks.shake.task(
-            parent=self,
-            args_json=args_json,
-            database_path=self.database_path)
-        window = self.tasks.shake.window(
-            parent=self,
-            task=task)
-        window.show()
+                project_file = os.path.join(str(project_dir), '.gui_projectdir')
+                if os.path.isfile(project_file):
+                    # Already a RELION project. Break out of the loop and run RELION.
+                    found_project = True
+                else:
+                    # Not an existing RELION project. Check if the user really means this directory.
+                    create_new = QtGui.QMessageBox.question(self, 'Create new project?',
+                                                            'There is no existing RELION project in this directory. '
+                                                            'Do you want to create a new one?',
+                                                            QtGui.QMessageBox.Ok | QtGui.QMessageBox.Cancel)
+                    if create_new == QtGui.QMessageBox.Ok:
+                        # Create a new project indicator file, then break out of loop and run RELION.
+                        open(project_file, 'w').close()
+                        found_project = True
+                    # else loop again to try a different directory
+            gui_process.run_detatched_process(command=relion_command, args=[], cwd=project_dir)
 
     def handle_run_images(self):
         window = gallery_viewer.CCPEMGalleryWindow(parent=self)
