@@ -58,17 +58,3 @@ def get_image_icons_path():
     else:
         print 'Warning: ccpem other icons path not found'
         return ''
-
-
-def get_theme_icons_path():
-    '''
-    Get small ccpem logo e.g. for gui windows
-    '''
-    path = os.path.join(get_icons_path(),
-                        'chester_theme/48x48')
-    if os.path.exists(path):
-        return path
-    else:
-        print 'Warning: ccpem theme icons path not found'
-        return ''
-
