@@ -12,17 +12,23 @@
 Task window for Buccaneer.
 '''
 import os
+
 from PyQt4 import QtGui, QtCore, QtWebKit
+
 from ccpem_core.tasks.buccaneer import  buccaneer_task
 from ccpem_gui.utils import window_utils
 from ccpem_core.ccpem_utils import ccpem_file_types
 from ccpem_gui.utils import command_line_launch
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import buccaneer as test_data
 
 
 class BuccaneerWindow(window_utils.CCPEMTaskWindow):
     '''
     Buccaneer window.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args.json')
+
     def __init__(self,
                  task,
                  parent=None):
@@ -107,14 +113,14 @@ class BuccaneerWindow(window_utils.CCPEMTaskWindow):
             button_tooltip='Show advance pipeline controls')
         self.args_widget.args_layout.addLayout(pipeline_control_frame)
         
-        # Set number of Buccaneer cycles in 1st buccaneer cycle
+        # Set number of internal Buccaneer cycles in 1st buccaneer cycle
         buc1st_ncycle_input = window_utils.NumberArgInput(
             parent=self,
             arg_name='ncycle_buc1st',
             args=self.args)
         pipeline_control_frame.add_extension_widget(buc1st_ncycle_input)
 
-        # Set number of Buccaneer cycles in nth cycles
+        # Set number of internal Buccaneer cycles in nth cycles
         bucnth_ncycle_input = window_utils.NumberArgInput(
             parent=self,
             arg_name='ncycle_bucnth',
@@ -198,6 +204,7 @@ class BuccaneerWindow(window_utils.CCPEMTaskWindow):
                     self.results_dock.setToolTip('Results overview')
                     self.results_dock.setWidget(self.rv_view)
                     self.tabifyDockWidget(self.setup_dock, self.results_dock)
+                    self.results_dock.show()
                     self.results_dock.raise_()
                     self.rv_timer.stop()
 
