@@ -10,10 +10,12 @@
 '''
 Task window for DockEM program.
 '''
-
+import inspect
 import os
 import math
+
 from PyQt4 import QtGui, QtCore
+
 from ccpem_gui.utils import window_utils
 from ccpem_gui.utils import ccpem_widgets
 from ccpem_core.tasks.dock_em import dock_em_task
@@ -22,19 +24,25 @@ from ccpem_core.settings import which
 from ccpem_core import settings
 from ccpem_gui.project_database import sqlite_project_database
 from ccpem_gui.utils import gui_process
+from ccpem_core import process_manager
+from ccpem_gui.utils import command_line_launch
+from ccpem_core.process_manager import job_register
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import dock_em as test_data
+
 
 class DockEMMainWindow(window_utils.CCPEMTaskWindow):
     '''
     Inherits from CCPEMTaskWindow and creates the form.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args.json')
+
     def __init__(self,
                  parent=None,
                  task=None):
         self.grid_sampling_input = None
         self.box_extent = None
         self.mrc_header = None
-        self.chimera_bin = which('chimera')
-        self.has_run = False
         self.review_dock = None
         super(DockEMMainWindow, self).__init__(task=task,
                                                parent=parent)
@@ -112,23 +120,11 @@ class DockEMMainWindow(window_utils.CCPEMTaskWindow):
             arg_name='map_resolution',
             required=True,
             args=self.args)
-        self.input_options_frame.add_extension_widget(self.map_resolution_input)
+        self.input_options_frame.add_extension_widget(
+            self.map_resolution_input)
+        self.map_resolution_input.value_line.editingFinished.connect(
+            self.set_theta)
 
-        if self.args.grid_sampling() is None:
-            self.set_grid_sampling()
-        self.grid_sampling_input = window_utils.NumberArgInput(
-            parent=self,
-            arg_name='grid_sampling',
-            args=self.args)
-        self.input_options_frame.add_extension_widget(self.grid_sampling_input)
-        self.target_map_arg_input.value_line.textChanged.connect(
-            self.set_grid_sampling)
-
-        self.high_pass_filter = window_utils.NumberArgInput(
-            parent=self,
-            arg_name='high_pass_filter',
-            args=self.args)
-        self.input_options_frame.add_extension_widget(self.high_pass_filter)
 
         # Input search object and pdb header
         self.search_object_arg_input = window_utils.FileArgInput(
@@ -150,19 +146,6 @@ class DockEMMainWindow(window_utils.CCPEMTaskWindow):
         self.input_options_frame.add_extension_widget(
             self.centre_model_input)
 
-        self.mask_smooth = window_utils.NumberArgInput(
-            parent=self,
-            arg_name='mask_smooth',
-            args=self.args)
-        self.input_options_frame.add_extension_widget(self.mask_smooth)
-
-        # Input mask Threshold
-        self.mask_threshold = window_utils.NumberArgInput(
-            parent=self,
-            arg_name='mask_threshold',
-            args=self.args)
-        self.input_options_frame.add_extension_widget(self.mask_threshold)
-
         # Base on 1/2 box size; to nearest power of 2
         # Input Extent search
         if self.args.box_extent() is None:
@@ -176,6 +159,54 @@ class DockEMMainWindow(window_utils.CCPEMTaskWindow):
         self.input_options_frame.add_extension_widget(self.box_extent)
         self.target_map_arg_input.value_line.textChanged.connect(
             self.set_box_extent)
+        self.box_extent.value_line.editingFinished.connect(
+            self.set_theta)
+
+        # Extended options
+        extended_options_frame = window_utils.CCPEMExtensionFrame(
+            button_name='Extended options',
+            button_tooltip='Show extended options')
+        self.args_widget.args_layout.addLayout(extended_options_frame)
+
+        # Grid Sampling
+        if self.args.grid_sampling() is None:
+            self.set_grid_sampling()
+        self.grid_sampling_input = window_utils.NumberArgInput(
+            parent=self,
+            arg_name='grid_sampling',
+            args=self.args)
+        extended_options_frame.add_extension_widget(
+            self.grid_sampling_input)
+        self.target_map_arg_input.value_line.textChanged.connect(
+            self.set_grid_sampling)
+
+        self.high_pass_filter = window_utils.NumberArgInput(
+            parent=self,
+            arg_name='high_pass_filter',
+            args=self.args)
+        extended_options_frame.add_extension_widget(
+            self.high_pass_filter)
+
+        self.mask_smooth = window_utils.NumberArgInput(
+            parent=self,
+            arg_name='mask_smooth',
+            args=self.args)
+        extended_options_frame.add_extension_widget(self.mask_smooth)
+
+        # Input mask Threshold
+        self.mask_threshold = window_utils.NumberArgInput(
+            parent=self,
+            arg_name='mask_threshold',
+            args=self.args)
+        extended_options_frame.add_extension_widget(self.mask_threshold)
+
+        # -> Fixed model pdb
+        theta_limit_input = window_utils.NumberArgInput(
+            parent=self,
+            arg_name='theta_limit',
+            required=False,
+            args=self.args)
+        extended_options_frame.add_extension_widget(theta_limit_input)
 
         # Full search options
                 # Separator
@@ -219,14 +250,19 @@ class DockEMMainWindow(window_utils.CCPEMTaskWindow):
         self.run_frame.add_extension_frame(self.ang_parameters_frame)
         self.ang_parameters_frame.button.click()
 
+        # Sampling information
+        self.sampling_info_label = QtGui.QLabel()
+        self.ang_parameters_frame.add_extension_widget(
+            self.sampling_info_label)
+        self.set_sampling_info()
+
         # -> Input angular sampling
         self.angular_sampling = window_utils.NumberArgInput(
             parent=self,
             arg_name='angl_sampling',
             args=self.args)
-        self.ang_parameters_frame.add_extension_widget(self.angular_sampling)
-        self.angular_sampling.value_line.editingFinished.connect(
-            self.set_theta)
+        self.ang_parameters_frame.add_extension_widget(
+            self.angular_sampling)
 
         # -> Input theta step
         self.theta_step = window_utils.NumberArgInput(
@@ -234,6 +270,8 @@ class DockEMMainWindow(window_utils.CCPEMTaskWindow):
             arg_name='theta_step',
             args=self.args)
         self.ang_parameters_frame.add_extension_widget(self.theta_step)
+        self.set_theta()
+
 
         # Set inputs for launcher
         self.launcher.add_file(
@@ -327,14 +365,12 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
         self.setup_dock.raise_()
         self.input_options_frame.button.setChecked(True)
         self.input_options_frame.button_clicked()
-        #
         self.full_run_option.value_line.setChecked(False)
 
     def run_search_clicked(self):
         self.setup_dock.raise_()
         self.input_options_frame.button.setChecked(False)
         self.input_options_frame.button_clicked()
-        #
         self.full_run_option.value_line.setChecked(True)
 
     def set_analyzer_ui(self):
@@ -463,8 +499,21 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
         Theta and angular sampling set to same. If user changes either value
         other value gets updated
         '''
-        self.theta_step.value_line.setValue(self.args.angl_sampling.value)
-        self.args.theta_step.value = self.args.angl_sampling.value
+        theta = self.task.calculate_theta_sampling()
+        if theta is not None:
+#             self.angular_sampling.value_line.setValue(float(theta))
+#             self.theta_step.value_line.setValue(float(theta))
+            self.set_sampling_info(theta=theta)
+
+    def set_sampling_info(self, theta=None):
+        if theta is None:
+            self.sampling_info_label.hide()
+        else:
+            sampling_info = (
+                'Suggested angular sampling : {0} deg\n'
+                'This based on resolution and search extent').format(theta)
+            self.sampling_info_label.setText(sampling_info)
+            self.sampling_info_label.show()
 
     def chimera_view_setup(self):
         '''
@@ -482,17 +531,22 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
         mask_script = os.path.join(
             os.path.dirname(os.path.realpath(__file__)),
             'dock_em_chimera_view_setup.py')
-        chimera_command = '%s %s %s %s %s %s %s' % (
+        chimera_command = '%s %s %s %s %s %s %s %s' % (
             str(mask_script),
             str(self.args.search_object_mask.value),
             str(self.args.target_map_filtered.value),
             str(self.args.search_object_filtered.value),
             str(self.args.search_object.value),
             str(self.args.mask_threshold.value),
+            str(self.args.roi_map.value),
             str(self.task.job_location))
         arg_list_chimera = ['--script', '%s' % (chimera_command)]
         process = QtCore.QProcess()
-        process.startDetached(self.chimera_bin, arg_list_chimera)
+        chimera_bin = which('chimera')
+        if chimera_bin is None:
+            print 'Chimera executable not found (add executable to system PATH)'
+        else:
+            process.startDetached(chimera_bin, arg_list_chimera)
 
     def chimera_view_solutions(self):
         '''
@@ -521,9 +575,12 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
                                         self.args.target_map_filtered.value,
                                         ids_checked)
         arg_list_chimera = ['--script', '%s' % (chimera_command)]
-        self.chimera_bin = which('chimera')
         process = QtCore.QProcess()
-        process.startDetached(self.chimera_bin, arg_list_chimera)
+        chimera_bin = which('chimera')
+        if chimera_bin is None:
+            print 'Chimera executable not found (add executable to system PATH)'
+        else:
+            process.startDetached(chimera_bin, arg_list_chimera)
 
     def handle_run_analyzer_button(self):
         '''
@@ -611,10 +668,9 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
             selected=True)
         # Cropped ROI map
         self.launcher.add_file(
-            description='Map cropped to region on interest',
+            arg_name='roi_map',
+            description=self.args.search_object_mask.help,
             file_type='map',
-            path=self.task.roi_crop_map,
-            display_from='running',
             selected=True)
         if len(self.launcher.files) > 0:
             self.launcher_dock.setVisible(True)
@@ -629,7 +685,6 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
             self.status_widget.set_finished()
             self.tb_run_button.setEnabled(False)
             self.disable_args_widgets()
-            self.tb_load_button.setEnabled(True)
             self.tb_browser_button.setEnabled(True)
             self.tb_terminal_button.setEnabled(True)
             self.tb_stop_button.setEnabled(False)
@@ -637,7 +692,6 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
             self.status_widget.set_finished()
             self.tb_run_button.setEnabled(True)
             self.disable_args_widgets(disable=False)
-            self.tb_load_button.setEnabled(True)
             self.tb_browser_button.setEnabled(True)
             self.tb_terminal_button.setEnabled(True)
             self.tb_stop_button.setEnabled(False)
@@ -657,8 +711,7 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
         '''
         Actions to run on job completion.
         '''
-        self.has_run = True
-        if self.args.run_search():
+        if self.args.stage() == 'Search':
             self.set_analyzer_ui()
             self.analyzer_dock.setVisible(True)
             self.analyzer_dock.raise_()
@@ -669,18 +722,59 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
 
     def run_detached_process(self, job_id=None):
         '''
-        Re-implement from window utils to stop creation of new job directory
+        Re-implement from window utils to stop assignemnt of job id
         '''
+        #
+#         if self.database_path is not None:
+#             db = sqlite_project_database.CCPEMDatabase(
+#                 database_path=self.database_path)
+#             db_inject = sqlite_project_database.CCPEMInjector(
+#                 database_path=self.database_path)
+#             # Check if job already has id
+#             re_run = self.task.args.stage() != 'Ready'
+#             if re_run and self.pipeline is not None:
+#                 job_id = process_manager.get_db_id(
+#                     self.pipeline.json)
+#                 set_job_location=False
+#             else:
+#                 job_id = db.insert_new_job(
+#                     program=self.task.task_info.name,
+#                     job_location='None')
+#                 set_job_location=True
+#         else:
+#             db_inject = None
+#         #
+#         self.task.run_task(set_job_location=set_job_location,
+#                            job_id=job_id,
+#                            db_inject=db_inject)
+#         self.pipeline = self.task.pipeline
+#         self.set_on_job_running()
+
+        path = self.task.job_location
         db_inject = None
         if self.database_path is not None:
+            path = os.path.dirname(self.database_path)
             db_inject = sqlite_project_database.CCPEMInjector(
                 database_path=self.database_path)
-        self.task.run_task(set_job_location=not self.has_run,
+
+        re_run = self.task.args.stage() != 'Ready'
+        if re_run and self.pipeline is not None:
+            job_id = process_manager.get_db_id(
+                    self.pipeline.json)
+            job_location = self.task.job_location
+        else:
+            job_id, job_location = job_register.job_register(
+                path=path,
+                db_inject=db_inject,
+                task_name=self.task.task_info.name)
+        #
+        self.task.run_task(job_location=job_location,
                            job_id=job_id,
                            db_inject=db_inject)
         self.pipeline = self.task.pipeline
         self.set_on_job_running()
 
+
     def recreate_process(self):
         if self.task.job_location is not None:
             self.dockem_log_path = os.path.join(self.task.job_location,
@@ -689,12 +783,11 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
 
 def main():
     '''
-    Launch stand alone window.
+    Launch standalone task runner.
     '''
-    window_utils.standalone_window_launch(
-#         args_json='./test_data/unittest_args.json',
-        task=dock_em_task.DockEM,
-        window=DockEMMainWindow)
+    command_line_launch.ccpem_task_launch(
+        task_class=dock_em_task.DockEM,
+        window_class=DockEMMainWindow)
 
 if __name__ == '__main__':
     main()
