@@ -6,12 +6,15 @@
 #     A copy of the CCP-EM licence can be obtained by writing to the
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
 #
+import os, re
 
-import os
 from PyQt4 import QtGui, QtCore, QtWebKit
+
 from ccpem_core.tasks.flex_em import flexem_task
 from ccpem_gui.utils import window_utils
 from ccpem_core.ccpem_utils import ccpem_file_types
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import flex_em as test_data
 try:
     import modeller # @UnusedImport
     modeller_available = True
@@ -24,6 +27,8 @@ class FlexEMWindow(window_utils.CCPEMTaskWindow):
     '''
     FlexEM window.
     '''
+    gui_test_args = get_test_data_path(test_data, 'demo_args.json')
+
     def __init__(self,
                  task,
                  parent=None):
@@ -103,46 +108,69 @@ class FlexEMWindow(window_utils.CCPEMTaskWindow):
         self.args_widget.args_layout.addWidget(self.iterations_input)
 
         # Extended options
-        options_frame = window_utils.CCPEMExtensionFrame(
+        self.options_frame = window_utils.CCPEMExtensionFrame(
             button_name='Extended options',
             button_tooltip='Extended Flex-EM options')
-        self.args_widget.args_layout.addLayout(options_frame)
+        self.args_widget.args_layout.addLayout(self.options_frame)
 
-        # -> Phi-Psi restraints
-        phi_psi_input = window_utils.ChoiceArgInput(
-            parent=self,
-            arg_name='phi_psi_restraints',
-            args=self.args)
-        options_frame.add_extension_widget(phi_psi_input)
+#         # -> Phi-Psi restraints
+#         phi_psi_input = window_utils.ChoiceArgInput(
+#             parent=self,
+#             arg_name='phi_psi_restraints',
+#             args=self.args)
+#         self.options_frame.add_extension_widget(phi_psi_input)
 
-        # Mode
-        self.mode_input = window_utils.ChoiceArgInput(
-            parent=self,
-            arg_name='mode',
-            args=self.args)
-        options_frame.add_extension_widget(self.mode_input)
+#         # Mode
+#         self.mode_input = window_utils.ChoiceArgInput(
+#             parent=self,
+#             arg_name='mode',
+#             args=self.args)
+#         self.options_frame.add_extension_widget(self.mode_input)
  
         # Cutoff 
         self.cutoff_input = window_utils.NumberArgInput(
             parent=self,
             arg_name='max_atom_disp',
-            required=True,
+            required=False,
             args=self.args)
-        options_frame.add_extension_widget(self.cutoff_input)
-
+        self.options_frame.add_extension_widget(self.cutoff_input)
+        # density weight 
+        self.density_weight = window_utils.NumberArgInput(
+            parent=self,
+            arg_name='density_weight',
+            required=False,
+            args=self.args)
+        self.options_frame.add_extension_widget(self.density_weight)
+        #template restraint options
+        self.set_template_restraints()
+        
+        # Keyword frame
+        keyword_frame = window_utils.CCPEMExtensionFrame(
+            button_name='Keywords',
+            button_tooltip='Optional user-supplied keywords (see info)')
+        self.args_widget.args_layout.addLayout(keyword_frame)
+ 
+        # -> Keyword entry
+        self.keyword_entry_new = window_utils.KeywordArgInput(
+            parent=self,
+            arg_name='keywords',
+            args=self.args,
+            label='Keywords')
+        keyword_frame.add_extension_widget(self.keyword_entry_new)
+        
         # Alpha test... refine B's; calc FSC; HM validation
         if self.args.alpha_mode():
             refine_b_input = window_utils.ChoiceArgInput(
                 parent=self,
                 arg_name='refine_b',
                 args=self.args)
-            options_frame.add_extension_widget(refine_b_input)
+            self.options_frame.add_extension_widget(refine_b_input)
             #
             fsc_calc_input = window_utils.ChoiceArgInput(
                 parent=self,
                 arg_name='fsc_calc',
                 args=self.args)
-            options_frame.add_extension_widget(fsc_calc_input)
+            self.options_frame.add_extension_widget(fsc_calc_input)
             #
             self.half_map_1_input = window_utils.FileArgInput(
                 parent=self,
@@ -162,13 +190,13 @@ class FlexEMWindow(window_utils.CCPEMTaskWindow):
                 arg_name='validate',
                 dependants=[self.half_map_1_input, self.half_map_2_input],
                 args=self.args)
-            options_frame.add_extension_widget(self.validation_button)
+            self.options_frame.add_extension_widget(self.validation_button)
 
             # -> Half map 1
-            options_frame.add_extension_widget(self.half_map_1_input)
+            self.options_frame.add_extension_widget(self.half_map_1_input)
 
             # -> Half map 2
-            options_frame.add_extension_widget(self.half_map_2_input)
+            self.options_frame.add_extension_widget(self.half_map_2_input)
 
         # Add files to launcher
         self.launcher.add_file(
@@ -187,6 +215,39 @@ class FlexEMWindow(window_utils.CCPEMTaskWindow):
             description=self.args.input_map.help,
             selected=True)
 
+    def set_template_restraints(self):
+        template_restraints_frame = window_utils.CCPEMExtensionFrame(
+            button_name='template restraints',
+            button_tooltip=('restrain based on template\n'))
+        
+        self.options_frame.add_extension_frame(template_restraints_frame)
+        # restraint choices
+        self.template_phipsi = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='phi_psi_restraints',
+#             tooltip_text=(''),
+            args=self.args)
+        template_restraints_frame.add_extension_widget(self.template_phipsi)
+#         self.template_distance = window_utils.CheckArgInput(
+#             parent=self,
+#             arg_name='distance_restraints',
+# #             tooltip_text=(''),
+#             args=self.args)
+#         template_restraints_frame.add_extension_widget(self.template_distance)
+#         self.max_template_distance = window_utils.NumberArgInput(
+#             parent=self,
+#             arg_name='max_distance',
+#             args=self.args)
+#         self.options_frame.add_extension_widget(self.max_template_distance)
+#         self.max_template_distance.hide()
+#         self.template_distance.value_line.stateChanged.connect(
+#                                             self.set_template_distance)
+    def set_template_distance(self):
+        if self.template_distance.value_line.isChecked():
+            self.max_template_distance.show()
+        else:
+            self.max_template_distance.hide()
+    
     def set_create_rigid_body(self):
         if self.args.create_rigid_body():
             self.rigid_input.hide()
@@ -202,6 +263,7 @@ class FlexEMWindow(window_utils.CCPEMTaskWindow):
         Actions to run on job completion.  For now show starting, refined
         pdb and experimental map.
         '''
+        md_output_dir = os.path.join(self.task.job_location,'1_MD')
         md_output_pdb = os.path.join(self.task.job_location,
                                      '1_MD/final1_mdcg.pdb')
         cg_output_pdb = os.path.join(self.task.job_location,
@@ -210,6 +272,7 @@ class FlexEMWindow(window_utils.CCPEMTaskWindow):
             self.output_pdb = md_output_pdb
         elif os.path.exists(cg_output_pdb):
             self.output_pdb = cg_output_pdb
+        
         if self.output_pdb is not None:
             self.launcher.add_file(
                 arg_name=None,
@@ -218,6 +281,17 @@ class FlexEMWindow(window_utils.CCPEMTaskWindow):
                 description='Output PDB',
                 display_from='finished',
                 selected=True)
+        
+        for file in os.listdir(md_output_dir):
+            if re.search("md[0-9]_[0-9]+.pdb",file) is not None:
+                filepath = os.path.join(md_output_dir,file)
+                self.launcher.add_file(
+                    arg_name=None,
+                    file_type='pdb',
+                    path=filepath,
+                    description='Output from each iteration',
+                    display_from='finished',
+                    selected=False)
         self.set_rv_ui()
 
     def set_rv_ui(self):
