@@ -6,17 +6,22 @@
 #     A copy of the CCP-EM licence can be obtained by writing to the
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
 #
-
 import os
+
 from ccpem_gui.utils import window_utils
 from ccpem_core.tasks.molrep import molrep_task
 from ccpem_core.ccpem_utils import ccpem_file_types
 from ccpem_gui.utils import command_line_launch
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import molrep as test_data
+
 
 class MolrepWindow(window_utils.CCPEMTaskWindow):
     '''
     Molrep window.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args.json')
+
     def __init__(self,
                  task,
                  parent=None):
