@@ -12,11 +12,16 @@ Task window for MRC2TIF program.
 from ccpem_core.tasks.mrc_mrc2tif import mrc_mrc2tif_task
 from ccpem_gui.utils import window_utils
 from ccpem_gui.utils import command_line_launch
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import mrc_mrc2tif as test_data
+
 
 class Mrc2TifWindow(window_utils.CCPEMTaskWindow):
     '''
     Inherits from CCPEMTaskWindow.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args.json')
+
     def __init__(self,
                  task,
                  parent=None):
