@@ -12,17 +12,23 @@
 Task window for Nautilus.
 '''
 import os
-from ccpem_core.tasks.nautilus import nautilus_task
+
 from PyQt4 import QtGui, QtCore, QtWebKit
+
+from ccpem_core.tasks.nautilus import nautilus_task
 from ccpem_gui.utils import window_utils
 from ccpem_core.ccpem_utils import ccpem_file_types
 from ccpem_gui.utils import command_line_launch
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import nautilus as test_data
 
 
 class NautilusWindow(window_utils.CCPEMTaskWindow):
     '''
     Nautilus window.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args.json')
+
     def __init__(self,
                  task,
                  parent=None):
@@ -107,14 +113,14 @@ class NautilusWindow(window_utils.CCPEMTaskWindow):
             button_tooltip='Show pipeline controls for number of internal cycles')
         self.args_widget.args_layout.addLayout(pipeline_control_frame)
 
-        # Set number of Buccaneer cycles in 1st nautilus cycle
+        # Set number of internal cycles in 1st Nautilus cycle
         nau1st_ncycle_input = window_utils.NumberArgInput(
             parent=self,
             arg_name='ncycle_nau1st',
             args=self.args)
         pipeline_control_frame.add_extension_widget(nau1st_ncycle_input)
 
-        # Set number of Nautilus cycles in nth cycles
+        # Set number of internal cycles in nth Nautilus cycles
         naunth_ncycle_input = window_utils.NumberArgInput(
             parent=self,
             arg_name='ncycle_naunth',
@@ -182,6 +188,7 @@ class NautilusWindow(window_utils.CCPEMTaskWindow):
                     self.results_dock.setToolTip('Results overview')
                     self.results_dock.setWidget(self.rv_view)
                     self.tabifyDockWidget(self.setup_dock, self.results_dock)
+                    self.results_dock.show()
                     self.results_dock.raise_()
                     self.rv_timer.stop()
 
