@@ -11,13 +11,18 @@
 Task window for ProSMART.
 '''
 import os
+
 from PyQt4 import QtGui, QtCore, QtWebKit
+
 from ccpem_gui.utils import window_utils
 from ccpem_core.ccpem_utils import ccpem_file_types
 from ccpem_core.ccpem_utils import ccpem_coord_tools
 from ccpem_core.tasks.prosmart import prosmart_task
-from ccpem_gui.project_database import sqlite_project_database
 from ccpem_gui.utils import gui_process
+from ccpem_gui.utils import command_line_launch
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import prosmart as test_data
+
 
 # XXX Coot - how to autoload restraints
 # XXX Howto link with refmac
@@ -355,6 +360,8 @@ class ProSMARTWindow(window_utils.CCPEMTaskWindow):
     '''
     ProSMART window.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args.json')
+
     def __init__(self,
                  task,
                  parent=None):
@@ -453,20 +460,13 @@ class ProSMARTWindow(window_utils.CCPEMTaskWindow):
             self.results_dock.setToolTip('Results overview')
             self.results_dock.setWidget(self.rv_view)
             self.tabifyDockWidget(self.setup_dock, self.results_dock)
+            self.results_dock.show()
             self.results_dock.raise_()
 
     def handle_toolbar_run(self):
         '''
         Over ride from baseclass to allow validation of multiple datasets
         '''
-        if self.database_path is not None:
-            db = sqlite_project_database.CCPEMDatabase(
-                database_path=self.database_path)
-            job_id = db.insert_new_job(program=self.task.task_info.name,
-                                       job_location='None')
-        else:
-            job_id=None
-
         # Remove reference pdbs if not used
         if self.args.mode() != 'Reference model':
             self.args.ref_pdbs.value = None
@@ -481,7 +481,7 @@ class ProSMARTWindow(window_utils.CCPEMTaskWindow):
                     return
                 else :
                     self.ref_pdbs.set_args()
-        self.run_detached_process(job_id=job_id)
+        self.run_detached_process()
 
     def set_on_job_running_custom(self):
         if hasattr(self, 'tb_chimera_button'):
@@ -592,11 +592,11 @@ class ProSMARTWindow(window_utils.CCPEMTaskWindow):
 
 def main():
     '''
-    Launch stand alone window.
+    Launch standalone task runner.
     '''
-    window_utils.standalone_window_launch(
-        task=prosmart_task.ProSMART,
-        window=ProSMARTWindow)
+    command_line_launch.ccpem_task_launch(
+        task_class=prosmart_task.ProSMART,
+        window_class=ProSMARTWindow)
 
 if __name__ == '__main__':
     main()
