@@ -11,11 +11,15 @@
 Task window for Refmac5.
 '''
 import os
+
 from PyQt4 import QtGui, QtCore, QtWebKit
+
 from ccpem_core.tasks.refmac import refmac_task
 from ccpem_gui.utils import window_utils
 from ccpem_core.ccpem_utils import ccpem_file_types
 from ccpem_gui.utils import command_line_launch
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import refmac as test_data
 
 
 class RefmacDataset(object):
@@ -567,6 +571,8 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
     '''
     Refmac window.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args_local_hb_validation.json')
+
     def __init__(self,
                  task,
                  parent=None):
@@ -605,26 +611,36 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             args=self.args)
         self.args_widget.args_layout.addWidget(self.find_in_map_input)
 
+        self.local_refinement_input = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='local_refinement_on',
+            args=self.args)
+        self.args_widget.args_layout.addWidget(
+            self.local_refinement_input)
+
         # Refinement options frame
-        refinement_options_frame = window_utils.CCPEMExtensionFrame(
+        self.refinement_options_frame = window_utils.CCPEMExtensionFrame(
             button_name='Refinement options',
-            button_tooltip='Specify refinement parameters')
-        self.args_widget.args_layout.addLayout(refinement_options_frame)
+            button_tooltip='Change default refinement parameters')
+        self.args_widget.args_layout.addLayout(
+            self.refinement_options_frame)
 
         # -> Ncycle
         ncycle_input = window_utils.NumberArgInput(
             parent=self,
             arg_name='ncycle',
             args=self.args)
-        refinement_options_frame.add_extension_widget(ncycle_input)
+        self.refinement_options_frame.add_extension_widget(ncycle_input)
 
         # -> LIBG restraints for nucleic acids
         self.libg_input = window_utils.ChoiceArgInput(
             parent=self,
             arg_name='libg',
             args=self.args)
-        refinement_options_frame.add_extension_widget(self.libg_input)
-        self.libg_input.value_line.currentIndexChanged.connect(self.set_libg_selection)
+        self.refinement_options_frame.add_extension_widget(
+            self.libg_input)
+        self.libg_input.value_line.currentIndexChanged.connect(
+            self.set_libg_selection)
 
         # -> Keyword entry for libg nucleotide range selection
         self.libg_selection_input = window_utils.KeywordArgInput(
@@ -632,7 +648,8 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             arg_name='libg_selection',
             args=self.args,
             label='Nucleotide range')
-        refinement_options_frame.add_extension_widget(self.libg_selection_input)
+        self.refinement_options_frame.add_extension_widget(
+            self.libg_selection_input)
         self.set_libg_selection()
 
         # -> Weight auto
@@ -640,8 +657,8 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             parent=self,
             arg_name='weight_auto',
             args=self.args)
-        refinement_options_frame.add_extension_widget(self.weight_auto_input)
-        self.weight_auto_input.value_line.stateChanged.connect(self.set_weight_auto)
+        self.refinement_options_frame.add_extension_widget(
+            self.weight_auto_input)
 
         # -> Weight
         self.weight_input = window_utils.NumberArgInput(
@@ -649,54 +666,50 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             arg_name='weight',
             args=self.args,
             decimals = 5)
-        refinement_options_frame.add_extension_widget(self.weight_input)
-        self.set_weight_auto()
+        self.refinement_options_frame.add_extension_widget(
+            self.weight_input)
 
-        # -> Weight auto
-        self.symmetry_auto_input = window_utils.CheckArgInput(
+        # -> Symmetry
+        self.symmetry_auto_input = window_utils.ChoiceArgInput(
             parent=self,
             arg_name='symmetry_auto',
+            second_width=None,
             args=self.args)
-        refinement_options_frame.add_extension_widget(self.symmetry_auto_input)
+        self.refinement_options_frame.add_extension_widget(
+            self.symmetry_auto_input)
 
-        # -> Map sharpen
+        # -> Map sharpen / blur
         map_sharpen_input = window_utils.NumberArgInput(
             parent=self,
             decimals=1,
             minimum=-999,
             arg_name='map_sharpen',
             args=self.args)
-        refinement_options_frame.add_extension_widget(map_sharpen_input)
+        self.refinement_options_frame.add_extension_widget(
+            map_sharpen_input)
 
         # -> Jelly body
-        jelly_body_input = window_utils.ChoiceArgInput(
+        self.jelly_body_input = window_utils.ChoiceArgInput(
             parent=self,
             arg_name='jelly_body',
             args=self.args)
-        refinement_options_frame.add_extension_widget(jelly_body_input)
+        self.refinement_options_frame.add_extension_widget(
+            self.jelly_body_input)
 
         # -> Hydrogens
         hydrogens_input = window_utils.ChoiceArgInput(
             parent=self,
             arg_name='hydrogens',
             args=self.args)
-        refinement_options_frame.add_extension_widget(hydrogens_input)
+        self.refinement_options_frame.add_extension_widget(
+            hydrogens_input)
 
-        # -> Input ligand cif library
-        lib_input = window_utils.FileArgInput(
-            parent=self,
-            arg_name='lib_in',
-            args=self.args,
-            file_types=ccpem_file_types.lib_ext,
-            required=False)
-        refinement_options_frame.add_extension_widget(lib_input)
-
-
-        # B-factor refinement
+        # Reset input PDB b-factor
         bfactor_frame = window_utils.CCPEMExtensionFrame(
             button_name='Edit input model',
             button_tooltip='Set b-factor options')
-        refinement_options_frame.add_extension_frame(bfactor_frame)
+        self.refinement_options_frame.add_extension_frame(
+            bfactor_frame)
 
         # ->-> Set bfactor on
         bfactor_input = window_utils.NumberArgInput(
@@ -718,7 +731,8 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         local_refinement_frame = window_utils.CCPEMExtensionFrame(
             button_name='Local refinement options',
             button_tooltip='Refine around radius of supplied molecule only')
-        refinement_options_frame.add_extension_frame(local_refinement_frame)
+        self.refinement_options_frame.add_extension_frame(
+            local_refinement_frame)
 
         # ->-> Local refinement on
         mask_radius_input = window_utils.NumberArgInput(
@@ -727,13 +741,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             args=self.args,
             required=False,
             label='Mask radius')
-        self.local_refinement_input = window_utils.CheckArgInput(
-            parent=self,
-            arg_name='local_refinement_on',
-            dependants=[mask_radius_input],
-            args=self.args)
-        local_refinement_frame.add_extension_widget(
-            self.local_refinement_input)
 
         # ->-> Mask Radius
         local_refinement_frame.add_extension_widget(mask_radius_input)
@@ -742,7 +749,8 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         self.external_restraints_frame = window_utils.CCPEMExtensionFrame(
             button_name='External restraints',
             button_tooltip='Set external restraints')
-        self.args_widget.args_layout.addLayout(self.external_restraints_frame)
+        self.args_widget.args_layout.addLayout(
+            self.external_restraints_frame)
 
         # -> Use external restraints
 #        input_prosmart = window_utils.FileArgInput(
@@ -758,16 +766,17 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             parent=self)
         self.args_widget.args_layout.addWidget(self.restraints)
 
-
         self.restraints_button = window_utils.CheckArgInput(
             parent=self,
             arg_name='external_restraints_on',
             dependants=[self.restraints],
             args=self.args)
-        self.external_restraints_frame.add_extension_widget(self.restraints_button)
+        self.external_restraints_frame.add_extension_widget(
+            self.restraints_button)
 
         # -> ProSMART restraints
-        self.external_restraints_frame.add_extension_widget(self.restraints)
+        self.external_restraints_frame.add_extension_widget(
+            self.restraints)
 
         # -> External restraints weights
         for arg in ['external_weight_dmx']:
@@ -775,18 +784,20 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                 parent=self,
                 arg_name=arg,
                 args=self.args)
-            self.external_restraints_frame.add_extension_widget(restraints_menu)
+            self.external_restraints_frame.add_extension_widget(
+                restraints_menu)
         # -> Main chain only option
         input_main_chain = window_utils.ChoiceArgInput(
             parent=self,
             arg_name='external_main_only',
             args=self.args)
-        self.external_restraints_frame.add_extension_widget(input_main_chain)
+        self.external_restraints_frame.add_extension_widget(
+            input_main_chain)
 
         # Validation frame
         self.validation_frame = window_utils.CCPEMExtensionFrame(
             button_name='Validate options',
-            button_tooltip='Show validation options')
+            button_tooltip='Validate refinement pipeline')
         self.args_widget.args_layout.addLayout(self.validation_frame)
 
         self.half_map_1_input = window_utils.FileArgInput(
@@ -807,13 +818,17 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             arg_name='validate_on',
             dependants=[self.half_map_1_input, self.half_map_2_input],
             args=self.args)
-        self.validation_frame.add_extension_widget(self.validation_button)
+
+        self.validation_frame.add_extension_widget(
+            self.validation_button)
 
         # -> Half map 1
-        self.validation_frame.add_extension_widget(self.half_map_1_input)
+        self.validation_frame.add_extension_widget(
+            self.half_map_1_input)
 
         # -> Half map 2
-        self.validation_frame.add_extension_widget(self.half_map_2_input)
+        self.validation_frame.add_extension_widget(
+            self.half_map_2_input)
 
         # -> Reference map
         # Validation frame
@@ -853,6 +868,17 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             label='Keywords')
         keyword_frame.add_extension_widget(self.keyword_entry_new)
 
+        # Set dependancies
+        self.weight_auto_input.value_line.stateChanged.connect(
+            self.set_weight_auto)
+        self.weight_auto_input.value_line.stateChanged.connect(
+            self.set_validate_on)
+        self.set_weight_auto()
+        self.validation_button.value_line.stateChanged.connect(
+            self.set_validate_on)
+        self.restraints_button.value_line.stateChanged.connect(
+            self.show_prosmart_jelly_body_warning)
+
         # Change map / pdb / resolution input depending on DC mode
         self.set_dc_mode()
 
@@ -868,6 +894,58 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         else:
             self.weight_input.show()
 
+    def set_validate_on(self):
+        '''
+        Switch of auto weight & jelly body and show information message
+        '''
+        # Disable auto weight
+        if self.validation_button.value_line.isChecked() and \
+                self.weight_auto_input.value_line.isChecked():
+            self.weight_auto_input.value_line.setChecked(False)
+            self.weight_auto_input.setEnabled(False)
+            self.show_validation_weight_message()
+        elif not self.validation_button.value_line.isChecked():
+            self.weight_auto_input.setEnabled(True)
+        # Disable jelly body
+        if self.validation_button.value_line.isChecked() and \
+                self.jelly_body_input.value_line.currentText() == 'True':
+            self.jelly_body_input.value_line.setCurrentIndex(
+                self.jelly_body_input.choices.index('False'))
+            self.jelly_body_input.value_line.setEnabled(False)
+            self.show_validation_jelly_body_message()
+        elif not self.validation_button.value_line.isChecked():
+            self.jelly_body_input.value_line.setEnabled(True)
+
+    def show_validation_weight_message(self):
+        message = \
+            ('Please set weight. \nN.B. auto weight option cannot be '
+             'used in conjuction with validation.  Please manually set '
+             'the weight (this can be found from previous jobs in the '
+             'results tab)')
+        QtGui.QMessageBox.information(self,
+                                      'CCP-EM | Refmac5',
+                                      message)
+
+    def show_validation_jelly_body_message(self):
+        message = \
+            ('Jelly body restraints are not compatible with the '
+             'validation pipeline and have been disabled')
+        QtGui.QMessageBox.information(self,
+                                      'CCP-EM | Refmac5',
+                                      message)
+
+    def show_prosmart_jelly_body_warning(self):
+        if self.jelly_body_input.value_line.currentText() == 'True' and \
+                self.restraints_button.value_line.isChecked():
+            message = \
+                ('Jelly body restraints are not compatible with '
+                 'ProSMART external restraints so we recommend you '
+                 'turn off the jelly body restraints if using'
+                 'ProSMART restraints')
+            QtGui.QMessageBox.information(self,
+                                          'CCP-EM | Refmac5',
+                                          message)
+
     def set_libg_selection(self):
         if self.args.libg.value:
             self.libg_selection_input.show()
@@ -904,9 +982,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                 arg_name='numberCPUsOrNodes',
                 args=self.args)
             self.args_widget.args_layout.insertWidget(5, self.numberCPUsOrNodes)
-###
-
-
 
             # Resolution cutoff for Refmac DC
 #            self.cutoff_input = window_utils.NumberArgInput(
@@ -916,12 +991,11 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
 #                required=True)
 #            self.args_widget.args_layout.insertWidget(4, self.cutoff_input)
 
-###
             self.find_in_map_input.hide()
             self.reference_map_input.hide()
             self.external_restraints_frame.hide()
             self.validation_frame.hide()
-###
+
         else:
             if hasattr(self, 'datasets_input'):
                 self.datasets_input.deleteLater()
@@ -930,9 +1004,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             if hasattr(self, 'numberCPUsOrNodes'):
                 self.numberCPUsOrNodes.deleteLater()
 
-
-#            if hasattr(self, 'cutoff_input'):
-#                self.cutoff_input.deleteLater()
             # Input pdb
             self.pdb_input = window_utils.FileArgInput(
                 parent=self,
@@ -941,7 +1012,18 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                 label='Input PDB',
                 file_types=ccpem_file_types.pdb_ext,
                 required=True)
-            self.args_widget.args_layout.insertWidget(3, self.pdb_input)
+            self.args_widget.args_layout.insertWidget(2, self.pdb_input)
+
+            # -> Input ligand cif library
+            self.lib_input = window_utils.FileArgInput(
+                parent=self,
+                label='Input ligand',
+                arg_name='lib_in',
+                args=self.args,
+                file_types=ccpem_file_types.lib_ext,
+                required=False)
+            self.args_widget.args_layout.insertWidget(3, self.lib_input)
+
             # Input map
             self.map_input = window_utils.FileArgInput(
                 parent=self,
@@ -953,6 +1035,7 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             self.map_input.value_line.textChanged.connect(
                 self.set_reference_map)
             self.args_widget.args_layout.insertWidget(4, self.map_input)
+
             # Resolution
             self.resolution_input = window_utils.NumberArgInput(
                     parent=self,
@@ -960,12 +1043,10 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                     args=self.args,
                     required=True)
             self.args_widget.args_layout.insertWidget(5, self.resolution_input)
-###
             self.find_in_map_input.show()
             self.reference_map_input.show()
             self.external_restraints_frame.button.show()
             self.validation_frame.button.show()
-###
 
     def set_rv_ui(self):
         '''
@@ -985,6 +1066,7 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             self.results_dock.setToolTip('Results overview')
             self.results_dock.setWidget(self.rv_view)
             self.tabifyDockWidget(self.setup_dock, self.results_dock)
+            self.results_dock.show()
             self.results_dock.raise_()
 
     def handle_toolbar_run(self):
@@ -1027,11 +1109,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                 file_type='pdb',
                 description=self.args.start_pdb.help,
                 selected=True)
-#            self.launcher.add_file(
-#                arg_name='input_restraints_path',
-#                file_type='standard',
-#                description=self.args.input_restraints_path.help,
-#                selected=True)
         self.launcher_dock.show()
 
 
@@ -1041,20 +1118,12 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         pdb and experimental map.
         '''
         # Refined model
-        if self.task.args.local_refinement_on.value:
-            if hasattr(self.task, 'process_shift_back'):
-                self.launcher.add_file(
-                    path=self.task.process_shift_back.pdbout_path,
-                    file_type='pdb',
-                    description='Refined PDB file',
-                    selected=True)
-        else:
-            if hasattr(self.task, 'process_refine'):
-                self.launcher.add_file(
-                    path=self.task.process_refine.pdbout_path,
-                    file_type='pdb',
-                    description='Refined PDB file',
-                    selected=True)
+        if hasattr(self.task, 'process_refine'):
+            self.launcher.add_file(
+                path=self.task.process_refine.pdbout_path,
+                file_type='pdb',
+                description='Refined PDB file',
+                selected=True)
         self.launcher.set_tree_view()
         self.launcher_dock.raise_()
         self.launcher_dock.show()
