@@ -6,12 +6,13 @@
 #     A copy of the CCP-EM licence can be obtained by writing to the
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
 #
-
 '''
 Task window for TEMPy global scores.
 '''
 import os
+
 from PyQt4 import QtGui, QtCore, QtWebKit
+
 from ccpem_gui.utils import window_utils
 from ccpem_core.ccpem_utils import ccpem_file_types
 from ccpem_core.tasks.tempy.scores import scores_task
@@ -22,6 +23,8 @@ from ccpem_core import chimera_scripts
 from ccpem_core.settings import which
 from ccpem_core.process_manager import job_register
 from ccpem_gui.project_database import sqlite_project_database
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks.tempy import scores as test_data
 
 
 class PBBDatasets(object):
@@ -238,10 +241,13 @@ class MultiPDBInput(QtGui.QWidget):
             child = children[0]
             self.pdbs_arg.value = child.dataset.pdb_path
 
+
 class GlobScoreWindow(window_utils.CCPEMTaskWindow):
     '''
     TEMPy global scores window.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args.json')
+
     def __init__(self,
                  task,
                  parent=None):
@@ -269,18 +275,19 @@ class GlobScoreWindow(window_utils.CCPEMTaskWindow):
             required=True,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.map_input)
-        #set map process task button
         self.task.mapprocess_task = None
-        self.mp_button = QtGui.QRadioButton('Process input map')
-        self.mp_button.setToolTip('Run pre-processing job to apply filters, masks, downsampling, etc')
-        self.args_widget.args_layout.addWidget(self.mp_button)
-        self.mp_button.clicked.connect(self.handle_mapprocess_task)
-        self.mp_button.setEnabled(False)
-        if self.args.map_path.value is not None and \
-            os.path.isfile(self.args.map_path.value):
-                self.add_mapprocess_button()
-        self.map_input.select_button.clicked.connect(
-                                    self.add_mapprocess_button)
+#         #set map process task button
+#         self.task.mapprocess_task = None
+#         self.mp_button = QtGui.QRadioButton('Process input map')
+#         self.mp_button.setToolTip('Run pre-processing job to apply filters, masks, downsampling, etc')
+#         self.args_widget.args_layout.addWidget(self.mp_button)
+#         self.mp_button.clicked.connect(self.handle_mapprocess_task)
+#         self.mp_button.setEnabled(False)
+#         if self.args.map_path.value is not None and \
+#             os.path.isfile(self.args.map_path.value):
+#                 self.add_mapprocess_button()
+#         self.map_input.select_button.clicked.connect(
+#                                     self.add_mapprocess_button)
         self.task.map_input = self.map_input
 
         # Map resolution
@@ -290,7 +297,7 @@ class GlobScoreWindow(window_utils.CCPEMTaskWindow):
             required=True,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.map_resolution)
-        self.map_resolution.value_line.editingFinished.connect(self.check_processed_map)
+#         self.map_resolution.value_line.editingFinished.connect(self.check_processed_map)
         # Input PDBs
         self.input_pdbs = MultiPDBInput(
             group_label='Input PDB(s)',
@@ -395,8 +402,11 @@ class GlobScoreWindow(window_utils.CCPEMTaskWindow):
             str(pdb_str))
         arg_list_chimera = ['--script', '%s' % (chimera_command)]
         process = QtCore.QProcess()
-        self.chimera_bin = which('chimera')
-        process.startDetached(self.chimera_bin, arg_list_chimera)
+        chimera_bin = which('chimera')
+        if chimera_bin is None:
+            print 'Chimera executable not found (add executable to system PATH)'
+        else:
+            process.startDetached(chimera_bin, arg_list_chimera)
             
     def set_chimera_button(self):
         #view in chimera
@@ -433,6 +443,7 @@ class GlobScoreWindow(window_utils.CCPEMTaskWindow):
             self.results_dock.setWidget(results_dock_widget)#self.rv_view)
             self.tabifyDockWidget(self.setup_dock, self.results_dock)
             results_dock_layout.addWidget(self.rv_view)
+            self.results_dock.show()
             self.results_dock.raise_()
             
     def set_bokeh_ui(self):
@@ -450,6 +461,7 @@ class GlobScoreWindow(window_utils.CCPEMTaskWindow):
             #self.results_dock.setToolTip('Results overview')
             self.results_dock.setWidget(self.rv_view)
             self.tabifyDockWidget(self.setup_dock, self.results_dock)
+            self.results_dock.show()
             self.results_dock.raise_()
 
     def handle_toolbar_run(self):
