@@ -64,7 +64,8 @@ class CCPEMLauncher(QtGui.QGroupBox):
     '''
     all_mg_progs = {'ccp4mg':'CCP4mg',
                     'coot':'Coot',
-                    'chimera':'Chimera'}
+                    'chimera':'Chimera',
+                    'pymol': 'PyMOL'}
 
     def __init__(self,
                  parent,
@@ -106,12 +107,14 @@ class CCPEMLauncher(QtGui.QGroupBox):
             menu.addAction('Chimera', self.set_chimera_default)
         if 'CCP4mg' in self.mg_progs:
             menu.addAction('CCP4mg', self.set_ccp4mg_default)
+        if 'PyMOL' in self.mg_progs:
+            menu.addAction('PyMOL', self.set_pymol_default)
         self.mg_button.setMenu(menu)
         self.button_box.addButton(self.mg_button, self.button_box.ApplyRole)
         # Get default MG program from Qt global settings
         if mg_default is None:
             q_settings = QtCore.QSettings()
-            mg_default = q_settings.value('MG_DEFAULT_KEY').toString()
+            mg_default = q_settings.value('MG_DEFAULT_KEY', defaultValue='').toString()
             if mg_default == '':
                 mg_default = 'Coot'
 
@@ -162,6 +165,9 @@ class CCPEMLauncher(QtGui.QGroupBox):
     def set_ccp4mg_default(self):
         self.set_mg_default('CCP4mg')
 
+    def set_pymol_default(self):
+        self.set_mg_default('PyMOL')
+
     def add_file(self,
                  description='',
                  file_type='standard',
@@ -318,6 +324,8 @@ class CCPEMLauncher(QtGui.QGroupBox):
                 self.run_selected_chimera()
             elif mg_viewer == 'CCP4mg':
                 self.run_selected_ccp4mg()
+            elif mg_viewer == 'PyMOL':
+                self.run_selected_pymol()
 
     def run_selected_coot(self):
         if self.task_window is not None:
@@ -340,10 +348,10 @@ class CCPEMLauncher(QtGui.QGroupBox):
             args.append(pdb)
         for map_ in self.mg_files['map']:
             args.append(map_)
-        for mtz in self.mg_files['mtz']:
-            args.append(mtz)
         for cif in self.mg_files['cif']:
             args.append(cif)
+        if len(self.mg_files['mtz']) > 0:
+            print 'Warning: cannot open MTZ files in Chimera'
         if self.task_window is not None:
             if self.task_window.run_chimera_custom() != NotImplemented:
                 return
@@ -364,3 +372,15 @@ class CCPEMLauncher(QtGui.QGroupBox):
         for cif in self.mg_files['cif']:
             args.append(cif)
         gui_process.run_ccp4mg(args=args)
+
+    def run_selected_pymol(self):
+        args = []
+        for pdb in self.mg_files['pdb']:
+            args.append(pdb)
+        for map_ in self.mg_files['map']:
+            args.append(map_)
+        for mtz in self.mg_files['mtz']:
+            args.append(mtz)
+        for cif in self.mg_files['cif']:
+            args.append(cif)
+        gui_process.run_pymol(args=args)
