@@ -1,19 +1,11 @@
 import sys
 import os
 import subprocess
+
 from ccpem_core import ccpem_utils
 from ccpem_core import settings
 
 
-def get_ccpem_bin_location(attribute):
-    args = settings.get_ccpem_settings()
-    if getattr(args, attribute, None) is not None:
-        return getattr(args, attribute, None).value
-    else:
-        return None
-    return None
-
-
 def get_linux_terminal_command():
     command = settings.which('gnome-terminal')
     if command is None:
@@ -54,55 +46,68 @@ def run_terminal(working_directory=None):
     else:
         print 'Window terminal launch not supported yet...'
 
-def run_coot(args=[]):
+
+def run_coot(args=None):
     '''
     Run coot with optional command line args e.g. :
     coot --pdb=foo.pdb --map=foo.mrc
+
+    args must be a list or None
     '''
     coot_command = settings.which('coot')
     if coot_command is None:
         text = 'Warning: Coot not found'
         ccpem_utils.print_error(message=text)
     else:
+        # Run Coot in CCP4 mode, which puts the output in a separate window
+        # rather than on the console
+        full_args = ['--ccp4-mode']
+        if args is not None:
+            full_args += args
         run_detatched_process(command=coot_command,
-                              args=args)
+                              args=full_args)
 
 
-def run_ccp4mg(args=[]):
+def run_ccp4mg(args=None):
     '''
     Run ccp4mg with optional command line args e.g. :
     ccp4mg -pdb foo.pdb -map foo.map
     N.B. ccp4mg doesn't currently automatically recognise .mrc extension.
+
+    args must be a list or None
     '''
     ccp4mg_command = settings.which('ccp4mg')
     if ccp4mg_command is None:
         text = 'Warning: CCP4MG not found'
         ccpem_utils.print_error(message=text)
     else:
+        if args is None:
+            args = []
         run_detatched_process(command=ccp4mg_command,
                               args=args)
 
 
-def run_chimera(args=[]):
+def run_chimera(args=None):
     '''
     Run chimera with optional command line args e.g. :
     chimera foo.pdb foo.map
+
+    args must be a list or None
     '''
     chimera_command = settings.which('chimera')
     if chimera_command is None:
         text = 'Warning: Chimera not found'
         ccpem_utils.print_error(message=text)
     else:
+        if args is None:
+            args = []
         run_detatched_process(command=chimera_command,
                               args=args)
 
 
-def run_pymol(args=[]):
+def run_pymol(args=None):
     '''
-    Run PyMOL with optional command line args e.g. :
-    pymol foo.pdb foo.ccp4
-    N.B. ccp4mg doesn't currently automatically recognise .mrc or .map
-    extensions.
+    Run PyMOL with optional command line args
     '''
     pymol_command = settings.which('pymol')
     if pymol_command is None:
@@ -110,54 +115,33 @@ def run_pymol(args=[]):
         ccpem_utils.print_error(message=text)
     else:
         run_detatched_process(command=pymol_command,
-                              args=[])
+                              args=args)
 
 
-def run_relion():
+def run_relion_display():
     '''
-    Run relion GUI.
+    Run "relion_display --gui" to view map files
     '''
-    relion_command = get_ccpem_bin_location(attribute='relion_bin')
-    # Else try and find command
-    if relion_command is None:
-        relion_command = settings.which('relion')
-    if relion_command is None:
-        text = 'Warning: RELION not found'
+    relion_display_command = settings.which('relion_display')
+    if relion_display_command is None:
+        text = 'Warning: relion_display not found'
         ccpem_utils.print_error(message=text)
     else:
-        run_detatched_process(command=relion_command,
-                              args=[])
+        run_detatched_process(command=relion_display_command, args=['--gui'])
 
 
-def run_detatched_process(command, args=[], verbose=True):
+def run_detatched_process(command, args=None, cwd=None):
+    if args is None:
+        args = []
     assert command is not None
     assert type(args) is type([])
-    if verbose:
-        command_str = ccpem_utils.print_header(message='CCP-EM toolbar launch',
-                                               return_str=True)
-        command_str += ccpem_utils.print_sub_sub_header(message='Command',
-                                                        return_str=True)
-        command_str += command
-        for arg in args:
-            command_str += ' '
-            command_str += arg
-        command_str += '\n'
-        command_str += ccpem_utils.return_footer()
 
     # Run with python subprocess to allow environment to be set.  This is
-    # required to reset PYTHONPATH to remove ccpem python libraries which 
-    # can cause conflicts.
+    # required to reset PYTHONPATH and LD_LIBRARY_PATH to remove ccpem python
+    # and modeller libraries which can cause conflicts.
     env = os.environ.copy()
     env.pop('PYTHONPATH', None)
+    env.pop('LD_LIBRARY_PATH', None)
+
     command = [command] + args
-    subprocess.Popen(command,
-                     env=env)
-
-def main():
-    '''
-    For testing.
-    '''
-    pass
-
-if __name__ == '__main__':
-    main()
+    subprocess.Popen(command, env=env, cwd=cwd)
