@@ -139,6 +139,10 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
     '''
     Base Class for Task Windows
     '''
+    @property
+    def gui_test_args(self):
+        raise NotImplementedError("This property should be set in all sub-classes")
+
     def __init__(self,
                  parent=None,
                  task=None):
@@ -168,6 +172,10 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         self.launcher = ccpem_launcher_widget.CCPEMLauncher(
             parent=self)
         self.set_args()
+        # Add stretch to end of args widget
+        self.args_widget.args_layout.addStretch()
+        # messes up MapProcess
+
         self.set_pipeline_ui()
         self.set_launcher_ui()
         if self.pipeline is not None:
@@ -335,6 +343,8 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         self.tb_clone_button.setToolTip(
             'Clone current settings into a new job')
         #
+        self.tool_bar.addSeparator()
+        #
         if settings.which(program='coot') is not None:
             coot_icon = os.path.join(icon_utils.get_other_icons_path(),
                                      'coot_32x32.png')
@@ -359,6 +369,16 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
                 'CCP4mg',
                 self.run_ccp4mg)
         #
+        if settings.which(program='pymol') is not None:
+            pymol_icon = os.path.join(icon_utils.get_other_icons_path(),
+                                      'pymol_32x32.png')
+            self.tb_pymol_button = self.tool_bar.addAction(
+                QtGui.QIcon(pymol_icon),
+                'PyMOL',
+                self.run_pymol)
+        #
+        self.tool_bar.addSeparator()
+        #
         terminal_icon = os.path.join(icon_utils.get_icons_path(),
                                      'font_awesome/terminal_32x32.png')
         self.tb_terminal_button = self.tool_bar.addAction(
@@ -375,6 +395,8 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
             self.run_file_browser)
         self.tb_browser_button.setEnabled(False)
         #
+        self.tool_bar.addSeparator()
+        #
         info_icon = os.path.join(icon_utils.get_icons_path(),
                                 'ccpem_icons/info_32x32.png')
         self.tb_info_button = self.tool_bar.addAction(
@@ -477,14 +499,12 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
     def run_ccp4mg_custom(self):
         return NotImplemented
 
-    def run_relion(self):
+    def run_pymol(self):
         '''
-        Run Relion
+        Run PyMOL viewer.
         '''
-        if hasattr(self, 'run_relion_custom'):
-            self.run_relion_custom()
-        else:
-            run_relion()
+        self.launcher.launch_mg_viewers(mg_viewer='PyMOL',
+                                        launch_mg_without_file=True)
 
     def run_info_dialog(self):
         '''
@@ -630,8 +650,8 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
             # pipelines should be like refmac
             try:
                 self.task.run_pipeline(run=False)
-            except:
-                TypeError
+            except TypeError:
+                pass
         self.check_job_status()
 
     def check_job_status(self):
@@ -651,8 +671,8 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
                 self.set_on_job_running()
 
     def set_on_job_running(self):
-        self.set_window_title()
         if self.status != 'running':
+            self.set_window_title()
             if self.pipeline is not None:
                 self.status_widget.set_running()
                 self.job_status_timer.start(500)
@@ -671,7 +691,7 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
                 if len(self.launcher.files) > 0:
                     self.launcher_dock.setVisible(True)
                     self.launcher.set_tree_view()
-        self.set_on_job_running_custom()
+                self.set_on_job_running_custom()
 
     def set_on_job_running_custom(self):
         pass
@@ -1090,6 +1110,35 @@ class TitleArgInput(CCPEMArgBaseWidget):
     def disable(self):
         self.value_line.setEnabled(False)
 
+class StrArgInput(CCPEMArgBaseWidget):
+    def __init__(self,
+                 parent,
+                 arg_name,
+                 args,
+                 label=None,
+                 label_width=150,
+                 tooltip_text=None,
+                 required=False):
+        super(StrArgInput, self).__init__(
+            parent=parent,
+            arg_name=arg_name,
+            args=args,
+            label=label,
+            label_width=label_width,
+            tooltip_text=tooltip_text,
+            required=required)
+        # Keep reference to task window
+        task_window = self.parent()
+        # Set value display
+        self.value_line = QtGui.QLineEdit()
+        self.grid_layout.addWidget(self.value_line, 0, 1)
+        # Set value line
+        self.value_line.editingFinished.connect(self.on_edit_finished)
+        self.set_arg_value(value=self.action.value)
+
+    def disable(self):
+        self.value_line.setEnabled(False)
+
 class ListArgInput(CCPEMArgBaseWidget):
     '''
     List arg input.  Takes list of values seperated by a space or comma
