@@ -23,7 +23,7 @@ def main(args_path):
     assert os.path.exists(args['input_pdb'])
     assert os.path.exists(args['output_dssp'])
     # Set output directory
-    output_path = os.path.join(args['job_location'], 'job_data')
+    output_path = args['job_location']
     if output_path is not None:
         ccpem_utils.check_directory_and_make(directory=output_path)
         os.chdir(output_path)
