@@ -1,19 +1,3 @@
-                                                                                          
-!=******************************************************************************
-!=* ShapeM - Programs                                     AUTHOR: A.ROSEMAN    *
-!=*                                                                            *
-!=*                                                                            *
-!=* ShapeM is a set of software programs to match 3D density object shapes.    *
-!=* Specifically, it has been designed to locate known molecular shapes within *
-!=* molecular densities of larger complexes determined by cryoEM. It was       *
-                                                                                  
-!=******************************************************************************
-!=* ShapeM - Programs                                     AUTHOR: A.ROSEMAN    *
-!=*                                                                            *
-!=*                                                                            *
-!=* ShapeM is a set of software programs to match 3D density object shapes.    *
-!=* Specifically, it has been designed to locate known molecular shapes within *
-!=* molecular densities of larger complexes determined by cryoEM. It was       *
 !=******************************************************************************
 !=* ShapeM - Programs              		          AUTHOR: A.ROSEMAN    *
 !=*                                    		                               *
@@ -61,9 +45,6 @@
 ! mod to dock densities, therefore not inverse transformation
 !mod so no wrapparounds in density rotn
 
-!v1.2 origin to match V1.2 search density prog.
-!v1.3 extracted densities will match the sobj
-
 !C input: 
 !C       mrc density map file - fit object
 !c       mask file
@@ -71,24 +52,12 @@
 !C       run version key.
 !C       sampling of the map used for the search
 !C	 range of solutions to generate
-
 !C       size of extracted objects.  Keep at the target map size for convenience.
-! v1.2 no, now match extracgted objects to size of the seachobject/mask, by default.
 
 
-
-!C output: mrc files corresponding to searchdoc keys.
+!C output: pdb files corresponding to searchdoc keys.
 !C  
 
-!V1.2
-! window out boxes at centres given in searchdock files.
-! apply reverse rotatoins about the centres of these boxes.
-! these are the hits then aligned to the original search file.
-! note: make the masked ones and not masked ones. Will be useful. 
-
-!v1.3 make extracted object that are exactly aligned to the sobj.
-
-
 
 	program ShapeMXtB
 
@@ -98,7 +67,7 @@
         
         real sampling
         real psi,theta,phi
-        character*40 pdbfile,outfile2,filename,filename2,maskfilename,sobjfilename
+        character*40 pdbfile,outfile2,filename,filename2,maskfilename
         character*24 space1
  	character*6 head
 	character*10 space2
@@ -115,7 +84,7 @@
       	
 !C sampling for position search, in voxels      		
         integer  counter,counter2,zx,zy,zz,r1,r2,N
-	integer nx3,ny3,nz3,lx,ly,lz
+	integer nx3,ny3,nz3
 
 	integer size,sizeo2,sizem1,sx,fx,sy,fy,sz,fz
 	real, dimension (:,:,:), allocatable :: map, obj, rotobj,mask       
@@ -128,29 +97,22 @@
 	
 
       
-      write(6,*) 'ShapeM-XtB, v1.3d'
-      write(6,*) '=================='
+      write(6,*) 'ShapeM-XtB'
+      write(6,*) '=========='
     
       write(6,*)
 
-	print*,'Enter the EM map filename.'
-	read*,filename
-	print*, filename
-
-	print*,'Enter the sampling of the map (A/pixel)'
-	read*, sampling
-
 !C 1. read coords
       write (6,*) 'Enter the filename of the search object map    '
-      read (5,10) sobjfilename
+      read (5,10) filename
 10    format(A40)
-      print*, sobjfilename
+      print*, filename
 
-!	print*,"Enter the mask map filename. (This is mask just for presentation, it won't affect the origin of rotation.)";
-!	read*,maskfilename
+	print*,"Enter the mask map filename. (This is mask just for presentation, it won't affect the origin of rotation.)"
+	read*,maskfilename
 	
-!	print*,'Enter a threshold for the mask map.'
-!	read*,maskth
+	print*,'Enter a threshold for the mask map.'
+	read*,maskth
 	
 
 
@@ -162,8 +124,8 @@
        pdbfile = 'com'//num(runcode)//'.pdb'       
 ! pdb file com used to record origin of rotations.
 
-!      write (6,*) 'Enter the sampling in Angstoms.'
-!      read*,sampling
+      write (6,*) 'Enter the sampling in Angstoms.'
+      read*,sampling
 
 !      write (6,*) 'Enter the filename of the doc file    '
 !      read (5,10) filename2
@@ -178,10 +140,10 @@
       print *, r1,r2
 
 
- !     write (6,*) 'Enter a size (in pixels) for the extracted objects.'
- !     read *, size
- !     print*,size
- ! v1.3 .. make match the sobj in size.   
+      write (6,*) 'Enter a size (in pixels) for the extracted objects.'
+      read *, size
+      print*,size
+    
 
  	print*, pdbfile
 
@@ -205,23 +167,8 @@
 	comy=comy/sampling
 	comz=comz/sampling
 
+
         PRINT*,'COM of sobj at ',comx,comy,comz,' pixels.'
-
-! calc nearest integer posn of com
-! don't really need this. by definition the com will be the centre of the boxes windowed.
-! actually this is all not neccessary. wan't objects to line up with the sobj, therefore the centre must be centre of sobj box, not the com,
-! this will now be V1.3
-! give a warning that sobj must be rotatable within own box, i.e. write out when corners zeroed, to show what could be cut off. 
-! apply the corners cuttoff in the search. 
-! or..write out a version of the sobj centered by com.
-
-
-!v1.3 make nearest integer   
-
-	comx=int((comx/1)+.5)
-	comy=int((comy/1)+.5)
-	comz=int((comz/1)+.5)
-	print*,comx,comy,comz
    
 !C ***************************************************
 
@@ -235,18 +182,6 @@
 
 !C ***********************************************
 !C open input from MRC format file
-
-        
-        CALL IMOPEN(2,sobjfilename,'RO')
-        CALL IRDHDR(2,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
-
-	lx=nx
-	ly=ny
-	lz=nz
-
-        if ((lx.ne.ly).or.(lx.ne.lz))  stop "Search object map must be cubic."
-!        CALL IMCLOSE(2)
-
         
         CALL IMOPEN(1,filename,'RO')
         CALL IRDHDR(1,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
@@ -259,21 +194,17 @@
         nxp2=nx+2
         
 
-!centre of small box, spider convention in mrc type file
-        cx=int(float(lx)/2.)
-        cy=int(float(ly)/2.)
-        cz=int(float(lz)/2.)
+
+        cx=int(float(nx)/2.)+1
+        cy=int(float(ny)/2.)+1
+        cz=int(float(nz)/2.)+1
 
 
 
 !C allocate  image_files 
-!        allocate (map(0:nxp1+lx,0:nym1+ly,0:nzm1+lz),mask(0:nxp1,0:nym1,0:nzm1) )    
         allocate (map(0:nxp1,0:nym1,0:nzm1),mask(0:nxp1,0:nym1,0:nzm1) )    
-        map=0
        
-    !    bnx=nx+lx
-     !   bny=ny+ly
-!	bnz=nz+lz
+       
 
         CALL READMRCMAP(1,filename,map,nx,ny,nz,T,F,T,err) !read, is open, dont close, add 2 bytes
         
@@ -286,28 +217,28 @@
 	newxyz(1:3)=size
 	
 
-!        CALL IMOPEN(3,maskfilename,'RO')
-!        CALL IRDHDR(3,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
+        CALL IMOPEN(3,maskfilename,'RO')
+        CALL IRDHDR(3,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
 
-!        CALL READMRCMAP(3,maskfilename,mask,nx,ny,nz,T,F,T,err) !read, not open,  close, add 2 bytes  
+        CALL READMRCMAP(3,maskfilename,mask,nx,ny,nz,T,F,T,err) !read, not open,  close, add 2 bytes  
      
 !make mask binary
 
 ! vs maskth
-!	where (mask.lt.maskth) 
-!			  mask=0.0
-!	elsewhere
-!			  mask=1.0
-!	end where
+	where (mask.lt.maskth) 
+			  mask=0.0
+	elsewhere
+			  mask=1.0
+	end where
 
- !       print*,"Sum in mask = ", sum(mask)
+        print*,"Sum in mask = ", sum(mask)
 
- !       map=map*mask
+        map=map*mask
 
- !       print*,"Sum in masked map = ", sum(map)
+        print*,"Sum in masked map = ", sum(map)
 
  
-         allocate (obj(0:lx+1,0:ly-1,0:lz-1),rotobj(0:lx+1,0:ly-1,0:lz-1))      
+         allocate (obj(0:nxp1,0:nym1,0:nzm1),rotobj(0:nxp1,0:nym1,0:nzm1))      
          rotobj=1
      
               
@@ -315,50 +246,38 @@
 !C write top set of hits here
 	count=0
 	
-        !        comx=comx+cx
-	 !       comy=comy+cy
-          !      comz=comz+cz
+                comx=comx+cx
+	        comy=comy+cy
+                comz=comz+cz
 
 
 	do N=1,r2
 		count=count+1
 	
 		read (4,510) ji1,x,y,z,angnum,b,psi,theta,phi,j2,ccc
-		 print*,
+		 print*,35
 		 
-		shx=x-comx+cx
-		shy=y-comy+cy
-		shz=z-comz+cz
+		shx=-x
+		shy=-y
+		shz=-z
+
 
-		if (ji1.gt.r2) cycle
 		if (ji1.ge.r1) then
                	       
-			sx=int(lx/2.)
-			sy=int(ly/2.)
-			sz=int(lz/2.)
-			fx=int((lx/2.) +0.5)-1
-			fy=int((ly/2.) +0.5)-1
-			fz=int((lz/2.) +0.5)-1
-
-			print*,shx,sx,fx,shy,sy,fy,shz,sz,fz
-			obj=0
-		!	obj(0:lx-1,0:ly-1,0:lz-1)=map(shx-sx:shx+fx,shy-sy:shy+fy,shz-sz:shz+fz)
+			obj=map
+			call rotobjNI(obj,rotobj,psi,theta,phi,nx,ny,nz,comx,comy,comz)
 		
-   call window(obj,map,lx,ly,lz,nx,ny,nz,0,shx,shy,shz)
-   call rotobjI(obj,rotobj,psi,theta,phi,lx,ly,lz,comx,comy,comz)
-		! do inverse rotn
-
-!                        rotobj= eoshift(rotobj,shift=shx,boundary=0.0,dim=1)
- !                       rotobj= eoshift(rotobj,shift=shy,boundary=0.0,dim=2)
-  !                      rotobj= eoshift(rotobj,shift=shz,boundary=0.0,dim=3)
+                        rotobj= eoshift(rotobj,shift=shx,boundary=0.0,dim=1)
+                        rotobj= eoshift(rotobj,shift=shy,boundary=0.0,dim=2)
+                        rotobj= eoshift(rotobj,shift=shz,boundary=0.0,dim=3)
 
 				         
 			CALL IMOPEN(9,'maphit-run'//num(runcode)//'-'//num(ji1)//'.mrc','UNKNOWN')
-        		CALL ITRHDR(9,2)
-       			CALL WRITEMRCMAP(9,rotobj,lx,ly,lz,sampling,err) !open already, close it, subtract 2 from nx
+        		CALL ITRHDR(9,1)
+       			CALL WRITEMRCMAP(9,rotobj,nx,ny,nz,sampling,err) !open already, close it, subtract 2 from nx
 ! call ialsiz ? 
 		endif
-        
+
 	end do
 	print*,count
  
@@ -381,6 +300,7 @@
         print*,'error writing pdbfile.'
         stop
            
+
     
 999    continue
        print*,'Program finished O.K.'
@@ -393,13 +313,12 @@
 
 	contains         
                 
-        SUBROUTINE rotobjI(obj,therotobj,psi,theta,phi,nx,ny,nz,cx,cy,cz)
+        SUBROUTINE rotobjNI(obj,therotobj,psi,theta,phi,nx,ny,nz,cx,cy,cz)
            
 
 !c sub to apply rotation about centre of map to map object 
 !c convert rotations to matrix form
 !C spider convention for euler angles to mat
-! invert
 
 ! the object maps are nxp1,ny,nz in size
 !rotn centre is nx/2,ny/2,nz/2
@@ -414,7 +333,6 @@
         real val,b,val2
        
         therotobj=0
-
         nxm1=nx-1
         nym1=ny-1
         nzm1=nz-1
@@ -460,8 +378,6 @@
         call matmult(mata,mat,matd)
 
 
-        mate=transpose(matd) !inverse of rotation is done
-
         do iz=0,nzm1
                 do iy=0,nym1
                         do ix=0,nxm1
@@ -472,7 +388,7 @@
 
                                 val2=obj(ix,iy,iz)
                                                              
-				 call matmult2(x,y,z,mate,cx,cy,cz)      !transform coords by rotn
+				 call matmult2(x,y,z,matd,cx,cy,cz)      !transform coords by rotn
 			
 
                                  call interpo3(therotobj,nx,ny,nz,x,y,z,val2)            !interpo density at newposn to new map.
@@ -484,7 +400,7 @@
        
         return
 
-        END SUBROUTINE rotobjI
+        END SUBROUTINE rotobjNI
 
 
         subroutine interpo3(map,nx,ny,nz,sx,sy,sz,val)
@@ -644,149 +560,9 @@
  
       END SUBROUTINE WRITEMRCMAP
 
-
-      SUBROUTINE WRITEMRCMAP2(stream,map,x,y,z,sampling,err)
-      Use  mrc_image
-      REAL val,sampling
-      
-      integer x,y,z,err,stream,ix,iy,iz,newxyz(3)
-      real map(0:x+1,0:y-1,0:z-1)
-
-      print*,'write_mrcimage'         
-	newxyz(1)=x
-	newxyz(2)=y
-	newxyz(3)=z
-	
-        CALL IALSIZ(STREAM,newxyz,NXYZST)  
-        
-      print*,NX,NY,NZ  
-!     write file 
-
-      DMIN =  1.E10
-      DMAX = -1.E10
-      DOUBLMEAN = 0.0
-
-      DO 1450 IZ = 0,Z-1
-      DO 1450 IY = 0,Y-1
-            
-            DO 1400 IX = 0,X-1
-     
-                val = map(IX,IY,IZ)
-                ALINE(IX+1) = val
-                
-                DOUBLMEAN = DOUBLMEAN + val         
-                IF (val .LT. DMIN) DMIN = val
-                IF (val .GT. DMAX) DMAX = val
-
-1400         CONTINUE   
-
-      CALL IWRLIN(stream,ALINE)
-1450   CONTINUE
-      DMEAN = DOUBLMEAN/(NX*NY*NZ)
-
-      cell(1) = sampling *X
-      cell(2) = sampling *Y
-      cell(3) = sampling *Z
-      cell(4) = 90
-      cell(5) = 90
-      cell(6) = 90
-
-      CALL IALCEL(STREAM,CELL)  
-    
-      
-      CALL IWRHDR(stream,TITLE,-1,DMIN,DMAX,DMEAN)
-      CALL IMCLOSE(stream)
-      
-      return
-1999   STOP 'Error on file write.'
- 
-      END SUBROUTINE WRITEMRCMAP2
- 
-      subroutine window(smallmap,bigmap,lx,ly,lz,nx,ny,nz,border,cx,cy,cz)
-       integer lx,ly,lz,nx,ny,nz,border
-       integer cx,cy,cz
-       integer sx,fx,sy,fy,sz,fz
-       real smallmap(0:lx+1,0:ly-1,0:lz-1)
-       real bigmap(0:nx+1,0:ny-1,0:nz-1)
-       
-       smallmap=0
-       
-       sx=int(cx-int(lx/2.))
-       fx=int(cx+(int(lx/2.+0.5))-1)
-       sy=int(cy-int(ly/2.))
-       fy=int(cy+int(ly/2. +0.5)-1)
-       sz=int(cz-int(lz/2.))
-       fz=int(cz+int(lz/2.+0.5)-1)
-         
-	px=0
-	py=0
-	pz=0
-	qx=lx-1	
-	qy=ly-1	
-	qz=lz-1
-
-      
-
-       if ((sx.lt.0)) then  
-       			print*,'Warning: Region exceeds map boundary'
-			px=-sx
-       			sx=0
-       endif
-       			
-       if ((fx.gt.nx-1)) then 
-       			 print*,'Warning: Region exceeds map boundary'
-			 qx=(lx-(fx-(nx-1)))-1
-       			 fx=nx-1
-       endif
-       
-           
-       if ((sy.lt.0)) then  
-       			print*,'Warning: Region exceeds map boundary'
-			py=-sy       			
-			sy=0
-       endif
-       			
-       if ((fy.gt.ny-1)) then 
-       			 print*,'Warning: Region exceeds map boundary'
-			 qy=(ly-(fy-(ny-1)))-1
-       			 fy=ny-1
-       endif
-           
-       if ((sz.lt.0)) then  
-       			print*,'Warning: Region exceeds map boundary'
-			pz=-sz       			
-			sz=0
-       endif
-       			
-       if ((fz.gt.nz-1)) then 
-       			 print*,'Warning: Region exceeds map boundary'
-			qz=(lz-(fz-(nz-1)))-1       			 
-			fz=nz-1
-       endif
-    
-
-       smallmap(px:qx,py:qy,pz:qz)=bigmap(sx:fx,sy:fy,sz:fz)
-       print*,'window:',sx,fx,sy,fy,sz,fz
-   	smallmap(lx:lx+1,:,:)=0
-   
- !      smallmap(0:border-1,:,:)=0
-  !     smallmap(lx-border:lx+1,:,:)=0
-       
-   !    smallmap(:,0:border-1,:)=0
-    !   smallmap(:,ly-border:ly-1,:)=0
-       
-  !     smallmap(:,:,0:border-1)=0
-   !    smallmap(:,:,lz-border:lz-1)=0
-     
-       end subroutine window      
-
-
-  end program ShapeMXtB
+        end program ShapeMXtB
 
          
          
  
 
-! to do still : generalise windowing to avoid edge problems, use one of the window subroutines.
-
-!put in invert rotn
