@@ -42,9 +42,14 @@
 !=******************************************************************************
 !
 !
+!ShapeMv1.1, amr 8/5/15 handle smaller sobj and mask
+!v1.2 change cx,cy,cz to absolute centre in the std unit cell
+
 
 !ShapeMv1.0
 
+!ShapeMv1.0
+!v1.3c shift cccmap, circular
 
 
 ! 1. read map, search object, mask, angles
@@ -70,7 +75,7 @@
         Use  image_arrays2
         Use  mrc_image
         real, dimension (:,:,:), allocatable :: cccmaxmap,psimap,phimap,thetamap,scalemap
-        real, dimension (:,:,:), allocatable :: sobj,mask,lcfmask,pmask,commap
+        real, dimension (:,:,:), allocatable :: sobj,mask,lcfmask,pmask,commap,cmap
      
      	
 	real angles(99999,3),psi,theta,phi,val,STD
@@ -91,6 +96,7 @@
 	character*3 num
 	logical t,f
 	real x,y,z,maskth
+	integer lx,ly,lz,bnx,bny,bnz
 	integer nm8,numatoms
 	real*8 summap,sumcccs,sumnumccc,stdccc
 	real cx,cy,cz
@@ -99,13 +105,14 @@
 	real s1,s2,s3,iscale,omst,domega
 	integer sloop,ssteps
 	real comx,comy,comz,r
-	integer i,j,k
+	integer i,j,k,comix,comiy,comiz
+        character*2 box
 	
 	t=.true.
 	f=.false.
 
-        print*, 'ShapeM, V1.0'
-        print*, '============'
+        print*, 'ShapeM, V1.3c'
+        print*, '============='
 
 
 	print*,'Enter the EM map filename.'
@@ -134,6 +141,13 @@
 30      format (I3)
 
         pdbfile = 'com'//num(runcode)//'.pdb'       
+
+33	print*,'Origin of rotation at Center-of-mass of search object, or the Box center.  Type> C or B'
+	read*,box
+	if (((box.ne.'C') .and. (box .ne.'B')) .and. ((box.ne.'c') .and. (box .ne.'b'))) goto 33	
+	
+        
+
 ! pdb file com used to record origin of rotations.
  
 
@@ -154,21 +168,43 @@
 	nxm1=nx-1
         nym1=ny-1
         nzm1=nz-1
-        
+
+        bnx=nx
+        bny=ny
+        bnz=nz
+
         nxp1=nx+1
         nxp2=nx+2
         
 !C allocate  image_files 
         allocate (map(0:nxp1,0:nym1,0:nzm1), sobj(0:nxp1,0:nym1,0:nzm1))
         allocate (mask(0:nxp1,0:nym1,0:nzm1),pmask(0:nxp1,0:nym1,0:nzm1))
-        allocate (commap(0:nxp1,0:nym1,0:nzm1))
+        allocate (commap(0:nxp1,0:nym1,0:nzm1),cmap(0:nxm1,0:nym1,0:nzm1))
         
         allocate (rotsobj(0:nxp1,0:nym1,0:nzm1),rotmask(0:nxp1,0:nym1,0:nzm1))
         allocate (AA(0:nxp1,0:nym1,0:nzm1))
 	   
         CALL READMRCMAP(1,filename,map,nx,ny,nz,T,F,T,err) !read, is open, dont close, add 2 bytes
-        CALL READMRCMAP(2,sobjfilename,sobj,nx,ny,nz,F,T,T,err) !read, not open,  close, add 2 bytes         
-        CALL READMRCMAP(3,maskfilename,mask,nx,ny,nz,F,T,T,err) !read, not open,  close, add 2 bytes  
+
+
+        CALL IMOPEN(2,sobjfilename,'RO')
+        CALL IRDHDR(2,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
+	lx=nx
+	ly=ny
+	lz=nz
+
+
+        CALL READMRCMAP2(2,sobjfilename,sobj,bnx,bny,bnz,lx,ly,lz,F,T,T,err) !read, is open,  close, add 2 bytes 
+
+
+
+        CALL IMOPEN(2,maskfilename,'RO')
+        CALL IRDHDR(2,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
+        CALL READMRCMAP2(2,maskfilename,mask,bnx,bny,bnz,lx,ly,lz,F,T,T,err) !read, is open,  close, add 2 bytes  
+	
+
+        CALL IRDHDR(1,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
+
 
 !make mask binary
 
@@ -190,20 +226,21 @@
         commap=sobj
         where (sobj.lt.0) commap=0  ! eliminate negative regions
 
-
-	cx=nx/2+1
-	cy=ny/2+1
-	cz=nz/2+1
+! v1.3 on 27-5-15
+	cx=lx/2+1
+	cy=ly/2+1
+	cz=lz/2+1
 	r=nx/2-1
 
+! v1.3 on 27-5-15
 !	zero corners
-	do I=1,nx
-	 do j=1,ny
-	   do k=1,nz
-	        if (radius(I,j,k,cx,cy,cz) .gt. r ) commap(i,j,k)=0.0
-	   enddo
-	 enddo
-	enddo
+!	do I=0,nx-1
+!	 do j=0,ny-1
+!	   do k=0,nz-1
+!	        if (radius(I,j,k,cx,cy,cz) .gt. r ) commap(i,j,k)=0.0
+!	   enddo
+!	 enddo
+!	enddo
 
 !       print*,"Mean of commap=",meanval(commap)
         print*,"Sum of commap=",sum(commap),minval(commap),maxval(commap)
@@ -214,12 +251,16 @@
 	comz=0
 
 !	forall (I=1:nx, j=1:ny,k=1:nz)
-	do I=1,nx
-	 do j=1,ny
-	   do k=1,nz
- 		comx = comx + commap(i,j,k) * (float(i)-cx)
- 		comy = comy + commap(i,j,k) * (float(j)-cy)
- 		comz = comz + commap(i,j,k) * (float(k)-cz)
+	do I=0,nx-1
+	 do j=0,ny-1
+	   do k=0,nz-1
+ 		comx = comx + commap(i,j,k) * (float(i))
+ 		comy = comy + commap(i,j,k) * (float(j))
+ 		comz = comz + commap(i,j,k) * (float(k))
+!v1.2
+
+
+
 	   enddo
 	  enddo
 	enddo
@@ -228,6 +269,15 @@
         comz=comz/sum(commap)
 
 
+
+
+
+	if ((box.eq.'B') .or. (box .eq.'b')) then
+		comx=cx
+		comy=cy
+		comz=cz
+	endif
+
 !save the com to pdbfile
 
 	head = "ATOM  "
@@ -314,7 +364,8 @@
 		print*,nm,nm8
 
 		val=minval(map(0:nxm1,0:nym1,0:nzm1))
-!		map(0:nxm1,0:nym1,0:nzm1)=map(0:nxm1,0:nym1,0:nzm1)-val
+		print*,val
+		map(0:nxm1,0:nym1,0:nzm1)=map(0:nxm1,0:nym1,0:nzm1)-val
 		call msdset(map,nx,ny,nz,nm8,val,err)
 		print*,nm,nm8		
 		call msd(map,nx,ny,nz,nm8,meanmap,stdmap,err)
@@ -337,9 +388,22 @@
         counter2 = 0
         acount=0
         
-        comx=comx+cx
-        comy=comy+cy       
-        comz=comz+cz
+   !     comx=comx+cx
+   !     comy=comy+cy       
+   !     comz=comz+cz
+
+!v1.3 make nearest integer   
+
+	comx=int((comx/1)+.5)
+	comy=int((comy/1)+.5)
+	comz=int((comz/1)+.5)
+
+	comix=int((comx/1)+.5)
+	comiy=int((comy/1)+.5)
+	comiz=int((comz/1)+.5)
+
+
+	print*,comx,comy,comz
 
         do a = 1, numangles      
 	        print*,'angle searching = ',a,' numangles = ',numangles,'nm=',nm
@@ -455,6 +519,23 @@
 	stdccc=((sumnumccc*sumcccssq)+(sumcccs*sumcccs))/(sumnumccc*sumnumccc)
 	print*,'stdevCCC = ',stdccc
 	
+
+! write a shifted cccmaxmap
+     
+	cmap(0:nxm1, 0:nym1, 0:nzm1)  = cccmaxmap(0:nxm1, 0:nym1, 0:nzm1 )	
+        cmap= cshift(cmap,shift=comix,dim=1)
+        cmap= cshift(cmap,shift=comiy,dim=2)
+        cmap= cshift(cmap,shift=comiz,dim=3)
+
+	cccmaxmap(0:nxm1, 0:nym1, 0:nzm1)  = cmap(0:nxm1, 0:nym1, 0:nzm1 )	
+
+	CALL IMOPEN(7,'cccmaxmap-shifted'//num(runcode)//'.mrc','UNKNOWN')
+        CALL ITRHDR(7,1)
+	CALL WRITEMRCMAP(7,cccmaxmap,nx,ny,nz,sampling,err) !open already, close it, subtract 2 from nx
+
+
+
+
 	goto 999
 
 !C ***********************************************
@@ -472,6 +553,9 @@
         stop
            
 999    continue    
+
+       call imclose(1)
+  
        print*,'Program finished O.K.'
 
        STOP
@@ -526,6 +610,58 @@
      	
 	END SUBROUTINE READMRCMAP
 	
+
+	SUBROUTINE READMRCMAP2(stream,filename,map,X,Y,Z,lx,ly,lz,open,close,add2,err)
+ 
+        Use mrc_image
+
+         INTEGER  X,Y,Z,err
+         INTEGER  stream, IX,IY,IZ,xm1
+         real, DIMENSION (0:X+1,0:Y-1,0:Z-1) :: map  
+         INTEGER S(3),S1
+         logical add2,open,close
+         character*80 filename
+            
+          if(.not. open) then
+          	       CALL IMOPEN(stream,filename,'RO')
+       		       CALL IRDHDR(stream,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
+	  endif
+            
+         
+      
+      
+!     read in file 
+
+      DO 1350 IZ = 0,nz-1
+          DO 1350 IY = 0,ny-1
+            CALL IRDLIN(stream,ALINE,*1998)
+            DO 1300 IX = 0,nx-1       
+       !     print*,ix
+                map(ix,iy,iz) = ALINE(IX+1)
+1300         CONTINUE  
+	if(add2) then  
+     		       map(X+0,iy,iz)=0
+      		       map(X+1,iy,iz)=0
+        endif
+        
+!           print*,ix,iy,iz
+
+
+
+
+
+1350   CONTINUE
+
+	if (close) then
+		CALL IMCLOSE(stream)
+		print*,'closed ',stream
+	endif
+
+      return
+1998   STOP 'Error on file read.'
+     	
+	END SUBROUTINE READMRCMAP2
+	
 	
        
       SUBROUTINE WRITEMRCMAP(stream,map,x,y,z,sampling,err)
@@ -843,17 +979,28 @@
       mean=lsum/nm8
 
 	map8=map
+
+       lsum = sum(map8(0:nxm1,0:nym1,0:nzm1))
+        mean=lsum/nm8
+
+
 	map8=map8*map8
 
        sum_sqs=sum(map8(0:nxm1,0:nym1,0:nzm1))
     
  	 lsum=lsum*lsum
- 	 sum_sqs=nm8*sum_sqs
- 	 sq=((sum_sqs-lsum))
- 	 sq=sq/(nm8*nm8)
-    
+ !	 sum_sqs=nm8*sum_sqs
+ !	 sq=((sum_sqs-lsum))
+ !	 sq=sq/(nm8*nm8)
+  
+          sq = sum_sqs - (nm8*mean*mean)
 
-       if (sq.lt.0.0) stop 'sd lt zero in msd set.'
+	  print*, sq,sum_sqs,mean,nm8,lsum
+
+	  sq=sq/nm8
+  
+        print*,'sq=',sq
+       if (sq.lt.0.0) stop 'sd lt zero in msd set...'
 
        th=0.000000000001
       if (sq.gt.th) then
