@@ -67,7 +67,7 @@ def unittest_args():
                         '--ncpu',
                         help='number of CPUs',
                         type=int,
-                        default=1)
+                        default=2)
     parser.add_argument('-c',
                         '--coverage',
                         help='coverage of test',
@@ -100,6 +100,7 @@ def main(args):
     if args.coverage == 'performance':
         coverage = unit_integration_performance
     # Set number of CPUs available
+    n_cpu = args.ncpu
     if args.path is None:
         ccpem_core_path = os.path.dirname(ccpem_core.__file__)
         # Move to root directory to include src and unittest directories
@@ -114,6 +115,8 @@ def main(args):
                  '-k', coverage]
     for path in ignore:
         run_args += ['--ignore', path]
+    if n_cpu > 1:
+        run_args += ['-n', str(n_cpu)]
     if args.xml_output:
         run_args += ['--junitxml', 'results.xml']
     
@@ -121,10 +124,20 @@ def main(args):
         # If sip is available, turn off destroy on exit behaviour
         # (Destructors are called in random order which causes a segfault on
         # exit if multiple tests are run which use PyQt4)
-        import sip
+        try:
+            from PyQt4 import sip
+        except ImportError:
+            import sip
         sip.setdestroyonexit(False)
     except:
+        print("Warning: sip is not available. The test runner might fail "
+              "with segmentation faults after running PyQt4 tests.")
         pass
+
+    # Work around for matplotlib Qt4Agg backend causing problems with tests
+    # TODO: remove this after fixing the underlying Qt4Agg problem!
+    import matplotlib
+    matplotlib.use('agg')
     
     pytest.main(run_args)
 
