@@ -12,7 +12,7 @@ def main():
     parser.add_argument(
         'stdin',
         help='log file to parse',
-        type=file,
+        type=open,
         metavar='<file>'
     )
     parser.add_argument(
@@ -32,7 +32,7 @@ def main():
     parser.add_argument(
         '-k', '--kwdin',
         help='kwd file to parse',
-        type=file,
+        type=open,
         metavar='<file>'
     )
     parser.add_argument(
@@ -54,7 +54,7 @@ def main():
     )
     parser.add_argument(
         '-v', '--verbose',
-        help='print results of parsing for each recognised line',
+        help='show results of parsing for each recognised line',
         action='store_true'
     )
     parser.add_argument(
@@ -121,7 +121,12 @@ def main():
         patches = [fix_fsc_table, fix_stars],
       )
       API.flush()
-      print 'demo.py, summary:', summary
+      sys.stdout.write('demo.py, summary:\n')
+      for key, value in sorted(summary.items()):
+        sys.stdout.write(key + ':\n')
+        for kv in sorted(value.items()):
+          sys.stdout.write('%s = %s\n' %kv)
+
       d.close()
 
 def fix_fsc_table(line):
