@@ -1,7 +1,7 @@
 
 import re
 import pyrvapi_ext as API
-import regex_tree as RT
+from . import regex_tree as RT
 import time, sys
 import math
 
@@ -9,7 +9,7 @@ class generic_parser(object):
 
   def flush(self):
     if self.pause > 0:
-      print >>sys.stdout, 'sleepping'
+      sys.stdout.write('sleepping\n')
       time.sleep(self.pause)
 
     API.flush()
@@ -213,7 +213,7 @@ class generic_parser(object):
 
       column_name_list.append(column_name)
 
-    column_data_list = zip(*[line.split() for line in body.split('\n') if line.strip()])
+    column_data_list = list(zip(*[line.split() for line in body.split('\n') if line.strip()]))
     assert len(column_data_list) == len(column_name_list)
     if column_nick_list:
       assert len(column_name_list) == len(column_nick_list)
@@ -290,14 +290,12 @@ class generic_parser(object):
       x_is_reso = column_nick_list[axisx].strip() in rec_sq_reso_names
       column_name_x = column_name_list[axisx].strip()
       if x_is_reso:
-        # Angstrem sign:
-        # uno = 8491
-        # rch = '\xe2\x84\xab'
-        # A-ring letter:
-        uno = 197
-        rch = '\xc3\x85'
-        assert rch == unichr(uno).encode('utf-8')
-        column_name_x = 'Resolution (' + rch + ')'
+        # Angstrem sign (8491):
+        # encoded = b'\xe2\x84\xab'
+        # A-ring letter (197):
+        encoded = b'\xc3\x85'
+        decoded = str(encoded) if sys.getdefaultencoding() == 'ascii' else encoded.decode()
+        column_name_x = 'Resolution (' + decoded + ')'
 
       pltobj = API.graph_plot(self.widget, title, column_name_x, '')
       if x_is_reso:
