@@ -48,13 +48,13 @@ class document(object):
       os.mkdir(reportdir)
 
     if ostream:
-      print >>ostream, 'JavaScript library:', jslib
-      print >>ostream, 'Report directory:  ', reportdir
-      print >>ostream, 'Python executable: ', sys.executable
+      ostream.write('JavaScript library: ' + jslib + '\n')
+      ostream.write('Report directory:  ' + reportdir + '\n')
+      ostream.write('Python executable: ' + sys.executable + '\n')
       pfilter = lambda p: p.startswith('/Library') or os.path.abspath(p) == os.getcwd()
       pp = [p for p in sys.path if not pfilter(p)]
       pp.insert(0, 'In python path:')
-      print >>ostream, '\n  '.join(pp)
+      ostream.write('\n  '.join(pp) + '\n')
 
     #// Document modes
     #define RVAPI_MODE_Silent  0x00100000
