@@ -545,8 +545,8 @@ REMARK    MODEL GENERATE WITH TEMPY
             g = open(filename, 'w')
         else:
             g = open(filename+'.pdb', 'w')
-        header='''EXPDTA    MODEL GENERATE WITH TEMPY
-REMARK    MODEL GENERATE WITH TEMPY
+        header='''EXPDTA    MODEL GENERATED WITH TEMPY
+REMARK    MODEL GENERATED WITH TEMPY
 '''
         g.write(header)
         structList=self.split_into_chains()
@@ -566,14 +566,18 @@ REMARK    MODEL GENERATE WITH TEMPY
             if strchain==0:
                 chainlisttot[strchain].renumber_atoms()
             else:
-                start_num=chainlisttot[strchain-1].atomList[-1].serial
-                #+2 there is ter 
-                chainlisttot[strchain].renumber_atoms(start_num=start_num+2)
+                try:
+                    start_num=chainlisttot[strchain-1].atomList[-1].serial
+                    #+2 there is ter 
+                    chainlisttot[strchain].renumber_atoms(start_num=start_num+2)
+                except IndexError: pass
             for x in chainlisttot[strchain].atomList:
                 g.write(x.write_to_PDB())
                 last_prot_num+=1
-            line = chainlisttot[strchain].atomList[-1]._writeTerm()+'\n'
-            g.write(line)
+            try: 
+                line = chainlisttot[strchain].atomList[-1]._writeTerm()+'\n'
+                g.write(line)
+            except IndexError: pass
             #last_prot_num+=1
 
         #print last_prot_num
@@ -596,7 +600,7 @@ REMARK    MODEL GENERATE WITH TEMPY
                 line = hetchain[chain].atomList[-1]._writeTerm()+'\n'
                 g.write(line)
         lineend = ''
-        lineend += 'ENDMDL'.ljust(6)+'\n'
+        #lineend += 'ENDMDL'.ljust(6)+'\n'
         g.write(lineend)
         g.write(self.footer)
         g.close()
@@ -655,7 +659,8 @@ REMARK    MODEL GENERATE WITH TEMPY
             x_CoM = x_momentTotal/massTotal
             y_CoM = y_momentTotal/massTotal
             z_CoM = z_momentTotal/massTotal
-        return Vector.Vector(x_CoM, y_CoM, z_CoM)
+        try: return Vector.Vector(x_CoM, y_CoM, z_CoM)
+        except UnboundLocalError: return Vector.Vector(0.0,0.0,0.0)
 
     def translate(self, x, y, z):
         """
@@ -1089,6 +1094,20 @@ REMARK    MODEL GENERATE WITH TEMPY
         else:
             print "Warning no chain %s found"%chainID
     
+    def get_dict_str(self):
+        dict_ch = {}
+        list_res = []
+        #get chain details
+        currentChain = self.atomList[0].chain
+        for x in self.atomList:
+            if not x.chain == currentChain:
+                dict_ch[currentChain] = list_res[:]
+                currentChain = x.chain
+                list_res = []
+            cur_chain = x.chain
+            list_res.append(x.get_res_no())
+        if not cur_chain in dict_ch: dict_ch[cur_chain] = list_res[:]
+        return dict_ch
     
     def get_selection(self, startRes, finishRes, chain=''):
         """
