@@ -24,19 +24,20 @@ import os
 import scipy.cluster.hierarchy as hier
 try:
     import matplotlib.gridspec as gridspec
-    import matplotlib.pyplot as plt
     import matplotlib.cm as cm
     import matplotlib.gridspec as gridspec
-    import matplotlib.pyplot as plt
     import matplotlib.colors as mplcol
     from matplotlib.ticker import MultipleLocator
     from matplotlib import rcParams
-
-
 except ImportError:
     sys.stderr.write('to run this module please install matplotlib\n')
     sys.exit()
 
+try:
+    import matplotlib.pyplot as plt
+except RuntimeError:
+    plt = None
+
 import scipy.spatial.distance as ssd
 from numpy import zeros
 from numpy import array
@@ -140,7 +141,7 @@ class Plot:
             fig.savefig(str(name)+'.pdf')
         plt.show()
 
-    def ShowGeneralMatrix(self,mxGen,file_name='HeatMap',save=False,range=(0,1),figsize=(7, 5),cmap=plt.cm.Blues):
+    def ShowGeneralMatrix(self,mxGen,file_name='HeatMap',save=False,range=(0,1),figsize=(7, 5),cmap=None):
         """
           Heat Map plot of a matrix.
                 Arguments:
@@ -156,7 +157,8 @@ class Plot:
                     *cmap*
                         color palette to use. Choose form the one available in matplotlib or use cmp_Rainbow.
         """
-
+        if cmap is None:
+            cmap = plt.cm.Blues
         fig = plt.figure(figsize=figsize,dpi=300)
         ax = fig.add_subplot(111)
         #ax.set_title('SCCC plot')
@@ -411,3 +413,64 @@ class Plot:
                         else: line_out+='\t:%s\t%s\n'%(res,line2)
                 check += 1
         outfile.write(line_out)
+        
+    def lineplot(self,dict_points,outfile,xlabel=None,ylabel=None,xlim=None,ylim=None,
+                 legend_loc='upper left',line=True,marker=True,leg_pos=1.2,lstyle=True,
+                 legend = True):
+        #print 'Setting maptpltlib parameters'
+        try: plt.style.use('ggplot')
+        except AttributeError: pass
+        if len(dict_points) < 4: leg_pos = 1.15
+        elif len(dict_points) < 9: leg_pos = 1.4
+        else: leg_pos = 1.6 
+        ymaxm = xmaxm = -100.0
+        for k in dict_points:
+            if max(dict_points[k][1]) > ymaxm: ymaxm = max(dict_points[k][1])
+            if max(dict_points[k][0]) > xmaxm: xmaxm = max(dict_points[k][0]) 
+        
+        legendlist=[]
+        ###colorlist = ['darkcyan','brown','gray','darkgreen','darkkhaki','coral','indigo','maroon']#,'darkkhaki'
+        colormap = plt.cm.Spectral#Set1,Spectral#YlOrRd,Spectral,BuGn,Set1,Accent,spring
+        if len(dict_points) < 4: colormap = plt.cm.gist_earth
+        plt.gca().set_color_cycle([colormap(i) for i in nplinspace(0, 1, len(dict_points)+1)])
+        
+        if ylim is not None: plt.gca().set_ylim(ylim)
+        #,'legend.markerscale': 5}
+        
+        #fig = plt.figure(figsize=(15,8))
+        #plt.rcParams.update({'figure.figsize' : [15, 8]})
+        plt.rcParams.update({'font.size': 18})
+        plt.rcParams.update({'legend.fontsize': 14})
+        
+        if not xlabel is None: plt.xlabel(xlabel, fontsize=15)
+        if not ylabel is None: plt.ylabel(ylabel,fontsize=15)
+        
+        if legend_loc == 'upper left': bbox_to_anchor=(0, leg_pos)
+        elif legend_loc == 'upper right': 
+            bbox_to_anchor=(leg_pos, 0.7)
+            
+        list_styles = []
+        for i in range(0,len(dict_points),4):
+            list_styles.extend(['-',':','-.','--'])
+        list_markers = ['o', '*','>','D','s','p','<','v',':','h','x','+',',','.','_','2','d','^', 'H']
+        while len(list_markers) < len(dict_points):
+            list_markers.extend(list_markers)
+        i = 0
+        for k in dict_points:
+            
+            if line and marker: plt.plot(dict_points[k][0],dict_points[k][1],linewidth=3.0,label=k,linestyle=list_styles[i],marker=list_markers[i])
+            elif line and lstyle: plt.plot(dict_points[k][0],dict_points[k][1],linewidth=3.0,label=k,linestyle=list_styles[i])
+            elif line: plt.plot(dict_points[k][0],dict_points[k][1],linewidth=3.0,label=k)
+            elif marker: plt.plot(dict_points[k][0],dict_points[k][1],label=k,marker=list_markers[i])
+            i += 1
+        if legend:
+            if legend_loc == 'upper right':
+                plt.subplots_adjust(right=.7)
+            leg = plt.legend(loc=legend_loc,bbox_to_anchor=bbox_to_anchor,borderaxespad=0.)#(loc='upper right')
+            for legobj in leg.legendHandles:
+                legobj.set_linewidth(2.0)
+        
+            #plt.tight_layout(pad=7)
+            plt.savefig(outfile,bbox_extra_artists=(leg,), bbox_inches='tight')
+        else: plt.savefig(outfile)
+        plt.close()
