@@ -20,11 +20,12 @@
 #===============================================================================
 
 
-from numpy import array,  zeros, real,sqrt,exp, mgrid, transpose, mean as npmean
+from numpy import array,  zeros, real,sqrt,exp, mgrid, transpose, mean as npmean, amax as npmax
 from scipy.fftpack import fftn, ifftn
 from scipy.ndimage import fourier_gaussian,gaussian_filter,uniform_filter
 from TEMPy.EMMap import Map
 from collections import OrderedDict
+import gc
 
 class StructureBlurrer:
     """ 
@@ -254,10 +255,10 @@ class StructureBlurrer:
             #search all points withing 1.5sigma
             list_points = gridtree.query_ball_point(\
                             [atom.x,atom.y,atom.z], 
-                            sigma_thr*max(sim_sigma_coeff*res_map,1.0))
+                            max(apix,sigma_thr*max(sim_sigma_coeff*res_map,1.0)))
             return list_points
         else:
-            print "Warning, atom out of map box"
+            print "Warning, atom out of map box", atom.chain, atom.get_res_no(), atom.atom_name
             return []
     #added by aj
     def model_tree(self,list_coord1,distpot=6.0,list_coord2=None):
@@ -331,7 +332,9 @@ class StructureBlurrer:
         return dict_chain_indices, dict_chain_CA   
     #added by aj
     # get nearest grid indices for a residue atoms
-    def get_indices(self,structure_instance,emmap,res_map,sim_sigma_coeff=0.187,sigma_thr=2.0,atom_sel=None):
+    def get_indices(self,structure_instance,emmap,res_map,
+                    sim_sigma_coeff=0.187,sigma_thr=2.0,
+                    atom_sel=None, atom_centre='CA'):
         """
         
         Returns flat indices of the pixels occupied by each residue in a chain.
@@ -352,16 +355,20 @@ class StructureBlurrer:
         dict_res_CA = OrderedDict()
         dict_chain_res = OrderedDict()
         dict_chain_CA = OrderedDict()
-        dict_chain_indices = {}
+        dict_chain_indices = OrderedDict()
         gridtree = self.maptree(emmap)[0]
         points = []
         #get chain details
         currentChain = structure_instance.atomList[0].chain
+        prev_res = structure_instance.atomList[0].get_res_no()
+        prev_resname = structure_instance.atomList[0].res
+        ca_coord = ['','','']
         for x in structure_instance.atomList:
             if atom_sel == 'CA' and not x.atom_name == 'CA': continue
             elif atom_sel == 'AR' and x.res not in ['TYR','PHE','TRP'] \
                                 and not x.atom_name == 'CA': continue
-            
+                
+            cur_res = x.get_res_no()
             if not x.chain == currentChain:
                 #uniquify lists
                 for e in dict_res_indices:
@@ -372,25 +379,48 @@ class StructureBlurrer:
                 dict_chain_CA[currentChain] = dict_res_CA.copy()
                 currentChain = x.chain
                 dict_res_indices = {}
+            else:
+                 #check dict_CA if atom_centre not found for prev res
+                if cur_res != prev_res:
+                    if not dict_res_CA.has_key(prev_res):
+                        try: dict_res_CA[prev_res] = [prev_resname].extend(ca_coord)
+                        except AttributeError: 
+                            dict_res_CA[prev_res] = [' '].extend(ca_coord)
+            
             cur_chain = x.chain
-            cur_res = x.get_res_no()
             #save residue numbers in order
             try: 
               if not cur_res in dict_chain_res[currentChain]: 
                   dict_chain_res[currentChain].append(cur_res)
             except KeyError: dict_chain_res[currentChain] = [cur_res]
             #return indices covered by gaussian blur
-            if not res_map is None: points = self.mapGridPositions( \
+            if not res_map is None: 
+                points = self.mapGridPositions( \
                                             emmap,x,gridtree,res_map,
                                             sim_sigma_coeff,sigma_thr)
             #return indices covered by vdW radii
             else: points = self.mapGridPositions_vdw(emmap,x,gridtree)
+            
+            #nucleic acids
+            if x.res in ['A','T','C','G','U']:
+                if atom_centre in ['CA','CB']:
+                    atom_centre = "C1'"
+                if x.atom_name in ["P","C3'","C1'"]:
+                    ca_coord = [x.x, x.y, x.z]
+            elif x.atom_name == 'CA':
+                ca_coord = [x.x, x.y, x.z]
+            if x.atom_name == atom_centre: #x.fullid
+                #CA coordinates
+                try: dict_res_CA[cur_res] = [x.res, x.x, x.y, x.z]
+                except AttributeError: 
+                    dict_res_CA[cur_res] = [' ', x.x, x.y, x.z]
+            
+            prev_res = cur_res
+            prev_resname = x.res
+            #continue if no indices are returned
             if len(points) == 0:
                 dict_res_indices[cur_res] = []
                 continue
-            if x.atom_name == 'CA': #x.fullid
-                #CA coordinates
-                dict_res_CA[cur_res] = [x.x, x.y, x.z]
             # get points occupied by the residue
             if dict_res_indices.has_key(cur_res):
                 dict_res_indices[cur_res].extend(points)
@@ -403,6 +433,10 @@ class StructureBlurrer:
                 dict_res_indices[e] = list(setlist)
             dict_chain_indices[currentChain] = dict_res_indices.copy()
             dict_chain_CA[currentChain] = dict_res_CA.copy()
+        if not dict_res_CA.has_key(cur_res):
+            try: dict_res_CA[cur_res] = [x.res].extend(ca_coord)
+            except AttributeError: 
+                    dict_res_CA[cur_res] = [' '].extend(ca_coord)
         return dict_chain_indices, dict_chain_res,dict_chain_CA, gridtree
     
     #added by aj
@@ -425,9 +459,10 @@ class StructureBlurrer:
            *win*
                Fragment length (odd values)
         """
-        dict_chain_indices, dict_chain_res,dict_res_dist = \
+        dict_chain_indices, dict_chain_res,dict_chain_CA, gridtree = \
             self.get_indices(structure_instance,emmap,res_map,
-                             sim_sigma_coeff,sigma_thr=sigma_thr)
+                             sim_sigma_coeff=sim_sigma_coeff,
+                             sigma_thr=sigma_thr)
         origin = emmap.origin
         apix = emmap.apix
         box_size = emmap.box_size()
@@ -439,6 +474,7 @@ class StructureBlurrer:
         for ch in dict_chain_indices:
             dict_res_scores = {}
             dict_res_indices = dict_chain_indices[ch]    
+            prev_mapval = 0.0
             for res in dict_res_indices:
                 if not dict_res_scores.has_key(res):
                     indices = dict_res_indices[res][:]
@@ -472,8 +508,14 @@ class StructureBlurrer:
                     '''
                     array_indices = array(sc_indices)
                     ind_arrxyz = transpose(array_indices)
-                    ind_arrzyx = (ind_arrxyz[2],ind_arrxyz[1],ind_arrxyz[0])
-                dict_res_scores[res] = npmean(emmap.fullMap[ind_arrzyx])
+                    try:
+                        ind_arrzyx = (ind_arrxyz[2],ind_arrxyz[1],ind_arrxyz[0])
+                    except IndexError:
+                        dict_res_scores[res] = prev_mapval
+                        continue
+                    mapval = npmean(emmap.fullMap[ind_arrzyx])
+                    dict_res_scores[res] = mapval
+                    prev_mapval = mapval
             dict_chain_scores[ch] = dict_res_scores.copy()
         return dict_chain_scores
                     
@@ -918,11 +960,14 @@ class StructureBlurrer:
         sigma = sigma_coeff*resolution
         newMap = self.make_atom_overlay_map(newMap, prot)
         gauss_map = gaussian_filter(newMap.fullMap, sigma)
+        del newMap.fullMap
         newMap.fullMap = gauss_map
         newMap = newMap.downsample_map(densMap_apix,grid_shape=densMap.fullMap.shape)
+        del gauss_map
         if normalise:
             newMap = newMap.normalise()
         newMap.update_header()
+        gc.collect()
         return newMap
 
     def gaussian_blur_real_space_box(self, prot, resolution, box_size_x, box_size_y, box_size_z, sigma_coeff=0.356, normalise=True,filename="None"):
