@@ -91,13 +91,14 @@ post_list = ["coot_gui.py",
             "enhanced_ligand.py",
             "ligand_check.py",
             "acedrg_link.py",
+            "sharpen_blur.py",
             "interactive_nudge_residues.py",
             "gui_ligand_sliders.py",
             "coot_toolbuttons.py",
             "pdbe_validation_data.py",
             "contact_score_isolated_ligand.py",
-            "ligand_validation_sliders.py"
-	    # "rcrane_loader.py" # calls set_found_coot_gui()
+            "ligand_validation_sliders.py",
+            "rcrane_loader.py" # calls set_found_coot_gui()
 ]
 
 # list of modules not available on Windows
