@@ -295,7 +295,7 @@ if (have_coot_python):
 
      add_simple_coot_menu_menuitem(
        submenu_maps,
-       "Copy Map Molecule...", 
+       "Copy Map...",
        lambda func: map_molecule_chooser_gui("Map to Copy...", 
 		lambda imol: copy_molecule(imol)))
 
@@ -444,22 +444,30 @@ if (have_coot_python):
        lambda func: molecule_chooser_gui("Assign HETATMs as per PDB definition", 
 		lambda imol: assign_hetatms(imol)))
 
-
-     add_simple_coot_menu_menuitem(
-       submenu_models,
-       "Copy Coordinates Molecule...", 
-       lambda func: molecule_chooser_gui("Molecule to Copy...", 
-		lambda imol: copy_molecule(imol)))
+     # in main menu now
+     # add_simple_coot_menu_menuitem(
+     #   submenu_models,
+     #   "Copy Coordinates Molecule...", 
+     #   lambda func: molecule_chooser_gui("Molecule to Copy...", 
+     #    	lambda imol: copy_molecule(imol)))
 
 
-     add_simple_coot_menu_menuitem(
-       submenu_models,
-       "Copy Fragment...", 
-       lambda func: generic_chooser_and_entry("Create a new Molecule\n \
-                                  From which molecule shall we seed?", 
-                                 "Atom selection for fragment", "//A/1-10", 
-		lambda imol, text: new_molecule_by_atom_selection(imol,text)))
-
+     # moved to main menu now
+     # should stay open if helper function returns False
+     # def atom_selection_from_fragmemt_func(imol, text, button_state):
+     #   print "BL DEBUG:: imol, text, button_state", imol, text, button_state
+     #   jmol = new_molecule_by_atom_selection(imol, text)
+     #   if button_state:
+     #     move_molecule_to_screen_centre(jmol)
+     #   return valid_model_molecule_qm(jmol)
+     # add_simple_coot_menu_menuitem(
+     #   submenu_models,
+     #   "Copy Fragment...", 
+     #   lambda func: generic_chooser_and_entry_and_check_button("Create a new Molecule\n \
+     #                              From which molecule shall we copy the fragment?", 
+     #                                                           "Atom selection for fragment", "//A/1-10", "Move molecule here?", 
+     #    	                                               lambda imol, text, button_state: atom_selection_from_fragmemt_func(imol, text, button_state),
+     #                                          False))
 
      # --- D ---
 
@@ -771,25 +779,26 @@ if (have_coot_python):
      # --- Rep ---
 
      # BL says:: may work, not sure about function entirely
-     add_simple_coot_menu_menuitem(
-       submenu_models,
-       "Replace Fragment...",
-       lambda func: molecule_chooser_gui("Define the molecule that needs updating",
-		lambda imol_base: generic_chooser_and_entry(
-				"Molecule that contains the new fragment:",
-				"Atom Selection","//",
-				lambda imol_fragment, atom_selection_str:
-				replace_fragment(imol_base, imol_fragment, atom_selection_str))))
+     # this is in main menu now
+     # add_simple_coot_menu_menuitem(
+     #   submenu_models,
+     #   "Replace Fragment...",
+     #   lambda func: molecule_chooser_gui("Define the molecule that needs updating",
+     #    	lambda imol_base: generic_chooser_and_entry(
+     #    			"Molecule that contains the new fragment:",
+     #    			"Atom Selection","//",
+     #    			lambda imol_fragment, atom_selection_str:
+     #    			replace_fragment(imol_base, imol_fragment, atom_selection_str))))
 
-     
-     add_simple_coot_menu_menuitem(
-       submenu_models,
-       "Replace Residue...",
-       lambda func: generic_single_entry("Replace this residue with residue of type:",
-                                         "ALA", "Mutate",
-                                         lambda text: using_active_atom(mutate_by_overlap,
-                                                                        "aa_imol", "aa_chain_id", "aa_res_no",
-                                                                        text)))
+     # in main menu now
+     # add_simple_coot_menu_menuitem(
+     #   submenu_models,
+     #   "Replace Residue...",
+     #   lambda func: generic_single_entry("Replace this residue with residue of type:",
+     #                                     "ALA", "Mutate",
+     #                                     lambda text: using_active_atom(mutate_by_overlap,
+     #                                                                    "aa_imol", "aa_chain_id", "aa_res_no",
+     #                                                                    text)))
 
      # --- Res ---
      
@@ -1177,7 +1186,13 @@ if (have_coot_python):
        submenu,
        "Molasses Refinement mode", 
        lambda func: (printf("Molasses..."),
-                     set_dragged_refinement_steps_per_frame(5)))
+                     set_dragged_refinement_steps_per_frame(4)))
+
+
+     add_simple_coot_menu_menuitem(
+       submenu,
+       "Smooth Refinement mode",
+       lambda func: (set_dragged_refinement_steps_per_frame(42)))
 
 
      add_simple_coot_menu_menuitem(
@@ -1244,120 +1259,58 @@ if (have_coot_python):
 	else:
 		add_status_bar_text("Failed to read a number")
 
-     add_simple_coot_menu_menuitem(
-       submenu_refine,
-       "Set Density Fit Graph Weight...",
-       lambda func: generic_single_entry("set weight (smaller means apparently better fit)", 
-		str("%.2f" %residue_density_fit_scale_factor()), "Set it", 
-		lambda text: set_den_gra_func(text)))
 
 
-     # ---------------------------------------------------------------------
-     #     Recent structures from the PDBe
-     # ---------------------------------------------------------------------
-     #
-     add_simple_coot_menu_menuitem(
-       submenu_pdbe, "PDBe recent structures...",
-       lambda func: pdbe_latest_releases_gui())
+#      # ---------------------------------------------------------------------
+#      #     Recent structures from the PDBe
+#      # ---------------------------------------------------------------------
+#      #
+#      add_simple_coot_menu_menuitem(
+#        submenu_pdbe, "PDBe recent structures...",
+#        lambda func: pdbe_latest_releases_gui())
 
-     # we do test for refmac at startup not runtime (for simplicity)
-     if command_in_path_qm("refmac5"):
-       mess = " Get it "
-     else:
-       mess = "\n  WARNING::refmac5 not in the path - SF calculation will fail  \n\n"
+#      # we do test for refmac at startup not runtime (for simplicity)
+#      if command_in_path_qm("refmac5"):
+#        mess = " Get it "
+#      else:
+#        mess = "\n  WARNING::refmac5 not in the path - SF calculation will fail  \n\n"
        
-     add_simple_coot_menu_menuitem(
-       submenu_pdbe, "Get from PDBe...",
-       lambda func: generic_single_entry("Get PDBe accession code",
-                                         "", " Get it ",
-                                         lambda text:
-                                         pdbe_get_pdb_and_sfs_cif("include-sfs", text.rstrip().lstrip())))
+#      add_simple_coot_menu_menuitem(
+#        submenu_pdbe, "Get from PDBe...",
+#        lambda func: generic_single_entry("Get PDBe accession code",
+#                                          "", " Get it ",
+#                                          lambda text:
+#                                          pdbe_get_pdb_and_sfs_cif("include-sfs", text.rstrip().lstrip())))
 
-     # ---------------------------------------------------------------------
-     #     Tutorial data
-     # ---------------------------------------------------------------------
-     #
-     def load_tutorial_data_func():
-       data_dir = False
-       prefix_dir = os.getenv("COOT_PREFIX")
-       if not prefix_dir:
-         pkg_data_dir = pkgdatadir()
-       else:
-         pkg_data_dir = os.path.join(prefix_dir, "share", "coot")
-       if os.path.isdir(pkg_data_dir):  
-         data_dir = os.path.join(pkg_data_dir, "data")
-       if data_dir:
-         pdb_file_name = os.path.join(data_dir, "tutorial-modern.pdb")
-         mtz_file_name = os.path.join(data_dir, "rnasa-1.8-all_refmac1.mtz")
+#      # ---------------------------------------------------------------------
+#      #     Tutorial data
+#      # ---------------------------------------------------------------------
+#      #
+#      def load_tutorial_data_func():
+#        data_dir = False
+#        prefix_dir = os.getenv("COOT_PREFIX")
+#        if not prefix_dir:
+#          pkg_data_dir = pkgdatadir()
+#        else:
+#          pkg_data_dir = os.path.join(prefix_dir, "share", "coot")
+#        if os.path.isdir(pkg_data_dir):  
+#          data_dir = os.path.join(pkg_data_dir, "data")
+#        if data_dir:
+#          pdb_file_name = os.path.join(data_dir, "tutorial-modern.pdb")
+#          mtz_file_name = os.path.join(data_dir, "rnasa-1.8-all_refmac1.mtz")
 
-         if os.path.isfile(pdb_file_name):
-           read_pdb(pdb_file_name)
-         if os.path.isfile(mtz_file_name):
-           make_and_draw_map(mtz_file_name, "FWT", "PHWT", "", 0, 0)
-           make_and_draw_map(mtz_file_name, "DELFWT", "PHDELWT", "", 0, 1)
+#          if os.path.isfile(pdb_file_name):
+#            read_pdb(pdb_file_name)
+#          if os.path.isfile(mtz_file_name):
+#            make_and_draw_map(mtz_file_name, "FWT", "PHWT", "", 0, 0)
+#            make_and_draw_map(mtz_file_name, "DELFWT", "PHDELWT", "", 0, 1)
        
-     add_simple_coot_menu_menuitem(
-       menu,
-       "Load tutorial model and data",
-       lambda func: load_tutorial_data_func()
-       )
+#      add_simple_coot_menu_menuitem(
+#        menu,
+#        "Load tutorial model and data",
+#        lambda func: load_tutorial_data_func()
+#        )
 
-
-     # ---------------------------------------------------------------------
-     #     Lidia
-     # ---------------------------------------------------------------------
-     #
-     if coot_can_do_lidia_p():
-       # don't do this if the LIDIA interface functions have already
-       # been done in guile-gtk.
-       # Otherwise, do, of course
-       #
-       if (use_gui_qm != 2):
-
-         submenu_lidia = gtk.Menu()
-         menuitem_lidia = gtk.MenuItem("Lidia...")
-
-         menuitem_lidia.set_submenu(submenu_lidia)
-         menu.append(menuitem_lidia)
-         menuitem_lidia.show()
-     
-         add_simple_coot_menu_menuitem(
-           submenu_lidia,
-           "Hydrogenate region",
-           lambda func:
-           hydrogenate_region(6)
-           )
-
-         # Does it work?! Maybe not!?
-         add_simple_coot_menu_menuitem(
-           submenu_lidia,
-           "View in LIDIA",
-           lambda func:
-           using_active_atom(fle_view,
-                             "aa_imol", "aa_chain_id",
-                             "aa_res_no", "aa_ins_code")
-           )
-         
-         add_simple_coot_menu_menuitem(
-           submenu_lidia,
-           "Load SBase monomer...",
-           lambda func:
-           generic_single_entry("Load SBase Monomer from three-letter-code: ",
-                                "",
-                                " Load ",
-                                lambda tlc:
-                                get_sbase_monomer(tlc))
-           )
-
-         add_simple_coot_menu_menuitem(
-           submenu_lidia,
-           "Activate prodrg flat mode",
-           lambda func:
-           using_active_atom(prodrg_flat,
-                             "aa_imol", "aa_chain_id",
-                             "aa_res_no")
-           )
-            
      
      # ---------------------------------------------------------------------
      #     Views/Representations
@@ -1515,7 +1468,7 @@ if (have_coot_python):
          
      add_simple_coot_menu_menuitem(
        submenu_representation,
-       "Limit Model Display Radius",
+       "Limit Model Display Radius...",
        lambda func: generic_single_entry("Display Radius Limit (0 for \'no limit\') ",
                                          #  "15.0" ;; maybe this should be the map radius
                                          # BL says:: I think it should be the current one
@@ -1708,7 +1661,7 @@ if (have_coot_python):
 
      add_simple_coot_menu_menuitem(
          submenu_modules, "Carbohydrate",
-         lambda func: add_module_carbohydrate())
+         lambda func: add_module_carbohydrate_gui())
      
      add_simple_coot_menu_menuitem(
          submenu_modules, "Cryo-EM",
@@ -1736,6 +1689,13 @@ if (have_coot_python):
        lambda func: set_rotate_translate_zone_rotates_about_zone_centre(0))
 
 
+     add_simple_coot_menu_menuitem(
+       submenu_settings,
+       "Set Density Fit Graph Weight...",
+       lambda func: generic_single_entry("set weight (smaller means apparently better fit)",
+		str("%.2f" %residue_density_fit_scale_factor()), "Set it",
+		lambda text: set_den_gra_func(text)))
+
      # BL says:: maybe check if number at some point
      add_simple_coot_menu_menuitem(
        submenu_settings,
