@@ -17,6 +17,8 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA
 
+from __future__ import print_function
+
 """
 pyrogen contains tools for converting molecules to mmcif restraints dictionaries,
 utilities for retrival, extraction and depction.
@@ -89,9 +91,9 @@ def execute_mogul(sdf_file_name, mogul_ins_file_name, mogul_out_file_name):
    else:
       return False
 
-def atom_name_from_atomic_number_and_count(element, count):
+def atom_name_from_atomic_number_and_count(element, count, inc):
     name = element
-    name += str(count)
+    name += str(count+inc)
     return name
 
 def add_atom_names(mol):
@@ -102,14 +104,29 @@ def add_atom_names(mol):
           n = atom.GetProp('name')
           atom_names.append(n)
        except KeyError:
+
+          # we want to generate a name that is not already in the atom_names list
+          
           z = atom.GetAtomicNum()
           if z in nz:
              nz[z]  = nz[z] + 1
           else:
              nz[z] = 1;
           ele = atom.GetSymbol().upper()
-          name = atom_name_from_atomic_number_and_count(ele, nz[z])
+          # we add inc argument, which gets added to count (nz[z]) in case that we
+          # already have a name that matches (previous) return from call to 
+          # atom_name_from_atomic_number_and_count()
+          #
+          inc = 0
+          name = atom_name_from_atomic_number_and_count(ele, nz[z], inc)
           p_name = pad_atom_name(name, ele)
+          # print('c.f.', name, " atom names", atom_names)
+          while p_name in atom_names :
+             inc += 1
+             name = atom_name_from_atomic_number_and_count(ele, nz[z], inc)
+             p_name = pad_atom_name(name, ele)
+          # print(atom, 'made-name', p_name, ":")
+
           atom.SetProp("name", p_name)
           atom_names.append(p_name)
     return atom_names
@@ -166,7 +183,7 @@ def is_mdl_file(file_name):
              return True
           else:
              return False
-        
+
 
 # return the contents of file_name
 def read_file(file_name):
@@ -201,20 +218,22 @@ def get_pdbe_cif_for_comp_id(comp_id):
             return file_name
 
       except OSError as e:
-         print e
-         print "Failed: Can't ftp from", url, "and write file", file_name
+         print(e)
+         print("Failed: Can't ftp from", url, "and write file", file_name)
 
    except IOError as e:
-      print e
-      print "Failed: Can't ftp from", url, "and write file", file_name
+      print(e)
+      print("Failed: Can't ftp from", url, "and write file", file_name)
 
+def fetch(comp_id):
+    return get_pdbe_cif_for_comp_id(comp_id)
 
 def MolFromFetchedCode(code):
    f = get_pdbe_cif_for_comp_id(code)
    m = pyrogen_boost.MolFromPDBXr(f, code)
    m.Compute2DCoords()
    return m
-        
+
 def make_restraints_for_bond_orders(mol):
     restraints = {}
     bond_list = []
@@ -241,10 +260,11 @@ def make_restraints_for_bond_orders(mol):
 # return True if mogul is not run or mogul exe is in place.
 # return False if mogul is expected but not found.
 def test_for_mogul():
+   global run_mogul
    if run_mogul:
       mogol_exe = which('mogul')
       if (mogol_exe == None):
-         print "mogul not found in path"
+         print("mogul not found in path")
          return False
       else:
          return True
@@ -299,18 +319,26 @@ def make_picture_to_file(mol, conf_id, output_file_name):
       # The import of Image may change depending on how it was provided.
       # What about pillow? Hmm. Not sure of the details.
       # import Image
-      from PIL import Image
+      from PIL import Image as Image
       state = Draw.MolToFile(mol, size=(300,300), fileName=output_file_name, confId=conf_id)
       # print 'INFO:: wrote PNG   "' + output_file_name + '"'
 
       # img = Draw.MolToImage(mol, fitImage=True, size=(900,900))
       # img2 = img.resize((300, 300), Image.ANTIALIAS)
       # img2.save(output_file_name + "resampled.png")
+
+      # testing MolDraw2D code (squiggly mess)
+      if True:
+         conf_id = AllChem.Compute2DCoords(mol)
+         drawer = Draw.MolDraw2DCairo(300,300)
+         drawer.DrawMolecule(mol, confId=conf_id)
+         drawer.FinishDrawing()
+         # c = drawer.GetDrawingText()
       
    except ImportError as e:
-      print 'ImportError:', e
+      print('ImportError:', e)
    except ValueError as e:
-      print 'ValueError in make_picture():', e
+      print('ValueError in make_picture():', e)
 
 def make_restraints_from_smiles(smiles_string, comp_id, compound_name, mogul_dir, name_stub, pdb_out_file_name, mmcif_dict_name, quartet_planes, quartet_hydrogen_planes, use_mmff, match_atom_names_to_dict_flag, comp_id_list_for_names_match, dict_file_for_names_match):
 
@@ -331,7 +359,7 @@ def make_restraints_from_mdl(mol_file_name, comp_id, mogul_dir, name_stub, pdb_o
       exit(1)
 
    if not os.path.exists(mol_file_name):
-      print "No such file:", mol_file_name
+      print("No such file:", mol_file_name)
       exit(1)
 
    compound_name = '.'
@@ -401,17 +429,24 @@ def make_restraints_from_mmcif_dict_single(cif_file_name_in, comp_id, mogul_dir,
    if False:  # debugging
       for atom in m.GetAtoms():
          try:
-            name   = atom.GetProp('name')
-            chir   = atom.GetProp('_CIPCode')
-            print ' atom', atom, 'name', name, 'chir', chir
+            name    = atom.GetProp('name')
+            cipcode = atom.GetProp('_CIPCode')
+            print('DEBUG:: make_restraints_from_mmcif_dict_single atom', \
+               atom, 'name', name, 'cip-code ', cipcode)
          except KeyError as e:
-            print 'pyrogen.py:: atom', atom, " with name ", name, ' has no _CIPCode property'
+            print('DEBUG:: pyrogen.py:: make_restraints_from_mmcif_dict_single atom', \
+               atom, " with name ", name, ' has no _CIPCode property')
+         try:
+            r = atom.GetProp('_CIPRank')
+            print(atom, "DEBUG:: pyrogen.py:: make_restraints_from_mmcif_dict_single atom cip rank", r)
+         except KeyError as e:
+            print('DEBUG:: pyrogen.py:: make_restraints_from_mmcif_dict_single atom', \
+               atom, "has no _CIPRank")
             pass
 
-
    # maybe user didn't select the correct comp_id for the given dictionary mmcif
    if m.GetNumAtoms() == 0:
-      print 'No atoms for comp_id', comp_id
+      print('No atoms for comp_id', comp_id)
       return False
    else :
 
@@ -419,7 +454,7 @@ def make_restraints_from_mmcif_dict_single(cif_file_name_in, comp_id, mogul_dir,
       try:
          name = m.GetProp('_Name')
       except KeyError:
-         print 'caught KeyError in make_restraints_from_mmcif_dict_single() trying GetProp _Name'
+         print('caught KeyError in make_restraints_from_mmcif_dict_single() trying GetProp _Name')
 
       return make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub,
                              pdb_out_file_name, mmcif_restraints_out_file_name,
@@ -433,6 +468,15 @@ def n_hydrogens(mol):
 	    n_H += 1
     return n_H
 
+def checked_mkdir(dirname):
+    if not os.path.exists(dirname):
+       os.makedirs(dirname)
+    else:
+       if os.path.isdir(dirname):
+          pass # this happens most of the time, I imagine
+       else:
+          print('Stop:: File', dirname, 'exists but is not a directory')
+
 
 # return sane_H_mol
 # 
@@ -445,7 +489,7 @@ def make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub, pdb_out_file_na
    # test here (or in calling functions) if m is sane (i.e. is an rdkit molecule)
 
    if not isinstance(m, Chem.rdchem.Mol):
-      print 'ERROR:: not a molecule'
+      print('ERROR:: not a molecule')
       return False
 
    n_attempts = 20 * m.GetNumAtoms() # default is 10 * number of atoms.
@@ -476,8 +520,9 @@ def make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub, pdb_out_file_na
    else:
       sane_H_mol = m_H
 
-   # This makes UFF types, which can fail sometimes.
-   # conf_id = AllChem.EmbedMolecule(sane_H_mol, AllChem.ETKDG(), maxAttempts=n_attempts)
+   AllChem.AssignStereochemistry(sane_H_mol);
+
+   # conf_id = AllChem.EmbedMolecule(sane_H_mol, maxAttempts=n_attempts)
    conf_id = AllChem.EmbedMolecule(sane_H_mol, AllChem.ETKDG())
 
    if use_mmff:
@@ -489,28 +534,26 @@ def make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub, pdb_out_file_na
 	 if n_bonds > 0:
 	    for i_bond in range(n_bonds):
 	       bond = ba.get_bond(i_bond)
-	       print bond.get_idx_1(), bond.get_idx_2(), bond.get_type(), \
-		     bond.get_resting_bond_length(), bond.get_sigma()
+	       print(bond.get_idx_1(), bond.get_idx_2(), bond.get_type(), \
+		     bond.get_resting_bond_length(), bond.get_sigma())
          n_angles = ba.angles_size()
 	 if n_angles > 0:
 	     for i_angle in range(n_angles):
 		 angle = ba.get_angle(i_angle)
-		 print angle.get_idx_1(), angle.get_idx_2(), angle.get_idx_3(), \
-		       angle.get_resting_angle(), angle.get_sigma()
-         
+		 print(angle.get_idx_1(), angle.get_idx_2(), angle.get_idx_3(), \
+		       angle.get_resting_angle(), angle.get_sigma())
+
    else:
       AllChem.UFFOptimizeMolecule(sane_H_mol, confId=conf_id)
 
-   # AllChem.UFFOptimizeMolecule(sane_H_mol)
-
    atom_names = add_atom_names(sane_H_mol) 
    all_set = atom_types.set_atom_types(sane_H_mol)  # has deloc bonds now, potentially
 
    # debug sane_H_mol
    if True:
       molblock = Chem.MolToMolBlock(sane_H_mol)
-      print >> file("sane_H_mol.mol",'w'), molblock
-
+      # print >> file("sane_H_mol.mol",'w'), molblock
+      print(molblock, file=file("sane_H_mol.mol",'w'))
 
    if (all_set != True):
       return False
@@ -527,13 +570,15 @@ def make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub, pdb_out_file_na
 
       moguled_mol = pyrogen_boost.mogulify(sane_H_mol) # Nitro bond orders (and other things?)
       if not os.path.isdir(mogul_dir):
-	  checked_mkdir(mogul_dir)
+          checked_mkdir(mogul_dir)
 	  if os.path.isdir(mogul_dir):
 	      mb = Chem.MolToMolBlock(moguled_mol)
-	      print >> file(sdf_file_name,'w'), mb
+	      # print >> file(sdf_file_name,'w'), mb
+              print(m, file=file(sdf_file_name,'w'))
       else:
 	  mb = Chem.MolToMolBlock(moguled_mol)
-	  print >> file(sdf_file_name,'w'), mb
+	  # print >> file(sdf_file_name,'w'), mb
+	  print(mb, file=file(sdf_file_name,'w'))
 
       
       bor = make_restraints_for_bond_orders(sane_H_mol)
@@ -541,7 +586,7 @@ def make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub, pdb_out_file_na
       # print out the set types:
       print_atom_props = False
       if print_atom_props:
-	  print '--- Atom Props ---'
+	  print('--- Atom Props ---')
       for atom in sane_H_mol.GetAtoms():
          charge = atom.GetProp('_GasteigerCharge') # string?
          name   = atom.GetProp('name')
@@ -551,13 +596,13 @@ def make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub, pdb_out_file_na
             hybrid      = atom.GetHybridization()
             f_charge    = float(charge)
 	    if print_atom_props:
-		print "  atom: %s %s type: %s arom: %s hybrid: %s charge: %6.3f" % (name, atom.GetSymbol(),
+		print("  atom: %s %s type: %s arom: %s hybrid: %s charge: %6.3f" % (name, atom.GetSymbol(),
 										    atom_type.ljust(4),
 										    str(is_aromatic).ljust(5),
 										    str(hybrid).rjust(3),
-										    f_charge)
+										    f_charge))
          except KeyError:
-            print "miss", name, atom.GetSymbol(), charge
+            print("miss", name, atom.GetSymbol(), charge)
 
       #
       replace_with_mmff_b_a_restraints = False
@@ -601,7 +646,16 @@ def make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub, pdb_out_file_na
 	      # ... but that's OK if we told pyrogen to run without mogul
 
               # sane_H_mol:
-              # print >>file('debug_sane_H.mol','w+'),Chem.MolToMolBlock(sane_H_mol)
+              print(Chem.MolToMolBlock(sane_H_mol), file=file('debug_sane_H.mol','w+'))
+
+              # debug
+              for atom in sane_H_mol.GetAtoms():
+                 try:
+                    r = atom.GetProp('_CIPRank')
+                    print(atom, "DEBUG:: pyrogen.py::make_restraints(): atom cip rank", r)
+                 except KeyError as e:
+                    print('DEBUG:: pyrogen.py::make_restraints() atom', atom, "has no _CIPRank")
+             
 
 	      restraints = pysw.mmcif_dict_from_mol(comp_id, compound_name, sane_H_mol,
 						    mmcif_dict_name,
@@ -609,7 +663,7 @@ def make_restraints(m, comp_id, mogul_dir, mogul_file_name_stub, pdb_out_file_na
 						    replace_with_mmff_b_a_restraints)
               
 	      if restraints == None:
-		  print "No restraints"
+		  print("No restraints")
 		  return True # hacked in value
 
               if match_atom_names_to_dict_flag:
@@ -661,7 +715,178 @@ def atom_match_dictionary(restraints, sane_H_mol, comp_id_list_for_names_match,
 
     return restraints
 
+def simple_make(mmcif_file_name, comp_id):
 
+   global run_mogul
+   run_mogul = False
+   mmcif_restraints_out_file_name = comp_id + "-pyrogen.cif"
+   pdb_fn = comp_id + "-pyrogen.pdb"
+   mol_pairs = make_restraints_from_mmcif_dict(mmcif_file_name,
+                                               comp_id,
+                                               ".', ",'.', 'postfix', False, True, True, pdb_fn,
+                                               mmcif_restraints_out_file_name)
+   for mol_info in mol_pairs:
+      (mol, comp_id) = mol_info
+   if not mol:
+      print('No molecule')
+
+
+def png_from_mmcif_file(mmcif_file_name_in, comp_id, png_file_name):
+   m = pyrogen_boost.rdkit_mol_chem_comp_pdbx(mmcif_file_name_in, comp_id)
+   conf_id = 0
+   n = m.GetNumConformers()
+   if n == 0:
+      conf_id = AllChem.Compute2DCoords(m)
+   conf = m.GetConformer(conf_id)
+   mol_for_drawing = Chem.RemoveHs(m, implicitOnly=False)
+   if conf.Is3D():
+      # print '3D path'
+      conf2D_id = AllChem.Compute2DCoords(mol_for_drawing)
+      make_picture_to_file(mol_for_drawing, conf2D_id, png_file_name)
+   else:
+      # print 'Non-3D path'
+      make_picture_to_file(mol_for_drawing, -1, png_file_name)
+
+def coot_png_from_mmcif_file(mmcif_file_name_in, comp_id, png_file_name, n_pixels=300, BackgroundColor=None):
+   # change the name of cairo_png_depict
+   # BackgroundColor is a hash colour, for example use '#ffffff' for white
+   #
+   return pyrogen_boost.cairo_png_depict(mmcif_file_name_in, comp_id, png_file_name, n_pixels, BackgroundColor)
+
+def depict(mol, iconf = -1, npx=300, highlightAtoms=[], highlightBonds=None, highlightAtomColours=None, highlightBondColours=None):
+    import IPython
+
+    # import Image
+    # import ImageFont
+    from PIL import Image
+    from PIL import ImageFont
+    import PIL
+    import PIL.ImageDraw
+    import io
+    try:
+       n_confs = mol.GetNumConformers()
+       if n_confs == 0:
+	   iconf = mol.Compute2DCoords()
+       s = pyrogen_boost.cairo_png_depict_to_string(mol, iconf, highlightAtoms, highlightBonds, highlightAtomColours, highlightBondColours, npx)
+       if len(s) > 0:
+          sio = io.BytesIO(s)
+          im = Image.open(sio)
+          bo = io.BytesIO()
+          im.save(bo, 'png')
+          IPython.display.display(IPython.display.Image(bo.getvalue()))
+       else:
+          print('Null image')
+    except AttributeError as e:
+	# maybe mol was not a RDKit molecule
+	print('ERROR::', e)
+
+def coot_depict_to_png_string(mol, iconf=-1, n_px=300, highlightAtoms=[], highlightBonds=None, highlightAtomColours=None, highlightBondColours=None):
+       s = pyrogen_boost.cairo_png_depict_to_string(mol, iconf, highlightAtoms, highlightBonds, highlightAtomColours, highlightBondColours, n_px)
+       return s
+
+
+def coot_depict_to_svg_string(mol, iconf=-1, n_px=300, highlightAtoms=[], highlightBonds=None, highlightAtomColours=None, highlightBondColours=None):
+       s = pyrogen_boost.cairo_svg_depict_to_string(mol, iconf, highlightAtoms, highlightBonds, highlightAtomColours, highlightBondColours, n_px)
+       return s
+
+# make MolFromPDBXr available in pyrogen
+def MolFromPDBXr(cif_file_name, comp_id):
+    return pyrogen_boost.MolFromPDBXr(cif_file_name, comp_id)
+
+def MolsToGridImage(mols, mols_per_row=3, sub_image_size=(200,200), legends=None):
+
+    # return None on failure to find the font.
+    # Locate the ttf font file on disk somewhere and make a truetype
+    # font from that (if you can)
+    def find_font():
+
+       import distutils
+       import distutils.sysconfig
+       prfx=distutils.sysconfig.PREFIX
+
+       # this ttf file is hard-coded and copied from dials base/share/fonts
+       # we need to install that directory as part of coot and find
+       # the file in the installation
+       font_file_base_name = "Vera.ttf" # VeraMono
+       dir_1 = os.path.join(prfx,  'share')
+       dir_2 = os.path.join(dir_1, 'coot')
+       dir_3 = os.path.join(dir_2, 'fonts')
+       font_file=os.path.join(dir_3, font_file_base_name)
+       if os.path.isfile(font_file):
+          font=ImageFont.truetype(font_file, 16)
+          return font
+       else:
+          return None
+
+    import IPython
+    # import Image
+    # import ImageFont
+    from PIL import Image
+    from PIL import ImageFont
+    import PIL
+    import PIL.ImageDraw
+    import io
+    n_rows=(len(mols) // mols_per_row)
+    if len(mols) > n_rows*mols_per_row:
+       n_rows += 1
+    full_size=(sub_image_size[0]*mols_per_row, sub_image_size[1]*n_rows)
+    composite=composite = Image.new('RGBA', full_size)
+    font=find_font()
+
+    for count,mol in enumerate(mols):
+        try:
+            # print('mol:', mol)
+            s = pyrogen_boost.cairo_png_depict_to_string(mol, -1, None, None, None, None, sub_image_size[0])
+            sio = io.BytesIO(s)
+            im = Image.open(sio)
+	    # add label if possible
+	    try:
+               if font:
+                  lab = legends[count]
+                  text_x_pos = sub_image_size[0]/2 - 10
+                  if text_x_pos < 0:
+                     text_x_pos = 0
+                  text_y_pos = 0.9 * sub_image_size[0]
+                  min_to_fit = 15
+                  if sub_image_size[1]-text_y_pos < min_to_fit:
+                     text_y_pos = sub_image_size[1] - min_to_fit
+                  draw = PIL.ImageDraw.Draw(im)
+                  # we don't have this attribute (multiline_text). Hmm. Maybe old version of PIL?
+                  # draw.multiline_text((text_x_pos, text_y_pos), lab, fill=(10,10,10,255), font=font, align="center")
+                  draw.text((text_x_pos, text_y_pos), lab, fill=(10,10,10,255), font=font)
+                  # debug print(text_x_pos, text_y_pos)
+            except TypeError as e:
+               # labels was not a list
+               pass
+	    except NameError as e:
+		print(e, "in legends", legends)
+            except IOError as e:
+               print("something label-related:", e)
+            region = im.crop((0,0,sub_image_size[0], sub_image_size[0]))
+            i_row = count // mols_per_row
+            i_col = count - i_row * mols_per_row
+            x_off = i_col * sub_image_size[0]
+            y_off = i_row * sub_image_size[0]
+            composite.paste(region,(x_off, y_off, x_off+sub_image_size[0], y_off+sub_image_size[0]))
+        except ValueError as e:
+            print(e, 'count ', count, " for mol", mol)
+        except IOError as e:
+            print(e, 'count ', count, " for mol", mol)
+        except Exception, e:
+            print(e, 'count ', count, " for mol", mol)
+    b = io.BytesIO()
+    composite.save(b, 'png')
+    IPython.display.display(IPython.display.Image(b.getvalue()))
+
+def prep(mol):
+   m_sh = Chem.RemoveHs(mol)
+   m_sh.Compute2DCoords()
+   Chem.Kekulize(m_sh)
+   return m_sh
+
+def d(mol, npx=300):
+   m_sh = prep(mol)
+   depict(m_sh, npx=npx)
 
 def score_and_print_tautomers(mol, comp_id, output_postfix, do_drawings):
 
@@ -669,7 +894,7 @@ def score_and_print_tautomers(mol, comp_id, output_postfix, do_drawings):
     for i in range(len(results)):
 	m = results[i]
 	s = Chem.MolToSmiles(m)
-	print "comp_id :", comp_id, ": SMILES", s, 'score:', tautomer.tautomer_score(m)
+	print("comp_id :", comp_id, ": SMILES", s, 'score:', tautomer.tautomer_score(m))
 	if do_drawings:
 	    file_name = comp_id + '-tautomer-' + str(i)
 	    file_name += '-' + options.output_postfix + '.png'
@@ -684,26 +909,17 @@ def score_and_print_tautomers(mol, comp_id, output_postfix, do_drawings):
 		make_picture_to_file(mol_for_drawing, conf2D_id, file_name)
 	    else:
 		make_picture_to_file(m, -1, file_name)
-   
+
 
 if __name__ == "__main__":
 
-    def checked_mkdir(dirname):
-        if not os.path.exists(dirname):
-           os.makedirs(dirname)
-	else:
-	   if os.path.isdir(dirname):
-	       pass # this happens most of the time, I imagine
-	   else:
-	       print 'Stop:: File', dirname, 'exists but is not a directory'
-
     def smiles_and_name_from(smi_raw):
        extension = os.path.splitext(smi_raw)[1]
        smiles_string = ''
        name=''
        if extension == '.smi' or extension == '.smiles':
 	   if not os.path.exists(smi_raw):
-	       print "File not found:", smi_raw
+	       print("File not found:", smi_raw)
 	       exit(1)
 	   else: 
 	       smiles_string,name = get_smiles_from_file(smi_raw)
@@ -766,6 +982,8 @@ if __name__ == "__main__":
                       default=False)
     parser.add_option('-w', '--wwPDB', default=False, dest="wwPDB", action="store_true",
                       help='Fetch the wwPDB ligand definition and use that')
+    parser.add_option('-f', dest="fetch", default=False,
+		      help='(Just) fetch from the PDBe the CCD entry for the given compound-id')
     parser.add_option("-q", "--quiet",
                       action="store_false", dest="verbose", default=True,
                       help="print less messages")
@@ -778,7 +996,10 @@ if __name__ == "__main__":
        print("Usage: pyrogen --help")
 
     if options.show_version:
-       print 'pyrogen-' + pyrogen_version, "revision", coot_git.revision_count()
+       print('pyrogen-' + pyrogen_version, "revision", coot_git.revision_count())
+
+    if options.fetch:
+	fetch(options.fetch)
 
     comp_id = options.comp_id
     if options.comp_id == 'default':
@@ -803,7 +1024,7 @@ if __name__ == "__main__":
     if run_mogul:
        if len(options.mogul_dir) > 0:
           if options.mogul_dir[0] == '-':
-             print 'Stop:: you probably didn\'t mean that you wanted',options.mogul_dir, 'as your tmp directory.'
+             print('Stop:: you probably didn\'t mean that you wanted',options.mogul_dir, 'as your tmp directory.')
              exit(1)
           checked_mkdir(options.mogul_dir)
 
@@ -822,7 +1043,7 @@ if __name__ == "__main__":
 	    else:
 		if options.mmcif_file_name != None:
 		    types = pysw.types_from_mmcif_dictionary(options.mmcif_file_name)
-		    print '-- tautomer mode: mmcif file types:', types
+		    print('-- tautomer mode: mmcif file types:', types)
 		    for type in types:
 			mol_local = pyrogen_boost.rdkit_mol_chem_comp_pdbx(options.mmcif_file_name, type)
 			score_and_print_tautomers(mol_local, type, options.output_postfix, options.drawing)
@@ -832,7 +1053,7 @@ if __name__ == "__main__":
               score_and_print_tautomers(mol, comp_id, options.output_postfix, options.drawing)
            if options.show_smiles:
               s = Chem.MolToSmiles(mol);
-              print s
+              print(s)
 
     else:
 
@@ -845,7 +1066,7 @@ if __name__ == "__main__":
            if os.path.isfile(mmcif_file_name):
               pass # good
            else:
-              print "Missing downloaded file for comp-id:",  comp_id
+              print("Missing downloaded file for comp-id:",  comp_id)
               exit(2)
 
         # JED mode for hydrogen planes
@@ -858,6 +1079,7 @@ if __name__ == "__main__":
         if options.no_match_names_flag:
             match_names_flag = False
 
+
 	if mmcif_file_name:
 	    mol_pairs = make_restraints_from_mmcif_dict(mmcif_file_name,
                                                         comp_id,
@@ -876,7 +1098,7 @@ if __name__ == "__main__":
 	    for mol_info in mol_pairs:
 		(mol, comp_id) = mol_info
 		if not mol:
-		    print 'No molecule'
+		    print('No molecule')
 		else:
 		    # Happy path
 		    if options.drawing:
