@@ -2,7 +2,7 @@
 # extension modules created with SIP.  It provides information about file
 # locations, version numbers etc., and provides some classes and functions.
 #
-# Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2018 Riverbank Computing Limited <info@riverbankcomputing.com>
 #
 # This file is part of SIP.
 #
@@ -38,11 +38,12 @@ _pkg_config = {
     'py_version':         0x02070f,
     'qt_framework':       0,
     'sip_bin':            '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/devbin/sip',
-    'sip_config_args':    '--bindir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/devbin --destdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/site-packages --incdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include --sipdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/share/sip LFLAGS+=-L/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
+    'sip_config_args':    '--sip-module PyQt4.sip --bindir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/devbin --destdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/site-packages --incdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include --sipdir=/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/share/sip LFLAGS+=-L/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib -s -Wl,--hash-style=both -Wl,--build-id=sha1',
     'sip_inc_dir':        '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/include',
-    'sip_mod_dir':        '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/site-packages',
-    'sip_version':        0x041009,
-    'sip_version_str':    '4.16.9',
+    'sip_module_dir':     '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/site-packages/PyQt4',
+    'sip_root_dir':       '/home/jenkins/workspace/CCP-EM/sl6_devtoolset/devtools/install/lib/python2.7/site-packages',
+    'sip_version':        0x04130c,
+    'sip_version_str':    '4.19.12',
     'universal':          ''
 }
 
@@ -335,7 +336,8 @@ class Makefile:
         installs is a list of extra install targets.  Each element is a two
         part list, the first of which is the source and the second is the
         destination.  If the source is another list then it is a set of source
-        files and the destination is a directory.
+        files and the destination is a directory.  If the destination is None
+        then the source is a command to run.
         universal is the name of the SDK if the target is a MacOS/X universal
         binary.  If it is None then the value is taken from the configuration.
         arch is the space separated MacOS/X architectures to build.  If it is
@@ -1255,7 +1257,10 @@ class Makefile:
                 self._installs = [self._installs]
 
             for src, dst in self._installs:
-                self.install_file(mfile, src, dst)
+                if dst is None:
+                    mfile.write("\t%s\n" % src)
+                else:
+                    self.install_file(mfile, src, dst)
 
         self.generate_target_clean(mfile)
 
@@ -1421,12 +1426,12 @@ class Makefile:
         strip is set if the files should be stripped after been installed.
         """
         # Help package builders.
-        if self.generator == "UNIX":
-            dst = "$(DESTDIR)" + dst
+        if self.generator == "UNIX" or self.generator == "MINGW":
+            dst = "$(DESTDIR)" + os.path.splitdrive(dst)[1]
 
         mfile.write("\t@%s %s " % (self.chkdir, _quote(dst)))
 
-        if self.generator == "UNIX":
+        if self.generator == "UNIX" or self.generator == "MINGW":
             mfile.write("|| ")
 
         mfile.write("%s %s\n" % (self.mkdir, _quote(dst)))
